@@ -47,16 +47,23 @@
 #include <pcl/apps/point_cloud_editor/statisticsDialog.h>
 #include <pcl/apps/point_cloud_editor/toolInterface.h>
 
+#include <pcl/memory.h>  // for pcl::shared_ptr
+
 #include <QGLWidget>
 
 #include <functional>
 
+class Selection;
+
 /// @brief class declaration for the widget for editing and viewing
 /// point clouds.
 class CloudEditorWidget : public QGLWidget
 {
   Q_OBJECT
   public:
+    /// The type for shared pointer pointing to a selection buffer
+    using SelectionPtr = pcl::shared_ptr<Selection>;
+
     /// @brief Constructor
     /// @param parent a pointer which points to the parent widget
     CloudEditorWidget (QWidget *parent = nullptr);
