@@ -1,15 +1,10 @@
 #pragma once
 
-#include <string>
-#include <vector>
-#include <ostream>
+#include <string>   // for string
+#include <vector>   // for vector
+#include <ostream>  // for ostream
 
-#ifdef USE_ROS
-   #error USE_ROS setup requires PCL to compile against ROS message headers, which is now deprecated
-#endif   
-
-// Include the correct Header path here
-#include <pcl/PCLHeader.h>
+#include <pcl/PCLHeader.h>   // for PCLHeader
 
 namespace pcl
 {
