@@ -1,10 +1,11 @@
 #pragma once
 
+#include <pcl/memory.h>
+#include <pcl/pcl_macros.h>
+
 #include <string>
 #include <vector>
 #include <ostream>
-#include <boost/shared_ptr.hpp>
-#include <pcl/pcl_macros.h>
 
 namespace pcl
 {
