@@ -38,7 +38,6 @@
 #pragma once
 
 #include <pcl/pcl_base.h>
-#include <cfloat>
 
 /**
   * \file pcl/common/common.h
@@ -88,7 +87,7 @@ namespace pcl
     */
   template <typename PointT> inline void 
   getPointsInBox (const pcl::PointCloud<PointT> &cloud, Eigen::Vector4f &min_pt,
-                  Eigen::Vector4f &max_pt, std::vector<int> &indices);
+                  Eigen::Vector4f &max_pt, Indices &indices);
 
   /** \brief Get the point at maximum distance from a given point and a given pointcloud
     * \param cloud the point cloud data message
@@ -107,7 +106,7 @@ namespace pcl
     * \ingroup common
     */
   template<typename PointT> inline void
-  getMaxDistance (const pcl::PointCloud<PointT> &cloud, const std::vector<int> &indices, 
+  getMaxDistance (const pcl::PointCloud<PointT> &cloud, const Indices &indices,
                   const Eigen::Vector4f &pivot_pt, Eigen::Vector4f &max_pt);
 
   /** \brief Get the minimum and maximum values on each of the 3 (x-y-z) dimensions in a given pointcloud
@@ -137,7 +136,7 @@ namespace pcl
     * \ingroup common
     */
   template <typename PointT> inline void 
-  getMinMax3D (const pcl::PointCloud<PointT> &cloud, const std::vector<int> &indices, 
+  getMinMax3D (const pcl::PointCloud<PointT> &cloud, const Indices &indices,
                Eigen::Vector4f &min_pt, Eigen::Vector4f &max_pt);
 
   /** \brief Get the minimum and maximum values on each of the 3 (x-y-z) dimensions in a given pointcloud
@@ -148,7 +147,7 @@ namespace pcl
     * \ingroup common
     */
   template <typename PointT> inline void 
-  getMinMax3D (const pcl::PointCloud<PointT> &cloud, const pcl::PointIndices &indices, 
+  getMinMax3D (const pcl::PointCloud<PointT> &cloud, const pcl::PointIndices &indices,
                Eigen::Vector4f &min_pt, Eigen::Vector4f &max_pt);
 
   /** \brief Compute the radius of a circumscribed circle for a triangle formed of three points pa, pb, and pc
