@@ -38,21 +38,27 @@
  *
  */
 
-#ifndef PCL_COMMON_IMPL_CENTROID_H_
-#define PCL_COMMON_IMPL_CENTROID_H_
+#pragma once
 
 #include <pcl/common/centroid.h>
 #include <pcl/conversions.h>
-#include <boost/mpl/size.hpp>
+#include <pcl/common/point_tests.h> // for pcl::isFinite
+
+#include <boost/fusion/algorithm/transformation/filter_if.hpp> // for boost::fusion::filter_if
+#include <boost/fusion/algorithm/iteration/for_each.hpp> // for boost::fusion::for_each
+#include <boost/mpl/size.hpp> // for boost::mpl::size
+
+
+namespace pcl
+{
 
-///////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::compute3DCentroid (ConstCloudIterator<PointT> &cloud_iterator,
-                        Eigen::Matrix<Scalar, 4, 1> &centroid)
+compute3DCentroid (ConstCloudIterator<PointT> &cloud_iterator,
+                   Eigen::Matrix<Scalar, 4, 1> &centroid)
 {
   // Initialize to 0
   centroid.setZero ();
-  
+
   unsigned cp = 0;
 
   // For each point in the cloud
@@ -74,10 +80,10 @@ pcl::compute3DCentroid (ConstCloudIterator<PointT> &cloud_iterator,
   return (cp);
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::compute3DCentroid (const pcl::PointCloud<PointT> &cloud, 
-                        Eigen::Matrix<Scalar, 4, 1> &centroid)
+compute3DCentroid (const pcl::PointCloud<PointT> &cloud,
+                   Eigen::Matrix<Scalar, 4, 1> &centroid)
 {
   if (cloud.empty ())
     return (0);
@@ -118,11 +124,11 @@ pcl::compute3DCentroid (const pcl::PointCloud<PointT> &cloud,
   return (cp);
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::compute3DCentroid (const pcl::PointCloud<PointT> &cloud, 
-                        const std::vector<int> &indices,
-                        Eigen::Matrix<Scalar, 4, 1> &centroid)
+compute3DCentroid (const pcl::PointCloud<PointT> &cloud,
+                   const Indices &indices,
+                   Eigen::Matrix<Scalar, 4, 1> &centroid)
 {
   if (indices.empty ())
     return (0);
@@ -160,20 +166,20 @@ pcl::compute3DCentroid (const pcl::PointCloud<PointT> &cloud,
   return (cp);
 }
 
-/////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::compute3DCentroid (const pcl::PointCloud<PointT> &cloud,
-                        const pcl::PointIndices &indices,
-                        Eigen::Matrix<Scalar, 4, 1> &centroid)
+compute3DCentroid (const pcl::PointCloud<PointT> &cloud,
+                   const pcl::PointIndices &indices,
+                   Eigen::Matrix<Scalar, 4, 1> &centroid)
 {
   return (pcl::compute3DCentroid (cloud, indices.indices, centroid));
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned
-pcl::computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
-                              const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                              Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
+computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
+                         const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                         Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
 {
   if (cloud.empty ())
     return (0);
@@ -240,11 +246,11 @@ pcl::computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
   return (point_count);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::computeCovarianceMatrixNormalized (const pcl::PointCloud<PointT> &cloud,
-                                        const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                                        Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
+computeCovarianceMatrixNormalized (const pcl::PointCloud<PointT> &cloud,
+                                   const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                                   Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
 {
   unsigned point_count = pcl::computeCovarianceMatrix (cloud, centroid, covariance_matrix);
   if (point_count != 0)
@@ -252,12 +258,12 @@ pcl::computeCovarianceMatrixNormalized (const pcl::PointCloud<PointT> &cloud,
   return (point_count);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
-                              const std::vector<int> &indices,
-                              const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                              Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
+computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
+                         const Indices &indices,
+                         const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                         Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
 {
   if (indices.empty ())
     return (0);
@@ -323,22 +329,22 @@ pcl::computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
   return (static_cast<unsigned int> (point_count));
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
-                              const pcl::PointIndices &indices,
-                              const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                              Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
+computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
+                         const pcl::PointIndices &indices,
+                         const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                         Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
 {
   return (pcl::computeCovarianceMatrix (cloud, indices.indices, centroid, covariance_matrix));
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::computeCovarianceMatrixNormalized (const pcl::PointCloud<PointT> &cloud,
-                                        const std::vector<int> &indices,
-                                        const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                                        Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
+computeCovarianceMatrixNormalized (const pcl::PointCloud<PointT> &cloud,
+                                   const Indices &indices,
+                                   const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                                   Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
 {
   unsigned point_count = pcl::computeCovarianceMatrix (cloud, indices, centroid, covariance_matrix);
   if (point_count != 0)
@@ -347,24 +353,20 @@ pcl::computeCovarianceMatrixNormalized (const pcl::PointCloud<PointT> &cloud,
   return (point_count);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
-template <typename PointT, typename Scalar> inline unsigned int
-pcl::computeCovarianceMatrixNormalized (const pcl::PointCloud<PointT> &cloud,
-                                        const pcl::PointIndices &indices,
-                                        const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                                        Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
-{
-  unsigned int point_count = pcl::computeCovarianceMatrix (cloud, indices.indices, centroid, covariance_matrix);
-  if (point_count != 0)
-    covariance_matrix /= static_cast<Scalar> (point_count);
 
-  return point_count;
+template <typename PointT, typename Scalar> inline unsigned int
+computeCovarianceMatrixNormalized (const pcl::PointCloud<PointT> &cloud,
+                                   const pcl::PointIndices &indices,
+                                   const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                                   Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
+{
+  return computeCovarianceMatrixNormalized(cloud, indices.indices, centroid, covariance_matrix);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
-                              Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
+computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
+                         Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
 {
   // create the buffer on the stack which is much faster than using cloud[indices[i]] and centroid as a buffer
   Eigen::Matrix<Scalar, 1, 6, Eigen::RowMajor> accu = Eigen::Matrix<Scalar, 1, 6, Eigen::RowMajor>::Zero ();
@@ -415,11 +417,11 @@ pcl::computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
   return (point_count);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
-                              const std::vector<int> &indices,
-                              Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
+computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
+                         const Indices &indices,
+                         Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
 {
   // create the buffer on the stack which is much faster than using cloud[indices[i]] and centroid as a buffer
   Eigen::Matrix<Scalar, 1, 6, Eigen::RowMajor> accu = Eigen::Matrix<Scalar, 1, 6, Eigen::RowMajor>::Zero ();
@@ -469,20 +471,20 @@ pcl::computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
   return (point_count);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
-                              const pcl::PointIndices &indices,
-                              Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
+computeCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
+                         const pcl::PointIndices &indices,
+                         Eigen::Matrix<Scalar, 3, 3> &covariance_matrix)
 {
   return (computeCovarianceMatrix (cloud, indices.indices, covariance_matrix));
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::computeMeanAndCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
-                                     Eigen::Matrix<Scalar, 3, 3> &covariance_matrix,
-                                     Eigen::Matrix<Scalar, 4, 1> &centroid)
+computeMeanAndCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
+                                Eigen::Matrix<Scalar, 3, 3> &covariance_matrix,
+                                Eigen::Matrix<Scalar, 4, 1> &centroid)
 {
   // create the buffer on the stack which is much faster than using cloud[indices[i]] and centroid as a buffer
   Eigen::Matrix<Scalar, 1, 9, Eigen::RowMajor> accu = Eigen::Matrix<Scalar, 1, 9, Eigen::RowMajor>::Zero ();
@@ -543,12 +545,12 @@ pcl::computeMeanAndCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
   return (static_cast<unsigned int> (point_count));
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::computeMeanAndCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
-                                     const std::vector<int> &indices,
-                                     Eigen::Matrix<Scalar, 3, 3> &covariance_matrix,
-                                     Eigen::Matrix<Scalar, 4, 1> &centroid)
+computeMeanAndCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
+                                const Indices &indices,
+                                Eigen::Matrix<Scalar, 3, 3> &covariance_matrix,
+                                Eigen::Matrix<Scalar, 4, 1> &centroid)
 {
   // create the buffer on the stack which is much faster than using cloud[indices[i]] and centroid as a buffer
   Eigen::Matrix<Scalar, 1, 9, Eigen::RowMajor> accu = Eigen::Matrix<Scalar, 1, 9, Eigen::RowMajor>::Zero ();
@@ -610,22 +612,22 @@ pcl::computeMeanAndCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
   return (static_cast<unsigned int> (point_count));
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline unsigned int
-pcl::computeMeanAndCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
-                                     const pcl::PointIndices &indices,
-                                     Eigen::Matrix<Scalar, 3, 3> &covariance_matrix,
-                                     Eigen::Matrix<Scalar, 4, 1> &centroid)
+computeMeanAndCovarianceMatrix (const pcl::PointCloud<PointT> &cloud,
+                                const pcl::PointIndices &indices,
+                                Eigen::Matrix<Scalar, 3, 3> &covariance_matrix,
+                                Eigen::Matrix<Scalar, 4, 1> &centroid)
 {
   return (computeMeanAndCovarianceMatrix (cloud, indices.indices, covariance_matrix, centroid));
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> void
-pcl::demeanPointCloud (ConstCloudIterator<PointT> &cloud_iterator,
-                       const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                       pcl::PointCloud<PointT> &cloud_out,
-                       int npts)
+demeanPointCloud (ConstCloudIterator<PointT> &cloud_iterator,
+                  const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                  pcl::PointCloud<PointT> &cloud_out,
+                  int npts)
 {
   // Calculate the number of points if not given
   if (npts == 0)
@@ -653,11 +655,11 @@ pcl::demeanPointCloud (ConstCloudIterator<PointT> &cloud_iterator,
   cloud_out.height = 1;
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> void
-pcl::demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
-                       const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                       pcl::PointCloud<PointT> &cloud_out)
+demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
+                  const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                  pcl::PointCloud<PointT> &cloud_out)
 {
   cloud_out = cloud_in;
 
@@ -670,23 +672,23 @@ pcl::demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
   }
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> void
-pcl::demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
-                       const std::vector<int> &indices,
-                       const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                       pcl::PointCloud<PointT> &cloud_out)
+demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
+                  const Indices &indices,
+                  const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                  pcl::PointCloud<PointT> &cloud_out)
 {
   cloud_out.header = cloud_in.header;
   cloud_out.is_dense = cloud_in.is_dense;
-  if (indices.size () == cloud_in.points.size ())
+  if (indices.size () == cloud_in.size ())
   {
     cloud_out.width    = cloud_in.width;
     cloud_out.height   = cloud_in.height;
   }
   else
   {
-    cloud_out.width    = static_cast<std::uint32_t> (indices.size ());
+    cloud_out.width    = indices.size ();
     cloud_out.height   = 1;
   }
   cloud_out.resize (indices.size ());
@@ -700,22 +702,22 @@ pcl::demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
   }
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> void
-pcl::demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
-                       const pcl::PointIndices& indices,
-                       const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                       pcl::PointCloud<PointT> &cloud_out)
+demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
+                  const pcl::PointIndices& indices,
+                  const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                  pcl::PointCloud<PointT> &cloud_out)
 {
   return (demeanPointCloud (cloud_in, indices.indices, centroid, cloud_out));
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> void
-pcl::demeanPointCloud (ConstCloudIterator<PointT> &cloud_iterator,
-                       const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                       Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> &cloud_out,
-                       int npts)
+demeanPointCloud (ConstCloudIterator<PointT> &cloud_iterator,
+                  const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                  Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> &cloud_out,
+                  int npts)
 {
   // Calculate the number of points if not given
   if (npts == 0)
@@ -741,11 +743,11 @@ pcl::demeanPointCloud (ConstCloudIterator<PointT> &cloud_iterator,
   }
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> void
-pcl::demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
-                       const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                       Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> &cloud_out)
+demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
+                  const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                  Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> &cloud_out)
 {
   std::size_t npts = cloud_in.size ();
 
@@ -757,19 +759,19 @@ pcl::demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
     cloud_out (1, i) = cloud_in[i].y - centroid[1];
     cloud_out (2, i) = cloud_in[i].z - centroid[2];
     // One column at a time
-    //cloud_out.block<4, 1> (0, i) = cloud_in.points[i].getVector4fMap () - centroid;
+    //cloud_out.block<4, 1> (0, i) = cloud_in[i].getVector4fMap () - centroid;
   }
 
   // Make sure we zero the 4th dimension out (1 row, N columns)
   //cloud_out.block (3, 0, 1, npts).setZero ();
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> void
-pcl::demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
-                       const std::vector<int> &indices,
-                       const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                       Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> &cloud_out)
+demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
+                  const Indices &indices,
+                  const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                  Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> &cloud_out)
 {
   std::size_t npts = indices.size ();
 
@@ -781,27 +783,27 @@ pcl::demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
     cloud_out (1, i) = cloud_in[indices[i]].y - centroid[1];
     cloud_out (2, i) = cloud_in[indices[i]].z - centroid[2];
     // One column at a time
-    //cloud_out.block<4, 1> (0, i) = cloud_in.points[indices[i]].getVector4fMap () - centroid;
+    //cloud_out.block<4, 1> (0, i) = cloud_in[indices[i]].getVector4fMap () - centroid;
   }
 
   // Make sure we zero the 4th dimension out (1 row, N columns)
   //cloud_out.block (3, 0, 1, npts).setZero ();
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> void
-pcl::demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
-                       const pcl::PointIndices &indices,
-                       const Eigen::Matrix<Scalar, 4, 1> &centroid,
-                       Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> &cloud_out)
+demeanPointCloud (const pcl::PointCloud<PointT> &cloud_in,
+                  const pcl::PointIndices &indices,
+                  const Eigen::Matrix<Scalar, 4, 1> &centroid,
+                  Eigen::Matrix<Scalar, Eigen::Dynamic, Eigen::Dynamic> &cloud_out)
 {
   return (pcl::demeanPointCloud (cloud_in, indices.indices, centroid, cloud_out));
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline void
-pcl::computeNDCentroid (const pcl::PointCloud<PointT> &cloud, 
-                        Eigen::Matrix<Scalar, Eigen::Dynamic, 1> &centroid)
+computeNDCentroid (const pcl::PointCloud<PointT> &cloud,
+                   Eigen::Matrix<Scalar, Eigen::Dynamic, 1> &centroid)
 {
   using FieldList = typename pcl::traits::fieldList<PointT>::type;
 
@@ -820,11 +822,11 @@ pcl::computeNDCentroid (const pcl::PointCloud<PointT> &cloud,
   centroid /= static_cast<Scalar> (cloud.size ());
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline void
-pcl::computeNDCentroid (const pcl::PointCloud<PointT> &cloud, 
-                        const std::vector<int> &indices,
-                        Eigen::Matrix<Scalar, Eigen::Dynamic, 1> &centroid)
+computeNDCentroid (const pcl::PointCloud<PointT> &cloud,
+                   const Indices &indices,
+                   Eigen::Matrix<Scalar, Eigen::Dynamic, 1> &centroid)
 {
   using FieldList = typename pcl::traits::fieldList<PointT>::type;
 
@@ -843,17 +845,17 @@ pcl::computeNDCentroid (const pcl::PointCloud<PointT> &cloud,
   centroid /= static_cast<Scalar> (indices.size ());
 }
 
-/////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT, typename Scalar> inline void
-pcl::computeNDCentroid (const pcl::PointCloud<PointT> &cloud,
-                        const pcl::PointIndices &indices, 
-                        Eigen::Matrix<Scalar, Eigen::Dynamic, 1> &centroid)
+computeNDCentroid (const pcl::PointCloud<PointT> &cloud,
+                   const pcl::PointIndices &indices,
+                   Eigen::Matrix<Scalar, Eigen::Dynamic, 1> &centroid)
 {
   return (pcl::computeNDCentroid (cloud, indices.indices, centroid));
 }
 
 template <typename PointT> void
-pcl::CentroidPoint<PointT>::add (const PointT& point)
+CentroidPoint<PointT>::add (const PointT& point)
 {
   // Invoke add point on each accumulator
   boost::fusion::for_each (accumulators_, detail::AddPoint<PointT> (point));
@@ -862,7 +864,7 @@ pcl::CentroidPoint<PointT>::add (const PointT& point)
 
 template <typename PointT>
 template <typename PointOutT> void
-pcl::CentroidPoint<PointT>::get (PointOutT& point) const
+CentroidPoint<PointT>::get (PointOutT& point) const
 {
   if (num_points_ != 0)
   {
@@ -874,8 +876,9 @@ pcl::CentroidPoint<PointT>::get (PointOutT& point) const
   }
 }
 
+
 template <typename PointInT, typename PointOutT> std::size_t
-pcl::computeCentroid (const pcl::PointCloud<PointInT>& cloud,
+computeCentroid (const pcl::PointCloud<PointInT>& cloud,
                       PointOutT& centroid)
 {
   pcl::CentroidPoint<PointInT> cp;
@@ -892,9 +895,10 @@ pcl::computeCentroid (const pcl::PointCloud<PointInT>& cloud,
   return (cp.getSize ());
 }
 
+
 template <typename PointInT, typename PointOutT> std::size_t
-pcl::computeCentroid (const pcl::PointCloud<PointInT>& cloud,
-                      const std::vector<int>& indices,
+computeCentroid (const pcl::PointCloud<PointInT>& cloud,
+                      const Indices& indices,
                       PointOutT& centroid)
 {
   pcl::CentroidPoint<PointInT> cp;
@@ -911,5 +915,5 @@ pcl::computeCentroid (const pcl::PointCloud<PointInT>& cloud,
   return (cp.getSize ());
 }
 
-#endif  //#ifndef PCL_COMMON_IMPL_CENTROID_H_
+} // namespace pcl
 
