@@ -40,6 +40,7 @@
 
 #include <pcl/point_types.h>
 #include <pcl/common/common.h>
+#include <cfloat> // for FLT_MAX
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 inline double
@@ -100,20 +101,20 @@ pcl::getMeanStd (const std::vector<float> &values, double &mean, double &stddev)
 template <typename PointT> inline void
 pcl::getPointsInBox (const pcl::PointCloud<PointT> &cloud, 
                      Eigen::Vector4f &min_pt, Eigen::Vector4f &max_pt,
-                     std::vector<int> &indices)
+                     Indices &indices)
 {
-  indices.resize (cloud.points.size ());
+  indices.resize (cloud.size ());
   int l = 0;
 
   // If the data is dense, we don't need to check for NaN
   if (cloud.is_dense)
   {
-    for (std::size_t i = 0; i < cloud.points.size (); ++i)
+    for (std::size_t i = 0; i < cloud.size (); ++i)
     {
       // Check if the point is inside bounds
-      if (cloud.points[i].x < min_pt[0] || cloud.points[i].y < min_pt[1] || cloud.points[i].z < min_pt[2])
+      if (cloud[i].x < min_pt[0] || cloud[i].y < min_pt[1] || cloud[i].z < min_pt[2])
         continue;
-      if (cloud.points[i].x > max_pt[0] || cloud.points[i].y > max_pt[1] || cloud.points[i].z > max_pt[2])
+      if (cloud[i].x > max_pt[0] || cloud[i].y > max_pt[1] || cloud[i].z > max_pt[2])
         continue;
       indices[l++] = int (i);
     }
@@ -121,17 +122,17 @@ pcl::getPointsInBox (const pcl::PointCloud<PointT> &cloud,
   // NaN or Inf values could exist => check for them
   else
   {
-    for (std::size_t i = 0; i < cloud.points.size (); ++i)
+    for (std::size_t i = 0; i < cloud.size (); ++i)
     {
       // Check if the point is invalid
-      if (!std::isfinite (cloud.points[i].x) || 
-          !std::isfinite (cloud.points[i].y) || 
-          !std::isfinite (cloud.points[i].z))
+      if (!std::isfinite (cloud[i].x) || 
+          !std::isfinite (cloud[i].y) || 
+          !std::isfinite (cloud[i].z))
         continue;
       // Check if the point is inside bounds
-      if (cloud.points[i].x < min_pt[0] || cloud.points[i].y < min_pt[1] || cloud.points[i].z < min_pt[2])
+      if (cloud[i].x < min_pt[0] || cloud[i].y < min_pt[1] || cloud[i].z < min_pt[2])
         continue;
-      if (cloud.points[i].x > max_pt[0] || cloud.points[i].y > max_pt[1] || cloud.points[i].z > max_pt[2])
+      if (cloud[i].x > max_pt[0] || cloud[i].y > max_pt[1] || cloud[i].z > max_pt[2])
         continue;
       indices[l++] = int (i);
     }
@@ -151,9 +152,9 @@ pcl::getMaxDistance (const pcl::PointCloud<PointT> &cloud, const Eigen::Vector4f
   // If the data is dense, we don't need to check for NaN
   if (cloud.is_dense)
   {
-    for (std::size_t i = 0; i < cloud.points.size (); ++i)
+    for (std::size_t i = 0; i < cloud.size (); ++i)
     {
-      pcl::Vector3fMapConst pt = cloud.points[i].getVector3fMap ();
+      pcl::Vector3fMapConst pt = cloud[i].getVector3fMap ();
       dist = (pivot_pt3 - pt).norm ();
       if (dist > max_dist)
       {
@@ -165,12 +166,12 @@ pcl::getMaxDistance (const pcl::PointCloud<PointT> &cloud, const Eigen::Vector4f
   // NaN or Inf values could exist => check for them
   else
   {
-    for (std::size_t i = 0; i < cloud.points.size (); ++i)
+    for (std::size_t i = 0; i < cloud.size (); ++i)
     {
       // Check if the point is invalid
-      if (!std::isfinite (cloud.points[i].x) || !std::isfinite (cloud.points[i].y) || !std::isfinite (cloud.points[i].z))
+      if (!std::isfinite (cloud[i].x) || !std::isfinite (cloud[i].y) || !std::isfinite (cloud[i].z))
         continue;
-      pcl::Vector3fMapConst pt = cloud.points[i].getVector3fMap ();
+      pcl::Vector3fMapConst pt = cloud[i].getVector3fMap ();
       dist = (pivot_pt3 - pt).norm ();
       if (dist > max_dist)
       {
@@ -181,14 +182,14 @@ pcl::getMaxDistance (const pcl::PointCloud<PointT> &cloud, const Eigen::Vector4f
   }
 
   if(max_idx != -1)
-    max_pt = cloud.points[max_idx].getVector4fMap ();
+    max_pt = cloud[max_idx].getVector4fMap ();
   else
     max_pt = Eigen::Vector4f(std::numeric_limits<float>::quiet_NaN(),std::numeric_limits<float>::quiet_NaN(),std::numeric_limits<float>::quiet_NaN(),std::numeric_limits<float>::quiet_NaN());
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 template<typename PointT> inline void
-pcl::getMaxDistance (const pcl::PointCloud<PointT> &cloud, const std::vector<int> &indices,
+pcl::getMaxDistance (const pcl::PointCloud<PointT> &cloud, const Indices &indices,
                      const Eigen::Vector4f &pivot_pt, Eigen::Vector4f &max_pt)
 {
   float max_dist = -FLT_MAX;
@@ -201,7 +202,7 @@ pcl::getMaxDistance (const pcl::PointCloud<PointT> &cloud, const std::vector<int
   {
     for (std::size_t i = 0; i < indices.size (); ++i)
     {
-      pcl::Vector3fMapConst pt = cloud.points[indices[i]].getVector3fMap ();
+      pcl::Vector3fMapConst pt = cloud[indices[i]].getVector3fMap ();
       dist = (pivot_pt3 - pt).norm ();
       if (dist > max_dist)
       {
@@ -216,12 +217,12 @@ pcl::getMaxDistance (const pcl::PointCloud<PointT> &cloud, const std::vector<int
     for (std::size_t i = 0; i < indices.size (); ++i)
     {
       // Check if the point is invalid
-      if (!std::isfinite (cloud.points[indices[i]].x) || !std::isfinite (cloud.points[indices[i]].y)
+      if (!std::isfinite (cloud[indices[i]].x) || !std::isfinite (cloud[indices[i]].y)
           ||
-          !std::isfinite (cloud.points[indices[i]].z))
+          !std::isfinite (cloud[indices[i]].z))
         continue;
 
-      pcl::Vector3fMapConst pt = cloud.points[indices[i]].getVector3fMap ();
+      pcl::Vector3fMapConst pt = cloud[indices[i]].getVector3fMap ();
       dist = (pivot_pt3 - pt).norm ();
       if (dist > max_dist)
       {
@@ -232,7 +233,7 @@ pcl::getMaxDistance (const pcl::PointCloud<PointT> &cloud, const std::vector<int
   }
 
   if(max_idx != -1)
-    max_pt = cloud.points[indices[max_idx]].getVector4fMap ();
+    max_pt = cloud[indices[max_idx]].getVector4fMap ();
   else
     max_pt = Eigen::Vector4f(std::numeric_limits<float>::quiet_NaN(),std::numeric_limits<float>::quiet_NaN(),std::numeric_limits<float>::quiet_NaN(),std::numeric_limits<float>::quiet_NaN());
 }
@@ -326,7 +327,7 @@ pcl::getMinMax3D (const pcl::PointCloud<PointT> &cloud, const pcl::PointIndices
   {
     for (const int &index : indices.indices)
     {
-      pcl::Array4fMapConst pt = cloud.points[index].getArray4fMap ();
+      pcl::Array4fMapConst pt = cloud[index].getArray4fMap ();
       min_p = min_p.min (pt);
       max_p = max_p.max (pt);
     }
@@ -337,11 +338,11 @@ pcl::getMinMax3D (const pcl::PointCloud<PointT> &cloud, const pcl::PointIndices
     for (const int &index : indices.indices)
     {
       // Check if the point is invalid
-      if (!std::isfinite (cloud.points[index].x) || 
-          !std::isfinite (cloud.points[index].y) || 
-          !std::isfinite (cloud.points[index].z))
+      if (!std::isfinite (cloud[index].x) || 
+          !std::isfinite (cloud[index].y) || 
+          !std::isfinite (cloud[index].z))
         continue;
-      pcl::Array4fMapConst pt = cloud.points[index].getArray4fMap ();
+      pcl::Array4fMapConst pt = cloud[index].getArray4fMap ();
       min_p = min_p.min (pt);
       max_p = max_p.max (pt);
     }
@@ -352,7 +353,7 @@ pcl::getMinMax3D (const pcl::PointCloud<PointT> &cloud, const pcl::PointIndices
 
 //////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointT> inline void
-pcl::getMinMax3D (const pcl::PointCloud<PointT> &cloud, const std::vector<int> &indices,
+pcl::getMinMax3D (const pcl::PointCloud<PointT> &cloud, const Indices &indices,
                   Eigen::Vector4f &min_pt, Eigen::Vector4f &max_pt)
 {
   min_pt.setConstant (FLT_MAX);
@@ -363,7 +364,7 @@ pcl::getMinMax3D (const pcl::PointCloud<PointT> &cloud, const std::vector<int> &
   {
     for (const int &index : indices)
     {
-      pcl::Array4fMapConst pt = cloud.points[index].getArray4fMap ();
+      pcl::Array4fMapConst pt = cloud[index].getArray4fMap ();
       min_pt = min_pt.array ().min (pt);
       max_pt = max_pt.array ().max (pt);
     }
@@ -374,11 +375,11 @@ pcl::getMinMax3D (const pcl::PointCloud<PointT> &cloud, const std::vector<int> &
     for (const int &index : indices)
     {
       // Check if the point is invalid
-      if (!std::isfinite (cloud.points[index].x) || 
-          !std::isfinite (cloud.points[index].y) || 
-          !std::isfinite (cloud.points[index].z))
+      if (!std::isfinite (cloud[index].x) || 
+          !std::isfinite (cloud[index].y) || 
+          !std::isfinite (cloud[index].z))
         continue;
-      pcl::Array4fMapConst pt = cloud.points[index].getArray4fMap ();
+      pcl::Array4fMapConst pt = cloud[index].getArray4fMap ();
       min_pt = min_pt.array ().min (pt);
       max_pt = max_pt.array ().max (pt);
     }
@@ -422,13 +423,12 @@ pcl::calculatePolygonArea (const pcl::PointCloud<PointT> &polygon)
 {
   float area = 0.0f;
   int num_points = polygon.size ();
-  int j = 0;
   Eigen::Vector3f va,vb,res;
 
   res(0) = res(1) = res(2) = 0.0f;
   for (int i = 0; i < num_points; ++i) 
   {
-    j = (i + 1) % num_points;
+    int j = (i + 1) % num_points;
     va = polygon[i].getVector3fMap ();
     vb = polygon[j].getVector3fMap ();
     res += va.cross (vb);
