@@ -4,7 +4,7 @@
  *  Point Cloud Library (PCL) - www.pointclouds.org
  *  Copyright (c) 2010-2011, Willow Garage, Inc.
  *
- *  All rights reserved. 
+ *  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -37,16 +37,19 @@
  *
  */
 
-#ifndef PCL_GAUSSIAN_KERNEL_IMPL
-#define PCL_GAUSSIAN_KERNEL_IMPL
+#pragma once
 
+#include <pcl/common/gaussian.h>
 #include <pcl/exceptions.h>
 
+namespace pcl
+{
+
 template <typename PointT> void
-pcl::GaussianKernel::convolveRows(const pcl::PointCloud<PointT> &input,
-                                  std::function <float (const PointT& p)> field_accessor,
-                                  const Eigen::VectorXf& kernel,
-                                  pcl::PointCloud<float> &output) const
+GaussianKernel::convolveRows(const pcl::PointCloud<PointT> &input,
+                             std::function <float (const PointT& p)> field_accessor,
+                             const Eigen::VectorXf& kernel,
+                             pcl::PointCloud<float> &output) const
 {
   assert(kernel.size () % 2 == 1);
   int kernel_width = kernel.size () -1;
@@ -76,10 +79,10 @@ pcl::GaussianKernel::convolveRows(const pcl::PointCloud<PointT> &input,
 }
 
 template <typename PointT> void
-pcl::GaussianKernel::convolveCols(const pcl::PointCloud<PointT> &input,
-                                  std::function <float (const PointT& p)> field_accessor,
-                                  const Eigen::VectorXf& kernel,
-                                  pcl::PointCloud<float> &output) const
+GaussianKernel::convolveCols(const pcl::PointCloud<PointT> &input,
+                             std::function <float (const PointT& p)> field_accessor,
+                             const Eigen::VectorXf& kernel,
+                             pcl::PointCloud<float> &output) const
 {
   assert(kernel.size () % 2 == 1);
   int kernel_width = kernel.size () -1;
@@ -110,4 +113,5 @@ pcl::GaussianKernel::convolveCols(const pcl::PointCloud<PointT> &input,
   }
 }
 
-#endif
+} // namespace pcl
+
