@@ -36,8 +36,6 @@
 
 #include <pcl/common/feature_histogram.h>
 
-#include <algorithm>
-
 #include <pcl/console/print.h>
 
 pcl::FeatureHistogram::FeatureHistogram (std::size_t const number_of_bins,
@@ -49,7 +47,7 @@ pcl::FeatureHistogram::FeatureHistogram (std::size_t const number_of_bins,
   {
     threshold_min_ = min;
     threshold_max_ = max;
-    step_ = (max - min) / static_cast<float> (number_of_bins_);
+    step_ = (max - min) / static_cast<float> (number_of_bins);
   }
   else
   {
