@@ -18,7 +18,6 @@
 #include <pcl/features/don.h>
 
 using namespace pcl;
-using namespace std;
 
 int
 main (int argc, char *argv[])
@@ -42,13 +41,13 @@ main (int argc, char *argv[])
   }
 
   /// the file to read from.
-  string infile = argv[1];
+  std::string infile = argv[1];
   /// small scale
-  istringstream (argv[2]) >> scale1;
+  std::istringstream (argv[2]) >> scale1;
   /// large scale
-  istringstream (argv[3]) >> scale2;
-  istringstream (argv[4]) >> threshold;   // threshold for DoN magnitude
-  istringstream (argv[5]) >> segradius;   // threshold for radius segmentation
+  std::istringstream (argv[3]) >> scale2;
+  std::istringstream (argv[4]) >> threshold;   // threshold for DoN magnitude
+  std::istringstream (argv[5]) >> segradius;   // threshold for radius segmentation
 
   // Load cloud in blob format
   pcl::PCLPointCloud2 blob;
@@ -148,7 +147,7 @@ main (int argc, char *argv[])
   doncloud = doncloud_filtered;
 
   // Save filtered output
-  std::cout << "Filtered Pointcloud: " << doncloud->points.size () << " data points." << std::endl;
+  std::cout << "Filtered Pointcloud: " << doncloud->size () << " data points." << std::endl;
 
   writer.write<pcl::PointNormal> ("don_filtered.pcd", *doncloud, false); 
 
@@ -174,16 +173,16 @@ main (int argc, char *argv[])
     pcl::PointCloud<PointNormal>::Ptr cloud_cluster_don (new pcl::PointCloud<PointNormal>);
     for (std::vector<int>::const_iterator pit = it->indices.begin (); pit != it->indices.end (); ++pit)
     {
-      cloud_cluster_don->points.push_back (doncloud->points[*pit]);
+      cloud_cluster_don->points.push_back ((*doncloud)[*pit]);
     }
 
-    cloud_cluster_don->width = int (cloud_cluster_don->points.size ());
+    cloud_cluster_don->width = cloud_cluster_don->size ();
     cloud_cluster_don->height = 1;
     cloud_cluster_don->is_dense = true;
 
     //Save cluster
-    std::cout << "PointCloud representing the Cluster: " << cloud_cluster_don->points.size () << " data points." << std::endl;
-    stringstream ss;
+    std::cout << "PointCloud representing the Cluster: " << cloud_cluster_don->size () << " data points." << std::endl;
+    std::stringstream ss;
     ss << "don_cluster_" << j << ".pcd";
     writer.write<pcl::PointNormal> (ss.str (), *cloud_cluster_don, false);
   }
