@@ -10,6 +10,7 @@
 #include <pcl/keypoints/narf_keypoint.h>
 #include <pcl/features/narf_descriptor.h>
 #include <pcl/console/parse.h>
+#include <pcl/common/file_io.h> // for getFilenameWithoutExtension
 
 typedef pcl::PointXYZ PointType;
 
@@ -123,7 +124,7 @@ main (int argc, char** argv)
         point_cloud.points.push_back (point);
       }
     }
-    point_cloud.width = (int) point_cloud.points.size ();  point_cloud.height = 1;
+    point_cloud.width = point_cloud.size ();  point_cloud.height = 1;
   }
   
   // -----------------------------------------------
@@ -171,23 +172,23 @@ main (int argc, char** argv)
   
   pcl::PointCloud<int> keypoint_indices;
   narf_keypoint_detector.compute (keypoint_indices);
-  std::cout << "Found "<<keypoint_indices.points.size ()<<" key points.\n";
+  std::cout << "Found "<<keypoint_indices.size ()<<" key points.\n";
 
   // ----------------------------------------------
   // -----Show keypoints in range image widget-----
   // ----------------------------------------------
-  //for (std::size_t i=0; i<keypoint_indices.points.size (); ++i)
-    //range_image_widget.markPoint (keypoint_indices.points[i]%range_image.width,
-                                  //keypoint_indices.points[i]/range_image.width);
+  //for (std::size_t i=0; i<keypoint_indices.size (); ++i)
+    //range_image_widget.markPoint (keypoint_indices[i]%range_image.width,
+                                  //keypoint_indices[i]/range_image.width);
   
   // -------------------------------------
   // -----Show keypoints in 3D viewer-----
   // -------------------------------------
   pcl::PointCloud<pcl::PointXYZ>::Ptr keypoints_ptr (new pcl::PointCloud<pcl::PointXYZ>);
   pcl::PointCloud<pcl::PointXYZ>& keypoints = *keypoints_ptr;
-  keypoints.points.resize (keypoint_indices.points.size ());
-  for (std::size_t i=0; i<keypoint_indices.points.size (); ++i)
-    keypoints.points[i].getVector3fMap () = range_image.points[keypoint_indices.points[i]].getVector3fMap ();
+  keypoints.resize (keypoint_indices.size ());
+  for (std::size_t i=0; i<keypoint_indices.size (); ++i)
+    keypoints[i].getVector3fMap () = range_image[keypoint_indices[i]].getVector3fMap ();
   pcl::visualization::PointCloudColorHandlerCustom<pcl::PointXYZ> keypoints_color_handler (keypoints_ptr, 0, 255, 0);
   viewer.addPointCloud<pcl::PointXYZ> (keypoints_ptr, keypoints_color_handler, "keypoints");
   viewer.setPointCloudRenderingProperties (pcl::visualization::PCL_VISUALIZER_POINT_SIZE, 7, "keypoints");
@@ -196,16 +197,16 @@ main (int argc, char** argv)
   // -----Extract NARF descriptors for interest points-----
   // ------------------------------------------------------
   std::vector<int> keypoint_indices2;
-  keypoint_indices2.resize (keypoint_indices.points.size ());
+  keypoint_indices2.resize (keypoint_indices.size ());
   for (unsigned int i=0; i<keypoint_indices.size (); ++i) // This step is necessary to get the right vector type
-    keypoint_indices2[i]=keypoint_indices.points[i];
+    keypoint_indices2[i]=keypoint_indices[i];
   pcl::NarfDescriptor narf_descriptor (&range_image, &keypoint_indices2);
   narf_descriptor.getParameters ().support_size = support_size;
   narf_descriptor.getParameters ().rotation_invariant = rotation_invariant;
   pcl::PointCloud<pcl::Narf36> narf_descriptors;
   narf_descriptor.compute (narf_descriptors);
   std::cout << "Extracted "<<narf_descriptors.size ()<<" descriptors for "
-                      <<keypoint_indices.points.size ()<< " keypoints.\n";
+                      <<keypoint_indices.size ()<< " keypoints.\n";
   
   //--------------------
   // -----Main loop-----
