@@ -13,18 +13,18 @@ int
   cloud->height = 1;
   cloud->points.resize (cloud->width * cloud->height);
 
-  for (std::size_t i = 0; i < cloud->points.size (); ++i)
+  for (auto& point: *cloud)
   {
-    cloud->points[i].x = 1024 * rand () / (RAND_MAX + 1.0f);
-    cloud->points[i].y = 1024 * rand () / (RAND_MAX + 1.0f);
-    cloud->points[i].z = 1024 * rand () / (RAND_MAX + 1.0f);
+    point.x = 1024 * rand () / (RAND_MAX + 1.0f);
+    point.y = 1024 * rand () / (RAND_MAX + 1.0f);
+    point.z = 1024 * rand () / (RAND_MAX + 1.0f);
   }
 
   std::cerr << "Cloud before filtering: " << std::endl;
-  for (std::size_t i = 0; i < cloud->points.size (); ++i)
-    std::cerr << "    " << cloud->points[i].x << " " 
-                        << cloud->points[i].y << " " 
-                        << cloud->points[i].z << std::endl;
+  for (const auto& point: *cloud)
+    std::cerr << "    " << point.x << " "
+                        << point.y << " "
+                        << point.z << std::endl;
 
   // Create the filtering object
   pcl::PassThrough<pcl::PointXYZ> pass;
@@ -35,10 +35,10 @@ int
   pass.filter (*cloud_filtered);
 
   std::cerr << "Cloud after filtering: " << std::endl;
-  for (std::size_t i = 0; i < cloud_filtered->points.size (); ++i)
-    std::cerr << "    " << cloud_filtered->points[i].x << " " 
-                        << cloud_filtered->points[i].y << " " 
-                        << cloud_filtered->points[i].z << std::endl;
+  for (const auto& point: *cloud_filtered)
+    std::cerr << "    " << point.x << " "
+                        << point.y << " "
+                        << point.z << std::endl;
 
   return (0);
 }
