@@ -16,10 +16,10 @@ main (int argc, char** argv)
             << cloud->width * cloud->height
             << " data points from test_pcd.pcd with the following fields: "
             << std::endl;
-  for (std::size_t i = 0; i < cloud->points.size (); ++i)
-    std::cout << "    " << cloud->points[i].x
-              << " "    << cloud->points[i].y
-              << " "    << cloud->points[i].z << std::endl;
+  for (const auto& point: *cloud)
+    std::cout << "    " << point.x
+              << " "    << point.y
+              << " "    << point.z << std::endl;
 
   return (0);
 }
