@@ -37,13 +37,10 @@
  *
  *
  */
-// STL
+
 #include <iostream>
 
-// PCL
 #include <pcl/io/pcd_io.h>
-#include <pcl/point_types.h>
-#include <pcl/common/io.h>
 #include <pcl/features/normal_3d.h>
 #include <pcl/features/rift.h>
 #include <pcl/features/intensity_gradient.h>
@@ -62,7 +59,7 @@ main (int, char** argv)
     return -1;
   }
 
-  std::cout << "points: " << cloud->points.size () << std::endl;
+  std::cout << "points: " << cloud->size () << std::endl;
 
   // Estimate the surface normals
   pcl::PointCloud<pcl::Normal>::Ptr cloud_n (new pcl::PointCloud<pcl::Normal>);
@@ -74,7 +71,7 @@ main (int, char** argv)
   norm_est.compute(*cloud_n);
 
   std::cout<<" Surface normals estimated";
-  std::cout<<" with size "<< cloud_n->points.size() <<std::endl;
+  std::cout<<" with size "<< cloud_n->size() <<std::endl;
  
   // Estimate the Intensity Gradient
   pcl::PointCloud<pcl::IntensityGradient>::Ptr cloud_ig (new pcl::PointCloud<pcl::IntensityGradient>);
@@ -86,7 +83,7 @@ main (int, char** argv)
   gradient_est.setRadiusSearch(0.25);
   gradient_est.compute(*cloud_ig);
   std::cout<<" Intensity Gradient estimated";
-  std::cout<<" with size "<< cloud_ig->points.size() <<std::endl;
+  std::cout<<" with size "<< cloud_ig->size() <<std::endl;
 
 
   // Estimate the RIFT feature
@@ -102,10 +99,9 @@ main (int, char** argv)
   rift_est.compute(rift_output);
 
   std::cout<<" RIFT feature estimated";
-  std::cout<<" with size "<<rift_output.points.size()<<std::endl;
+  std::cout<<" with size "<<rift_output.size()<<std::endl;
   
   // Display and retrieve the rift descriptor vector for the first point
-  pcl::Histogram<32> first_descriptor = rift_output.points[0];
-  std::cout << first_descriptor << std::endl;
+  std::cout << rift_output.front() << std::endl;
   return 0;
 }
