@@ -38,18 +38,12 @@
  *
  */
 
-// STL
 #include <iostream>
 
-// PCL
-#include <pcl/point_types.h>
 #include <pcl/io/pcd_io.h>
-#include <pcl/filters/extract_indices.h>
 #include <pcl/features/normal_3d.h>
-#include <pcl/kdtree/kdtree.h>
 #include <pcl/segmentation/extract_clusters.h>
 
-
 int 
 main (int, char **argv)
 {
@@ -62,7 +56,7 @@ main (int, char **argv)
     std::cout<<"Couldn't read the file "<<argv[1]<<std::endl;
     return (-1);
   }
-  std::cout << "Loaded pcd file " << argv[1] << " with " << cloud_ptr->points.size () << std::endl;
+  std::cout << "Loaded pcd file " << argv[1] << " with " << cloud_ptr->size () << std::endl;
 
   // Normal estimation
   pcl::NormalEstimation<pcl::PointXYZ, pcl::Normal> ne;
@@ -79,7 +73,6 @@ main (int, char **argv)
   tree_ec->setInputCloud (cloud_ptr);
   
   // Extracting Euclidean clusters using cloud and its normals
-  std::vector<int> indices;
   std::vector<pcl::PointIndices> cluster_indices;
   const float tolerance = 0.5f; // 50cm tolerance in (x, y, z) coordinate system
   const double eps_angle = 5 * (M_PI / 180.0); // 5degree tolerance in normals
@@ -95,12 +88,12 @@ main (int, char **argv)
   {
     pcl::PointCloud<pcl::PointXYZ>::Ptr cloud_cluster (new pcl::PointCloud<pcl::PointXYZ>);
     for (const int &index : it->indices)
-      cloud_cluster->points.push_back (cloud_ptr->points[index]); 
-    cloud_cluster->width = static_cast<std::uint32_t> (cloud_cluster->points.size ());
+      cloud_cluster->push_back ((*cloud_ptr)[index]); 
+    cloud_cluster->width = cloud_cluster->size ();
     cloud_cluster->height = 1;
     cloud_cluster->is_dense = true;
 
-    std::cout << "PointCloud representing the Cluster using xyzn: " << cloud_cluster->points.size () << " data points." << std::endl;
+    std::cout << "PointCloud representing the Cluster using xyzn: " << cloud_cluster->size () << " data " << std::endl;
     std::stringstream ss;
     ss << "./cloud_cluster_" << j << ".pcd";
     writer.write<pcl::PointXYZ> (ss.str (), *cloud_cluster, false); 
