@@ -38,11 +38,15 @@
  *
  */
 
-#ifndef PCL_FEATURES_IMPL_FPFH_OMP_H_
-#define PCL_FEATURES_IMPL_FPFH_OMP_H_
+#pragma once
 
 #include <pcl/features/fpfh_omp.h>
 
+#include <pcl/common/point_tests.h> // for pcl::isFinite
+
+#include <numeric>
+
+
 //////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointInT, typename PointNT, typename PointOutT> void
 pcl::FPFHEstimationOMP<PointInT, PointNT, PointOutT>::setNumberOfThreads (unsigned int nr_threads)
@@ -62,12 +66,12 @@ template <typename PointInT, typename PointNT, typename PointOutT> void
 pcl::FPFHEstimationOMP<PointInT, PointNT, PointOutT>::computeFeature (PointCloudOut &output)
 {
   std::vector<int> spfh_indices_vec;
-  std::vector<int> spfh_hist_lookup (surface_->points.size ());
+  std::vector<int> spfh_hist_lookup (surface_->size ());
 
   // Build a list of (unique) indices for which we will need to compute SPFH signatures
   // (We need an SPFH signature for every point that is a neighbor of any point in input_[indices_])
   if (surface_ != input_ ||
-      indices_->size () != surface_->points.size ())
+      indices_->size () != surface_->size ())
   { 
     std::vector<int> nn_indices (k_); // \note These resizes are irrelevant for a radiusSearch ().
     std::vector<float> nn_dists (k_); 
@@ -83,14 +87,14 @@ pcl::FPFHEstimationOMP<PointInT, PointNT, PointOutT>::computeFeature (PointCloud
       spfh_indices_set.insert (nn_indices.begin (), nn_indices.end ());
     }
     spfh_indices_vec.resize (spfh_indices_set.size ());
-    std::copy (spfh_indices_set.begin (), spfh_indices_set.end (), spfh_indices_vec.begin ());
+    std::copy (spfh_indices_set.cbegin (), spfh_indices_set.cend (), spfh_indices_vec.begin ());
   }
   else
   {
     // Special case: When a feature must be computed at every point, there is no need for a neighborhood search
     spfh_indices_vec.resize (indices_->size ());
-    for (int idx = 0; idx < static_cast<int> (indices_->size ()); ++idx)
-      spfh_indices_vec[idx] = idx;
+    std::iota(spfh_indices_vec.begin (), spfh_indices_vec.end (),
+              static_cast<decltype(spfh_indices_vec)::value_type>(0));
   }
 
   // Initialize the arrays that will store the SPFH signatures
@@ -104,9 +108,11 @@ pcl::FPFHEstimationOMP<PointInT, PointNT, PointOutT>::computeFeature (PointCloud
 
   // Compute SPFH signatures for every point that needs them
 
-#ifdef _OPENMP
-#pragma omp parallel for shared (spfh_hist_lookup) private (nn_indices, nn_dists) num_threads(threads_)
-#endif
+#pragma omp parallel for \
+  default(none) \
+  shared(spfh_hist_lookup, spfh_indices_vec) \
+  firstprivate(nn_indices, nn_dists) \
+  num_threads(threads_)
   for (std::ptrdiff_t i = 0; i < static_cast<std::ptrdiff_t> (spfh_indices_vec.size ()); ++i)
   {
     // Get the next point index
@@ -131,9 +137,11 @@ pcl::FPFHEstimationOMP<PointInT, PointNT, PointOutT>::computeFeature (PointCloud
   nn_dists.clear();
 
   // Iterate over the entire index vector
-#ifdef _OPENMP
-#pragma omp parallel for shared (output) private (nn_indices, nn_dists) num_threads(threads_)
-#endif
+#pragma omp parallel for \
+  default(none) \
+  shared(nr_bins, output, spfh_hist_lookup) \
+  firstprivate(nn_dists, nn_indices) \
+  num_threads(threads_)
   for (std::ptrdiff_t idx = 0; idx < static_cast<std::ptrdiff_t> (indices_->size ()); ++idx)
   {
     // Find the indices of point idx's neighbors...
@@ -141,7 +149,7 @@ pcl::FPFHEstimationOMP<PointInT, PointNT, PointOutT>::computeFeature (PointCloud
         this->searchForNeighbors ((*indices_)[idx], search_parameter_, nn_indices, nn_dists) == 0)
     {
       for (int d = 0; d < nr_bins; ++d)
-        output.points[idx].histogram[d] = std::numeric_limits<float>::quiet_NaN ();
+        output[idx].histogram[d] = std::numeric_limits<float>::quiet_NaN ();
 
       output.is_dense = false;
       continue;
@@ -159,12 +167,10 @@ pcl::FPFHEstimationOMP<PointInT, PointNT, PointOutT>::computeFeature (PointCloud
 
     // ...and copy it into the output cloud
     for (int d = 0; d < nr_bins; ++d)
-      output.points[idx].histogram[d] = fpfh_histogram[d];
+      output[idx].histogram[d] = fpfh_histogram[d];
   }
 
 }
 
 #define PCL_INSTANTIATE_FPFHEstimationOMP(T,NT,OutT) template class PCL_EXPORTS pcl::FPFHEstimationOMP<T,NT,OutT>;
 
-#endif    // PCL_FEATURES_IMPL_FPFH_OMP_H_ 
-
