@@ -41,7 +41,6 @@
 
 #include <pcl/features/gasd.h>
 #include <pcl/common/transforms.h>
-#include <pcl/point_types_conversion.h>
 
 #include <vector>
 
@@ -240,7 +239,7 @@ pcl::GASDEstimation<PointInT, PointOutT>::copyShapeHistogramsToOutput (const std
       {
         const std::size_t idx = ( (i + 1) * (grid_size + 2) + (j + 1)) * (grid_size + 2) + (k + 1);
 
-        std::copy (hists[idx].data () + 1, hists[idx].data () + hists_size + 1, output.points[0].histogram + pos);
+        std::copy (hists[idx].data () + 1, hists[idx].data () + hists_size + 1, output[0].histogram + pos);
         pos += hists_size;
       }
     }
@@ -281,10 +280,10 @@ pcl::GASDEstimation<PointInT, PointOutT>::computeFeature (PointCloudOut &output)
   hist_incr_ = 100.0f / static_cast<float> (shape_samples_.size () - 1);
 
   // for each sample
-  for (std::size_t i = 0; i < shape_samples_.size (); ++i)
+  for (const auto& sample: shape_samples_)
   {
     // compute shape histogram array coord based on distance between sample and centroid
-    const Eigen::Vector4f p (shape_samples_[i].x, shape_samples_[i].y, shape_samples_[i].z, 0.0f);
+    const Eigen::Vector4f p (sample.x, sample.y, sample.z, 0.0f);
     const float d = p.norm ();
 
     const float shape_grid_step = distance_normalization_factor / shape_half_grid_size_;
@@ -304,7 +303,7 @@ pcl::GASDEstimation<PointInT, PointOutT>::computeFeature (PointCloudOut &output)
   copyShapeHistogramsToOutput (shape_grid_size, shape_hists_size_, shape_hists, output, pos_);
 
   // set remaining values of the descriptor to zero (if any)
-  std::fill (output.points[0].histogram + pos_, output.points[0].histogram + output.points[0].descriptorSize (), 0.0f);
+  std::fill (output[0].histogram + pos_, output[0].histogram + output[0].descriptorSize (), 0.0f);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////
@@ -326,7 +325,7 @@ pcl::GASDColorEstimation<PointInT, PointOutT>::copyColorHistogramsToOutput (cons
         hists[idx][1] += hists[idx][hists_size + 1];
         hists[idx][hists_size] += hists[idx][0];
 
-        std::copy (hists[idx].data () + 1, hists[idx].data () + hists_size + 1, output.points[0].histogram + pos);
+        std::copy (hists[idx].data () + 1, hists[idx].data () + hists_size + 1, output[0].histogram + pos);
         pos += hists_size;
       }
     }
@@ -347,32 +346,32 @@ pcl::GASDColorEstimation<PointInT, PointOutT>::computeFeature (PointCloudOut &ou
                                              Eigen::VectorXf::Zero (color_hists_size_ + 2));
 
   // for each sample
-  for (std::size_t i = 0; i < shape_samples_.size (); ++i)
+  for (const auto& sample: shape_samples_)
   {
     // compute shape histogram array coord based on distance between sample and centroid
-    const Eigen::Vector4f p (shape_samples_[i].x, shape_samples_[i].y, shape_samples_[i].z, 0.0f);
+    const Eigen::Vector4f p (sample.x, sample.y, sample.z, 0.0f);
 
     // compute hue value
     float hue = 0.f;
 
-    const unsigned char max = std::max (shape_samples_[i].r, std::max (shape_samples_[i].g, shape_samples_[i].b));
-    const unsigned char min = std::min (shape_samples_[i].r, std::min (shape_samples_[i].g, shape_samples_[i].b));
+    const unsigned char max = std::max (sample.r, std::max (sample.g, sample.b));
+    const unsigned char min = std::min (sample.r, std::min (sample.g, sample.b));
 
     const float diff_inv = 1.f / static_cast <float> (max - min);
 
     if (std::isfinite (diff_inv))
     {
-      if (max == shape_samples_[i].r)
+      if (max == sample.r)
       {
-        hue = 60.f * (static_cast <float> (shape_samples_[i].g - shape_samples_[i].b) * diff_inv);
+        hue = 60.f * (static_cast <float> (sample.g - sample.b) * diff_inv);
       }
-      else if (max == shape_samples_[i].g)
+      else if (max == sample.g)
       {
-        hue = 60.f * (2.f + static_cast <float> (shape_samples_[i].b - shape_samples_[i].r) * diff_inv);
+        hue = 60.f * (2.f + static_cast <float> (sample.b - sample.r) * diff_inv);
       }
       else
       {
-        hue = 60.f * (4.f + static_cast <float> (shape_samples_[i].r - shape_samples_[i].g) * diff_inv); // max == b
+        hue = 60.f * (4.f + static_cast <float> (sample.r - sample.g) * diff_inv); // max == b
       }
 
       if (hue < 0.f)
@@ -392,7 +391,7 @@ pcl::GASDColorEstimation<PointInT, PointOutT>::computeFeature (PointCloudOut &ou
   copyColorHistogramsToOutput (color_grid_size, color_hists_size_, color_hists, output, pos_);
 
   // set remaining values of the descriptor to zero (if any)
-  std::fill (output.points[0].histogram + pos_, output.points[0].histogram + output.points[0].descriptorSize (), 0.0f);
+  std::fill (output[0].histogram + pos_, output[0].histogram + output[0].descriptorSize (), 0.0f);
 }
 
 #define PCL_INSTANTIATE_GASDEstimation(InT, OutT) template class PCL_EXPORTS pcl::GASDEstimation<InT, OutT>;
