@@ -41,6 +41,7 @@
 #define PCL_MOMENT_OF_INERTIA_ESTIMATION_HPP_
 
 #include <pcl/features/moment_of_inertia_estimation.h>
+#include <pcl/features/feature.h>
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointT>
@@ -232,15 +233,15 @@ pcl::MomentOfInertiaEstimation<PointT>::computeOBB ()
   unsigned int number_of_points = static_cast <unsigned int> (indices_->size ());
   for (unsigned int i_point = 0; i_point < number_of_points; i_point++)
   {
-    float x = (input_->points[(*indices_)[i_point]].x - mean_value_ (0)) * major_axis_ (0) +
-              (input_->points[(*indices_)[i_point]].y - mean_value_ (1)) * major_axis_ (1) +
-              (input_->points[(*indices_)[i_point]].z - mean_value_ (2)) * major_axis_ (2);
-    float y = (input_->points[(*indices_)[i_point]].x - mean_value_ (0)) * middle_axis_ (0) +
-              (input_->points[(*indices_)[i_point]].y - mean_value_ (1)) * middle_axis_ (1) +
-              (input_->points[(*indices_)[i_point]].z - mean_value_ (2)) * middle_axis_ (2);
-    float z = (input_->points[(*indices_)[i_point]].x - mean_value_ (0)) * minor_axis_ (0) +
-              (input_->points[(*indices_)[i_point]].y - mean_value_ (1)) * minor_axis_ (1) +
-              (input_->points[(*indices_)[i_point]].z - mean_value_ (2)) * minor_axis_ (2);
+    float x = ((*input_)[(*indices_)[i_point]].x - mean_value_ (0)) * major_axis_ (0) +
+              ((*input_)[(*indices_)[i_point]].y - mean_value_ (1)) * major_axis_ (1) +
+              ((*input_)[(*indices_)[i_point]].z - mean_value_ (2)) * major_axis_ (2);
+    float y = ((*input_)[(*indices_)[i_point]].x - mean_value_ (0)) * middle_axis_ (0) +
+              ((*input_)[(*indices_)[i_point]].y - mean_value_ (1)) * middle_axis_ (1) +
+              ((*input_)[(*indices_)[i_point]].z - mean_value_ (2)) * middle_axis_ (2);
+    float z = ((*input_)[(*indices_)[i_point]].x - mean_value_ (0)) * minor_axis_ (0) +
+              ((*input_)[(*indices_)[i_point]].y - mean_value_ (1)) * minor_axis_ (1) +
+              ((*input_)[(*indices_)[i_point]].z - mean_value_ (2)) * minor_axis_ (2);
 
     if (x <= obb_min_point_.x) obb_min_point_.x = x;
     if (y <= obb_min_point_.y) obb_min_point_.y = y;
@@ -332,17 +333,17 @@ pcl::MomentOfInertiaEstimation<PointT>::computeMeanValue ()
   unsigned int number_of_points = static_cast <unsigned int> (indices_->size ());
   for (unsigned int i_point = 0; i_point < number_of_points; i_point++)
   {
-    mean_value_ (0) += input_->points[(*indices_)[i_point]].x;
-    mean_value_ (1) += input_->points[(*indices_)[i_point]].y;
-    mean_value_ (2) += input_->points[(*indices_)[i_point]].z;
+    mean_value_ (0) += (*input_)[(*indices_)[i_point]].x;
+    mean_value_ (1) += (*input_)[(*indices_)[i_point]].y;
+    mean_value_ (2) += (*input_)[(*indices_)[i_point]].z;
 
-    if (input_->points[(*indices_)[i_point]].x <= aabb_min_point_.x) aabb_min_point_.x = input_->points[(*indices_)[i_point]].x;
-    if (input_->points[(*indices_)[i_point]].y <= aabb_min_point_.y) aabb_min_point_.y = input_->points[(*indices_)[i_point]].y;
-    if (input_->points[(*indices_)[i_point]].z <= aabb_min_point_.z) aabb_min_point_.z = input_->points[(*indices_)[i_point]].z;
+    if ((*input_)[(*indices_)[i_point]].x <= aabb_min_point_.x) aabb_min_point_.x = (*input_)[(*indices_)[i_point]].x;
+    if ((*input_)[(*indices_)[i_point]].y <= aabb_min_point_.y) aabb_min_point_.y = (*input_)[(*indices_)[i_point]].y;
+    if ((*input_)[(*indices_)[i_point]].z <= aabb_min_point_.z) aabb_min_point_.z = (*input_)[(*indices_)[i_point]].z;
 
-    if (input_->points[(*indices_)[i_point]].x >= aabb_max_point_.x) aabb_max_point_.x = input_->points[(*indices_)[i_point]].x;
-    if (input_->points[(*indices_)[i_point]].y >= aabb_max_point_.y) aabb_max_point_.y = input_->points[(*indices_)[i_point]].y;
-    if (input_->points[(*indices_)[i_point]].z >= aabb_max_point_.z) aabb_max_point_.z = input_->points[(*indices_)[i_point]].z;
+    if ((*input_)[(*indices_)[i_point]].x >= aabb_max_point_.x) aabb_max_point_.x = (*input_)[(*indices_)[i_point]].x;
+    if ((*input_)[(*indices_)[i_point]].y >= aabb_max_point_.y) aabb_max_point_.y = (*input_)[(*indices_)[i_point]].y;
+    if ((*input_)[(*indices_)[i_point]].z >= aabb_max_point_.z) aabb_max_point_.z = (*input_)[(*indices_)[i_point]].z;
   }
 
   if (number_of_points == 0)
@@ -364,9 +365,9 @@ pcl::MomentOfInertiaEstimation<PointT>::computeCovarianceMatrix (Eigen::Matrix <
   for (unsigned int i_point = 0; i_point < number_of_points; i_point++)
   {
     Eigen::Vector3f current_point (0.0f, 0.0f, 0.0f);
-    current_point (0) = input_->points[(*indices_)[i_point]].x - mean_value_ (0);
-    current_point (1) = input_->points[(*indices_)[i_point]].y - mean_value_ (1);
-    current_point (2) = input_->points[(*indices_)[i_point]].z - mean_value_ (2);
+    current_point (0) = (*input_)[(*indices_)[i_point]].x - mean_value_ (0);
+    current_point (1) = (*input_)[(*indices_)[i_point]].y - mean_value_ (1);
+    current_point (2) = (*input_)[(*indices_)[i_point]].z - mean_value_ (2);
 
     covariance_matrix += current_point * current_point.transpose ();
   }
@@ -380,14 +381,14 @@ pcl::MomentOfInertiaEstimation<PointT>::computeCovarianceMatrix (PointCloudConst
 {
   covariance_matrix.setZero ();
 
-  unsigned int number_of_points = static_cast <unsigned int> (cloud->points.size ());
+  const auto number_of_points = cloud->size ();
   float factor = 1.0f / static_cast <float> ((number_of_points - 1 > 0)?(number_of_points - 1):1);
   Eigen::Vector3f current_point;
   for (unsigned int i_point = 0; i_point < number_of_points; i_point++)
   {
-    current_point (0) = cloud->points[i_point].x - mean_value_ (0);
-    current_point (1) = cloud->points[i_point].y - mean_value_ (1);
-    current_point (2) = cloud->points[i_point].z - mean_value_ (2);
+    current_point (0) = (*cloud)[i_point].x - mean_value_ (0);
+    current_point (1) = (*cloud)[i_point].y - mean_value_ (1);
+    current_point (2) = (*cloud)[i_point].z - mean_value_ (2);
 
     covariance_matrix += current_point * current_point.transpose ();
   }
@@ -483,9 +484,9 @@ pcl::MomentOfInertiaEstimation<PointT>::calculateMomentOfInertia (const Eigen::V
   for (unsigned int i_point = 0; i_point < number_of_points; i_point++)
   {
     Eigen::Vector3f vector;
-    vector (0) = mean_value (0) - input_->points[(*indices_)[i_point]].x;
-    vector (1) = mean_value (1) - input_->points[(*indices_)[i_point]].y;
-    vector (2) = mean_value (2) - input_->points[(*indices_)[i_point]].z;
+    vector (0) = mean_value (0) - (*input_)[(*indices_)[i_point]].x;
+    vector (1) = mean_value (1) - (*input_)[(*indices_)[i_point]].y;
+    vector (2) = mean_value (2) - (*input_)[(*indices_)[i_point]].z;
 
     Eigen::Vector3f product = vector.cross (current_axis);
 
@@ -509,12 +510,12 @@ pcl::MomentOfInertiaEstimation<PointT>::getProjectedCloud (const Eigen::Vector3f
   for (unsigned int i_point = 0; i_point < number_of_points; i_point++)
   {
     const unsigned int index = (*indices_)[i_point];
-    float K = - (D + normal_vector (0) * input_->points[index].x + normal_vector (1) * input_->points[index].y + normal_vector (2) * input_->points[index].z);
+    float K = - (D + normal_vector (0) * (*input_)[index].x + normal_vector (1) * (*input_)[index].y + normal_vector (2) * (*input_)[index].z);
     PointT projected_point;
-    projected_point.x = input_->points[index].x + K * normal_vector (0);
-    projected_point.y = input_->points[index].y + K * normal_vector (1);
-    projected_point.z = input_->points[index].z + K * normal_vector (2);
-    projected_cloud->points[i_point] = projected_point;
+    projected_point.x = (*input_)[index].x + K * normal_vector (0);
+    projected_point.y = (*input_)[index].y + K * normal_vector (1);
+    projected_point.z = (*input_)[index].z + K * normal_vector (2);
+    (*projected_cloud)[i_point] = projected_point;
   }
   projected_cloud->width = number_of_points;
   projected_cloud->height = 1;
