@@ -152,13 +152,13 @@ pcl::ROPSEstimation <PointInT, PointOutT>::computeFeature (PointCloudOut &output
   {
     std::set <unsigned int> local_triangles;
     std::vector <int> local_points;
-    getLocalSurface (input_->points[idx], local_triangles, local_points);
+    getLocalSurface ((*input_)[idx], local_triangles, local_points);
 
     Eigen::Matrix3f lrf_matrix;
-    computeLRF (input_->points[idx], local_triangles, lrf_matrix);
+    computeLRF ((*input_)[idx], local_triangles, lrf_matrix);
 
     PointCloudIn transformed_cloud;
-    transformCloud (input_->points[idx], lrf_matrix, local_points, transformed_cloud);
+    transformCloud ((*input_)[idx], lrf_matrix, local_points, transformed_cloud);
 
     std::array<PointInT, 3> axes;
     axes[0].x = 1.0f; axes[0].y = 0.0f; axes[0].z = 0.0f;
@@ -193,17 +193,19 @@ pcl::ROPSEstimation <PointInT, PointOutT>::computeFeature (PointCloudOut &output
       } while (theta < 90.0f);
     }
 
-    float norm = 0.0f;
-    for (std::size_t i_dim = 0; i_dim < feature_size; i_dim++)
-      norm += std::abs (feature[i_dim]);
+    const float norm = std::accumulate(
+        feature.cbegin(), feature.cend(), 0.f, [](const auto& sum, const auto& val) {
+          return sum + std::abs(val);
+        });
+    float invert_norm;
     if (norm < std::numeric_limits <float>::epsilon ())
-      norm = 1.0f;
+      invert_norm = 1.0f;
     else
-      norm = 1.0f / norm;
+      invert_norm = 1.0f / norm;
 
     output.points.emplace_back ();
     for (std::size_t i_dim = 0; i_dim < feature_size; i_dim++)
-      output.points.back ().histogram[i_dim] = feature[i_dim] * norm;
+      output.points.back().histogram[i_dim] = feature[i_dim] * invert_norm;
   }
 }
 
@@ -259,9 +261,9 @@ pcl::ROPSEstimation <PointInT, PointOutT>::computeLRF (const PointInT& point, co
     for (unsigned int i_vertex = 0; i_vertex < 3; i_vertex++)
     {
       const unsigned int index = triangles_[triangle].vertices[i_vertex];
-      pt[i_vertex] (0) = surface_->points[index].x;
-      pt[i_vertex] (1) = surface_->points[index].y;
-      pt[i_vertex] (2) = surface_->points[index].z;
+      pt[i_vertex] (0) = (*surface_)[index].x;
+      pt[i_vertex] (1) = (*surface_)[index].y;
+      pt[i_vertex] (2) = (*surface_)[index].z;
     }
 
     const float curr_area = ((pt[1] - pt[0]).cross (pt[2] - pt[0])).norm ();
@@ -310,9 +312,9 @@ pcl::ROPSEstimation <PointInT, PointOutT>::computeLRF (const PointInT& point, co
     for (unsigned int i_vertex = 0; i_vertex < 3; i_vertex++)
     {
       const unsigned int index = triangles_[triangle].vertices[i_vertex];
-      pt[i_vertex] (0) = surface_->points[index].x;
-      pt[i_vertex] (1) = surface_->points[index].y;
-      pt[i_vertex] (2) = surface_->points[index].z;
+      pt[i_vertex] (0) = (*surface_)[index].x;
+      pt[i_vertex] (1) = (*surface_)[index].y;
+      pt[i_vertex] (2) = (*surface_)[index].z;
     }
 
     float factor1 = 0.0f;
@@ -392,9 +394,9 @@ pcl::ROPSEstimation <PointInT, PointOutT>::transformCloud (const PointInT& point
 
   for (const auto& idx: local_points)
   {
-    Eigen::Vector3f transformed_point (surface_->points[idx].x - point.x,
-                                       surface_->points[idx].y - point.y,
-                                       surface_->points[idx].z - point.z);
+    Eigen::Vector3f transformed_point ((*surface_)[idx].x - point.x,
+                                       (*surface_)[idx].y - point.y,
+                                       (*surface_)[idx].z - point.z);
 
     transformed_point = matrix * transformed_point;
 
@@ -421,7 +423,7 @@ pcl::ROPSEstimation <PointInT, PointOutT>::rotateCloud (const PointInT& axis, co
                      (1 - cosine) * y * x + sine * z,    cosine + (1 - cosine) * y * y,      (1 - cosine) * y * z - sine * x,
                      (1 - cosine) * z * x - sine * y,    (1 - cosine) * z * y + sine * x,    cosine + (1 - cosine) * z * z;
 
-  const auto number_of_points = cloud.points.size ();
+  const auto number_of_points = cloud.size ();
 
   rotated_cloud.header = cloud.header;
   rotated_cloud.width = number_of_points;
@@ -447,13 +449,11 @@ pcl::ROPSEstimation <PointInT, PointOutT>::rotateCloud (const PointInT& axis, co
     rotated_point.z = point (2);
     rotated_cloud.points.emplace_back (rotated_point);
 
-    if (min (0) > rotated_point.x) min (0) = rotated_point.x;
-    if (min (1) > rotated_point.y) min (1) = rotated_point.y;
-    if (min (2) > rotated_point.z) min (2) = rotated_point.z;
-
-    if (max (0) < rotated_point.x) max (0) = rotated_point.x;
-    if (max (1) < rotated_point.y) max (1) = rotated_point.y;
-    if (max (2) < rotated_point.z) max (2) = rotated_point.z;
+    for (int i = 0; i < 3; ++i)
+    {
+      min(i) = std::min(min(i), point(i));
+      max(i) = std::max(max(i), point(i));
+    }
   }
 }
 
@@ -489,7 +489,7 @@ pcl::ROPSEstimation <PointInT, PointOutT>::getDistributionMatrix (const unsigned
     matrix (row, col) += 1.0f;
   }
 
-  matrix /= static_cast <float> (std::min<std::size_t> (1, cloud.points.size ()));
+  matrix /= std::max<float> (1, cloud.size ());
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////////
