@@ -42,7 +42,6 @@
 
 #include <pcl/features/shot.h>
 #include <pcl/features/shot_lrf.h>
-#include <utility>
 
 // Useful constants.
 #define PST_PI 3.1415926535897932384626433832795
@@ -199,7 +198,7 @@ pcl::SHOTEstimationBase<PointInT, PointNT, PointOutT, PointRFT>::createBinDistan
 {
   bin_distance_shape.resize (indices.size ());
 
-  const PointRFT& current_frame = frames_->points[index];
+  const PointRFT& current_frame = (*frames_)[index];
   //if (!std::isfinite (current_frame.rf[0]) || !std::isfinite (current_frame.rf[4]) || !std::isfinite (current_frame.rf[11]))
     //return;
 
@@ -209,7 +208,7 @@ pcl::SHOTEstimationBase<PointInT, PointNT, PointOutT, PointRFT>::createBinDistan
   for (std::size_t i_idx = 0; i_idx < indices.size (); ++i_idx)
   {
     // check NaN normal
-    const Eigen::Vector4f& normal_vec = normals_->points[indices[i_idx]].getNormalVector4fMap ();
+    const Eigen::Vector4f& normal_vec = (*normals_)[indices[i_idx]].getNormalVector4fMap ();
     if (!std::isfinite (normal_vec[0]) ||
         !std::isfinite (normal_vec[1]) ||
         !std::isfinite (normal_vec[2]))
@@ -273,7 +272,7 @@ pcl::SHOTEstimationBase<PointInT, PointNT, PointOutT, PointRFT>::interpolateSing
     if (!std::isfinite(binDistance[i_idx]))
       continue;
 
-    Eigen::Vector4f delta = surface_->points[indices[i_idx]].getVector4fMap () - central_point;
+    Eigen::Vector4f delta = (*surface_)[indices[i_idx]].getVector4fMap () - central_point;
     delta[3] = 0;
 
     // Compute the Euclidean norm
@@ -452,7 +451,7 @@ pcl::SHOTColorEstimation<PointInT, PointNT, PointOutT, PointRFT>::interpolateDou
     if (!std::isfinite(binDistanceShape[i_idx]))
       continue;
 
-    Eigen::Vector4f delta = surface_->points[indices[i_idx]].getVector4fMap () - central_point;
+    Eigen::Vector4f delta = (*surface_)[indices[i_idx]].getVector4fMap () - central_point;
     delta[3] = 0;
 
     // Compute the Euclidean norm
@@ -674,12 +673,12 @@ pcl::SHOTColorEstimation<PointInT, PointNT, PointOutT, PointRFT>::computePointSH
   {
     binDistanceColor.reserve (nNeighbors);
 
-    //unsigned char redRef = input_->points[(*indices_)[index]].rgba >> 16 & 0xFF;
-    //unsigned char greenRef = input_->points[(*indices_)[index]].rgba >> 8& 0xFF;
-    //unsigned char blueRef = input_->points[(*indices_)[index]].rgba & 0xFF;
-    unsigned char redRef = input_->points[(*indices_)[index]].r;
-    unsigned char greenRef = input_->points[(*indices_)[index]].g;
-    unsigned char blueRef = input_->points[(*indices_)[index]].b;
+    //unsigned char redRef = (*input_)[(*indices_)[index]].rgba >> 16 & 0xFF;
+    //unsigned char greenRef = (*input_)[(*indices_)[index]].rgba >> 8& 0xFF;
+    //unsigned char blueRef = (*input_)[(*indices_)[index]].rgba & 0xFF;
+    unsigned char redRef = (*input_)[(*indices_)[index]].r;
+    unsigned char greenRef = (*input_)[(*indices_)[index]].g;
+    unsigned char blueRef = (*input_)[(*indices_)[index]].b;
 
     float LRef, aRef, bRef;
 
@@ -690,9 +689,9 @@ pcl::SHOTColorEstimation<PointInT, PointNT, PointOutT, PointRFT>::computePointSH
 
     for (const auto& idx: indices)
     {
-      unsigned char red = surface_->points[idx].r;
-      unsigned char green = surface_->points[idx].g;
-      unsigned char blue = surface_->points[idx].b;
+      unsigned char red = (*surface_)[idx].r;
+      unsigned char green = (*surface_)[idx].g;
+      unsigned char blue = (*surface_)[idx].b;
 
       float L, a, b;
 
@@ -798,9 +797,9 @@ pcl::SHOTEstimation<PointInT, PointNT, PointOutT, PointRFT>::computeFeature (pcl
     {
       // Copy into the resultant cloud
       for (int d = 0; d < descLength_; ++d)
-        output.points[idx].descriptor[d] = std::numeric_limits<float>::quiet_NaN ();
+        output[idx].descriptor[d] = std::numeric_limits<float>::quiet_NaN ();
       for (int d = 0; d < 9; ++d)
-        output.points[idx].rf[d] = std::numeric_limits<float>::quiet_NaN ();
+        output[idx].rf[d] = std::numeric_limits<float>::quiet_NaN ();
 
       output.is_dense = false;
       continue;
@@ -811,12 +810,12 @@ pcl::SHOTEstimation<PointInT, PointNT, PointOutT, PointRFT>::computeFeature (pcl
 
     // Copy into the resultant cloud
     for (int d = 0; d < descLength_; ++d)
-      output.points[idx].descriptor[d] = shot_[d];
+      output[idx].descriptor[d] = shot_[d];
     for (int d = 0; d < 3; ++d)
     {
-      output.points[idx].rf[d + 0] = frames_->points[idx].x_axis[d];
-      output.points[idx].rf[d + 3] = frames_->points[idx].y_axis[d];
-      output.points[idx].rf[d + 6] = frames_->points[idx].z_axis[d];
+      output[idx].rf[d + 0] = (*frames_)[idx].x_axis[d];
+      output[idx].rf[d + 3] = (*frames_)[idx].y_axis[d];
+      output[idx].rf[d + 6] = (*frames_)[idx].z_axis[d];
     }
   }
 }
@@ -870,9 +869,9 @@ pcl::SHOTColorEstimation<PointInT, PointNT, PointOutT, PointRFT>::computeFeature
     {
       // Copy into the resultant cloud
       for (int d = 0; d < descLength_; ++d)
-        output.points[idx].descriptor[d] = std::numeric_limits<float>::quiet_NaN ();
+        output[idx].descriptor[d] = std::numeric_limits<float>::quiet_NaN ();
       for (int d = 0; d < 9; ++d)
-        output.points[idx].rf[d] = std::numeric_limits<float>::quiet_NaN ();
+        output[idx].rf[d] = std::numeric_limits<float>::quiet_NaN ();
 
       output.is_dense = false;
       continue;
@@ -883,12 +882,12 @@ pcl::SHOTColorEstimation<PointInT, PointNT, PointOutT, PointRFT>::computeFeature
 
     // Copy into the resultant cloud
     for (int d = 0; d < descLength_; ++d)
-      output.points[idx].descriptor[d] = shot_[d];
+      output[idx].descriptor[d] = shot_[d];
     for (int d = 0; d < 3; ++d)
     {
-      output.points[idx].rf[d + 0] = frames_->points[idx].x_axis[d];
-      output.points[idx].rf[d + 3] = frames_->points[idx].y_axis[d];
-      output.points[idx].rf[d + 6] = frames_->points[idx].z_axis[d];
+      output[idx].rf[d + 0] = (*frames_)[idx].x_axis[d];
+      output[idx].rf[d + 3] = (*frames_)[idx].y_axis[d];
+      output[idx].rf[d + 6] = (*frames_)[idx].z_axis[d];
     }
   }
 }
