@@ -48,8 +48,6 @@ using std::vector;
 using Eigen::Vector3f;
 
 #include <pcl/range_image/range_image.h>
-#include <pcl/common/vector_average.h>
-#include <pcl/common/common_headers.h>
 
 namespace pcl 
 {
@@ -260,16 +258,11 @@ Narf::extractFromRangeImageWithBestRotation (const RangeImage& range_image, cons
   getRotations(rotations, strengths);
   if (rotations.empty())
     return false;
-  float best_rotation=rotations[0], best_strength=strengths[0];
-  for (std::size_t i = 1; i < rotations.size(); ++i)
-  {
-    if (strengths[i] > best_strength)
-    {
-      best_rotation = rotations[i];
-      best_strength = strengths[i];
-    }
-  }
-  
+
+  const auto max_it = std::max_element(strengths.cbegin (), strengths.cend ());
+  const auto max_idx = std::distance(strengths.cbegin (), max_it);
+  const auto best_rotation = rotations[max_idx];
+
   transformation_ = Eigen::AngleAxisf(-best_rotation, Eigen::Vector3f(0.0f, 0.0f, 1.0f))*transformation_;
   surface_patch_rotation_ = best_rotation;
   return extractDescriptor(descriptor_size_);
@@ -376,11 +369,15 @@ void
 Narf::extractForInterestPoints (const RangeImage& range_image, const PointCloud<InterestPoint>& interest_points,
                                 int descriptor_size, float support_size, bool rotation_invariant, std::vector<Narf*>& feature_list)
 {
-  # pragma omp parallel for num_threads(max_no_of_threads) default(shared) schedule(dynamic, 10)
+#pragma omp parallel for \
+  default(none) \
+  shared(descriptor_size, feature_list, interest_points, range_image, rotation_invariant, support_size) \
+  schedule(dynamic, 10) \
+  num_threads(max_no_of_threads)
   //!!! nizar 20110408 : for OpenMP sake on MSVC this must be kept signed
-  for (std::ptrdiff_t idx = 0; idx < static_cast<std::ptrdiff_t>(interest_points.points.size ()); ++idx)
+  for (std::ptrdiff_t idx = 0; idx < static_cast<std::ptrdiff_t>(interest_points.size ()); ++idx)
   {
-    const auto& interest_point = interest_points.points[idx];
+    const auto& interest_point = interest_points[idx];
     Vector3fMapConst point = interest_point.getVector3fMap ();
 
     Narf* feature = new Narf;
@@ -679,7 +676,7 @@ NarfDescriptor::computeFeature(NarfDescriptor::PointCloudOut& output)
   output.points.resize(feature_list.size());
   for (std::size_t i = 0; i < feature_list.size(); ++i)
   {
-    feature_list[i]->copyToNarf36(output.points[i]);
+    feature_list[i]->copyToNarf36(output[i]);
   }
   
   // Cleanup
