@@ -90,11 +90,7 @@ pcl::FieldComparison<PointT>::FieldComparison (
 template <typename PointT>
 pcl::FieldComparison<PointT>::~FieldComparison () 
 {
-  if (point_data_ != nullptr)
-  {
-    delete point_data_;
-    point_data_ = nullptr;
-  }
+  delete point_data_;
 }
 
 //////////////////////////////////////////////////////////////////////////
@@ -686,17 +682,18 @@ pcl::ConditionalRemoval<PointT>::applyFilter (PointCloud &output)
     output.width    = this->input_->width;
     output.is_dense = this->input_->is_dense;
   }
-  output.points.resize (input_->points.size ());
-  removed_indices_->resize (input_->points.size ());
+  output.points.resize (input_->size ());
+  removed_indices_->resize (input_->size ());
 
-  int nr_p = 0;
   int nr_removed_p = 0;
 
   if (!keep_organized_)
   {
+    int nr_p = 0;
     for (std::size_t index: (*Filter<PointT>::indices_))
     {
-      const PointT& point = input_->points[index];
+
+      const PointT& point = (*input_)[index];
       // Check if the point is invalid
       if (!std::isfinite (point.x)
           || !std::isfinite (point.y)
@@ -712,7 +709,7 @@ pcl::ConditionalRemoval<PointT>::applyFilter (PointCloud &output)
 
       if (condition_->evaluate (point))
       {
-        copyPoint (point, output.points[nr_p]);
+        copyPoint (point, output[nr_p]);
         nr_p++;
       }
       else
@@ -734,7 +731,7 @@ pcl::ConditionalRemoval<PointT>::applyFilter (PointCloud &output)
     std::sort (indices.begin (), indices.end ());   //TODO: is this necessary or can we assume the indices to be sorted?
     bool removed_p = false;
     std::size_t ci = 0;
-    for (std::size_t cp = 0; cp < input_->points.size (); ++cp)
+    for (std::size_t cp = 0; cp < input_->size (); ++cp)
     {
       if (cp == static_cast<std::size_t> (indices[ci]))
       {
@@ -746,11 +743,11 @@ pcl::ConditionalRemoval<PointT>::applyFilter (PointCloud &output)
         }
 
         // copy all the fields
-        copyPoint (input_->points[cp], output.points[cp]);
+        copyPoint ((*input_)[cp], output[cp]);
 
-        if (!condition_->evaluate (input_->points[cp]))
+        if (!condition_->evaluate ((*input_)[cp]))
         {
-          output.points[cp].getVector4fMap ().setConstant (user_filter_value_);
+          output[cp].getVector4fMap ().setConstant (user_filter_value_);
           removed_p = true;
 
           if (extract_removed_indices_)
@@ -762,7 +759,7 @@ pcl::ConditionalRemoval<PointT>::applyFilter (PointCloud &output)
       }
       else
       {
-        output.points[cp].getVector4fMap ().setConstant (user_filter_value_);
+        output[cp].getVector4fMap ().setConstant (user_filter_value_);
         removed_p = true;
         //as for !keep_organized_: removed points due to setIndices are not considered as removed_indices_
       }
