@@ -72,18 +72,13 @@ pcl::FastBilateralFilterOMP<PointT>::applyFilter (PointCloud &output)
   float base_max = -std::numeric_limits<float>::max (),
         base_min = std::numeric_limits<float>::max ();
   bool found_finite = false;
-  for (std::size_t x = 0; x < output.width; ++x)
+  for (const auto& pt: output)
   {
-    for (std::size_t y = 0; y < output.height; ++y)
+    if (std::isfinite(pt.z))
     {
-      if (std::isfinite (output (x, y).z))
-      {
-        if (base_max < output (x, y).z)
-          base_max = output (x, y).z;
-        if (base_min > output (x, y).z)
-          base_min = output (x, y).z;
-        found_finite = true;
-      }
+      base_max = std::max<float>(pt.z, base_max);
+      base_min = std::min<float>(pt.z, base_min);
+      found_finite = true;
     }
   }
   if (!found_finite)
@@ -91,9 +86,10 @@ pcl::FastBilateralFilterOMP<PointT>::applyFilter (PointCloud &output)
     PCL_WARN ("[pcl::FastBilateralFilterOMP] Given an empty cloud. Doing nothing.\n");
     return;
   }
-#ifdef _OPENMP
-#pragma omp parallel for num_threads (threads_)
-#endif
+#pragma omp parallel for \
+  default(none) \
+  shared(base_min, base_max, output) \
+  num_threads(threads_)
   for (long int i = 0; i < static_cast<long int> (output.size ()); ++i)
     if (!std::isfinite (output.at(i).z))
       output.at(i).z = base_max;
@@ -108,8 +104,16 @@ pcl::FastBilateralFilterOMP<PointT>::applyFilter (PointCloud &output)
   const std::size_t small_depth  = static_cast<std::size_t> (base_delta / sigma_r_)   + 1 + 2 * padding_z;
 
   Array3D data (small_width, small_height, small_depth);
-#ifdef _OPENMP
-#pragma omp parallel for num_threads (threads_)
+#if OPENMP_LEGACY_CONST_DATA_SHARING_RULE
+#pragma omp parallel for \
+  default(none) \
+  shared(base_min, data, output) \
+  num_threads(threads_)
+#else
+#pragma omp parallel for \
+  default(none) \
+  shared(base_min, data, output, small_height, small_width) \
+  num_threads(threads_)	
 #endif
   for (long int i = 0; i < static_cast<long int> (small_width * small_height); ++i)
   {
@@ -149,8 +153,16 @@ pcl::FastBilateralFilterOMP<PointT>::applyFilter (PointCloud &output)
     {
       Array3D* current_buffer = (n_iter % 2 == 1 ? &buffer : &data);
       Array3D* current_data =(n_iter % 2 == 1 ? &data : &buffer);
-#ifdef _OPENMP
-#pragma omp parallel for num_threads (threads_)
+#if OPENMP_LEGACY_CONST_DATA_SHARING_RULE
+#pragma omp parallel for \
+  default(none) \
+  shared(current_buffer, current_data, dim, offset) \
+  num_threads(threads_)
+#else
+#pragma omp parallel for \
+  default(none) \
+  shared(current_buffer, current_data, dim, offset, small_depth, small_height, small_width) \
+  num_threads(threads_)
 #endif
       for(long int i = 0; i < static_cast<long int> ((small_width - 2)*(small_height - 2)); ++i)
       {
@@ -174,9 +186,10 @@ pcl::FastBilateralFilterOMP<PointT>::applyFilter (PointCloud &output)
     for (std::vector<Eigen::Vector2f, Eigen::aligned_allocator<Eigen::Vector2f> >::iterator d = data.begin (); d != data.end (); ++d)
       *d /= ((*d)[0] != 0) ? (*d)[1] : 1;
 
-#ifdef _OPENMP
-#pragma omp parallel for num_threads (threads_)
-#endif
+#pragma omp parallel for \
+  default(none) \
+  shared(base_min, data, output) \
+  num_threads(threads_)
     for (long int i = 0; i < static_cast<long int> (input_->size ()); ++i)
     {
       std::size_t x = static_cast<std::size_t> (i % input_->width);
@@ -190,9 +203,10 @@ pcl::FastBilateralFilterOMP<PointT>::applyFilter (PointCloud &output)
   }
   else
   {
-#ifdef _OPENMP
-#pragma omp parallel for num_threads (threads_)
-#endif
+#pragma omp parallel for \
+  default(none) \
+  shared(base_min, data, output) \
+  num_threads(threads_)
     for (long i = 0; i < static_cast<long int> (input_->size ()); ++i)
     {
       std::size_t x = static_cast<std::size_t> (i % input_->width);
