@@ -82,7 +82,7 @@ namespace pcl
        */
       inline
       ModelOutlierRemoval (bool extract_removed_indices = false) :
-          FilterIndices<PointT>::FilterIndices (extract_removed_indices)
+          FilterIndices<PointT> (extract_removed_indices)
       {
         thresh_ = 0;
         normals_distance_weight_ = 0;
@@ -199,12 +199,6 @@ namespace pcl
       using FilterIndices<PointT>::extract_removed_indices_;
       using FilterIndices<PointT>::removed_indices_;
 
-      /** \brief Filtered results are stored in a separate point cloud.
-       * \param[out] output The resultant point cloud.
-       */
-      void
-      applyFilter (PointCloud &output) override;
-
       /** \brief Filtered results are indexed by an indices array.
        * \param[out] indices The resultant indices.
        */
