@@ -45,7 +45,6 @@
 #include "data_source.hpp"
 #include <pcl/search/pcl_search.h>
 
-using namespace std;
 using namespace pcl;
 using namespace pcl::gpu;
 
@@ -60,7 +59,7 @@ TEST(PCL_FeaturesGPU, fpfh_low_level)
                    
     std::vector<int> data;
     source.getNeghborsArray(data);
-    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->size());    
     std::transform(source.normals->points.begin(), source.normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());
     
     //uploading data to GPU
@@ -95,7 +94,7 @@ TEST(PCL_FeaturesGPU, fpfh_low_level)
     for(std::size_t i = 0; i < downloaded.size(); ++i)
     {
         FPFHSignature33& gpu = downloaded[i];
-        FPFHSignature33& cpu = fpfhs.points[i];
+        FPFHSignature33& cpu = fpfhs[i];
         
         std::size_t FSize = sizeof(FPFHSignature33)/sizeof(gpu.histogram[0]);                                
         
@@ -123,7 +122,7 @@ TEST(PCL_FeaturesGPU, fpfh_high_level1)
 
     PointCloud<Normal>::Ptr& normals = source.normals;
 
-    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->size());    
     std::transform(normals->points.begin(), normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());
 
     //uploading data to GPU
@@ -170,7 +169,7 @@ TEST(PCL_FeaturesGPU, fpfh_high_level1)
     for(std::size_t i = 0; i < downloaded.size(); ++i)
     {
         FPFHSignature33& gpu = downloaded[i];
-        FPFHSignature33& cpu = fpfhs.points[i];
+        FPFHSignature33& cpu = fpfhs[i];
         
         std::size_t FSize = sizeof(FPFHSignature33)/sizeof(gpu.histogram[0]);                                
         
@@ -201,7 +200,7 @@ TEST(PCL_FeaturesGPU, fpfh_high_level2)
 
     PointCloud<Normal>::Ptr& normals = source.normals;
 
-    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->size());    
     std::transform(normals->points.begin(), normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());
 
     //uploading data to GPU
@@ -248,7 +247,7 @@ TEST(PCL_FeaturesGPU, fpfh_high_level2)
     for(std::size_t i = 0; i < downloaded.size(); ++i)
     {
         FPFHSignature33& gpu = downloaded[i];
-        FPFHSignature33& cpu = fpfhs.points[i];
+        FPFHSignature33& cpu = fpfhs[i];
         
         std::size_t FSize = sizeof(FPFHSignature33)/sizeof(gpu.histogram[0]);                                
         
@@ -278,7 +277,7 @@ TEST(PCL_FeaturesGPU, fpfh_high_level3)
     
     PointCloud<Normal>::Ptr& normals = source.normals_surface;
 
-    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->size());    
     std::transform(normals->points.begin(), normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());
 
     //uploading data to GPU
@@ -325,7 +324,7 @@ TEST(PCL_FeaturesGPU, fpfh_high_level3)
     for(std::size_t i = 0; i < downloaded.size(); ++i)
     {
         FPFHSignature33& gpu = downloaded[i];
-        FPFHSignature33& cpu = fpfhs.points[i];
+        FPFHSignature33& cpu = fpfhs[i];
         
         std::size_t FSize = sizeof(FPFHSignature33)/sizeof(gpu.histogram[0]);                                
         
@@ -356,7 +355,7 @@ TEST(PCL_FeaturesGPU, fpfh_high_level4)
 
     PointCloud<Normal>::Ptr& normals = source.normals_surface;
 
-    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->size());    
     std::transform(normals->points.begin(), normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());
 
     //uploading data to GPU
@@ -403,7 +402,7 @@ TEST(PCL_FeaturesGPU, fpfh_high_level4)
     for(std::size_t i = 0; i < downloaded.size(); ++i)
     {
         FPFHSignature33& gpu = downloaded[i];
-        FPFHSignature33& cpu = fpfhs.points[i];
+        FPFHSignature33& cpu = fpfhs[i];
         
         std::size_t FSize = sizeof(FPFHSignature33)/sizeof(gpu.histogram[0]);                                
         
