@@ -43,7 +43,6 @@
 
 #include "data_source.hpp"
 
-using namespace std;
 using namespace pcl;
 using namespace pcl::gpu;
 
@@ -61,7 +60,7 @@ TEST(PCL_FeaturesGPU, spinImages_rectangular)
 
 	const int min_beighbours = 15;
                    
-    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->size());    
     std::transform(source.normals->points.begin(), source.normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());        
     
     //uploading data to GPU
@@ -119,7 +118,7 @@ TEST(PCL_FeaturesGPU, spinImages_rectangular)
 			continue;  
 
         SpinImage& gpu = downloaded[i];
-        SpinImage& cpu = spin_images->points[i];
+        SpinImage& cpu = (*spin_images)[i];
         
         std::size_t FSize = sizeof(SpinImage)/sizeof(gpu.histogram[0]);                                
         
@@ -150,7 +149,7 @@ TEST(PCL_FeaturesGPU, spinImages_radial)
 
 	const int min_beighbours = 15;
                    
-    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->size());    
     std::transform(source.normals->points.begin(), source.normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());        
     
 
@@ -209,7 +208,7 @@ TEST(PCL_FeaturesGPU, spinImages_radial)
 			continue;  
 
         SpinImage& gpu = downloaded[i];
-        SpinImage& cpu = spin_images->points[i];
+        SpinImage& cpu = (*spin_images)[i];
         
         std::size_t FSize = sizeof(SpinImage)/sizeof(gpu.histogram[0]);                                
         
@@ -240,7 +239,7 @@ TEST(PCL_FeaturesGPU, spinImages_rectangular_angular)
 
 	const int min_beighbours = 15;
                    
-    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->size());    
     std::transform(source.normals->points.begin(), source.normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());        
     
 
@@ -299,7 +298,7 @@ TEST(PCL_FeaturesGPU, spinImages_rectangular_angular)
 			continue;  
 
         SpinImage& gpu = downloaded[i];
-        SpinImage& cpu = spin_images->points[i];
+        SpinImage& cpu = (*spin_images)[i];
         
         std::size_t FSize = sizeof(SpinImage)/sizeof(gpu.histogram[0]);                                
         
@@ -330,7 +329,7 @@ TEST(PCL_FeaturesGPU, spinImages_radial_angular)
 
 	const int min_beighbours = 15;
                    
-    std::vector<PointXYZ> normals_for_gpu(source.normals->points.size());    
+    std::vector<PointXYZ> normals_for_gpu(source.normals->size());    
     std::transform(source.normals->points.begin(), source.normals->points.end(), normals_for_gpu.begin(), DataSource::Normal2PointXYZ());        
     
 
@@ -389,7 +388,7 @@ TEST(PCL_FeaturesGPU, spinImages_radial_angular)
 			continue;  
 
         SpinImage& gpu = downloaded[i];
-        SpinImage& cpu = spin_images->points[i];
+        SpinImage& cpu = (*spin_images)[i];
         
         std::size_t FSize = sizeof(SpinImage)/sizeof(gpu.histogram[0]);                                
         
