@@ -53,7 +53,6 @@
   #include <opencv2/gpu/gpu.hpp>
 #endif
 
-using namespace std;
 using namespace pcl::device;
 using namespace pcl::gpu;
 
@@ -114,7 +113,7 @@ pcl::gpu::KinfuTracker::setDepthIntrinsics (float fx, float fy, float cx, float
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 void
-pcl::gpu::KinfuTracker::getDepthIntrinsics (float& fx, float& fy, float& cx, float& cy)
+pcl::gpu::KinfuTracker::getDepthIntrinsics (float& fx, float& fy, float& cx, float& cy) const
 {
   fx = fx_;
   fy = fy_;
@@ -567,7 +566,7 @@ namespace pcl
     PCL_EXPORTS void
     mergePointNormal(const DeviceArray<PointXYZ>& cloud, const DeviceArray<Normal>& normals, DeviceArray<PointNormal>& output)
     {
-      const std::size_t size = min(cloud.size(), normals.size());
+      const std::size_t size = std::min(cloud.size(), normals.size());
       output.create(size);
 
       const DeviceArray<float4>& c = (const DeviceArray<float4>&)cloud;
