@@ -153,7 +153,7 @@ namespace pcl
           */      
         std::size_t getWorldSize () 
         { 
-          return (world_->points.size () );
+          return (world_->size () );
         }
 
         /** \brief Returns the world as two vectors of cubes of size "size" (pointclouds) and transforms
