@@ -33,21 +33,21 @@
  *  POSSIBILITY OF SUCH DAMAGE.
  *
  */
- 
+
 #pragma once
 
-#include <chrono>
-
-#include <pcl/pcl_config.h>
-#include <pcl/pcl_exports.h>
 #include <pcl/io/boost.h>
-
 #include <pcl/io/image_metadata_wrapper.h>
+#include <pcl/memory.h>
+#include <pcl/pcl_config.h>
+#include <pcl/pcl_macros.h>
+
+#include <chrono>
 
 namespace pcl
 {
   namespace io
-  { 
+  {
 
     /**
     * @brief Image interface class providing an interface to fill a RGB or Grayscale image buffer.
@@ -212,3 +212,4 @@ namespace pcl
 
   } // namespace
 }
+
