@@ -38,6 +38,7 @@
 
 #include <chrono>
 
+#include <pcl/memory.h>
 #include <pcl/pcl_macros.h>
 #include <pcl/io/boost.h>
 
@@ -63,7 +64,7 @@ namespace pcl
         IRImage (FrameWrapper::Ptr ir_metadata);
         IRImage (FrameWrapper::Ptr ir_metadata, Timestamp time);
 
-        ~IRImage () throw ()
+        ~IRImage () noexcept
         {}
 
         void
