@@ -44,7 +44,7 @@
 #include <pcl/io/file_grabber.h>
 #include <pcl/common/time_trigger.h>
 #include <pcl/conversions.h>
-#include <pcl/make_shared.h>
+#include <pcl/memory.h>
 
 #ifdef HAVE_OPENNI
 #include <pcl/io/openni_camera/openni_image.h>
@@ -62,7 +62,7 @@ namespace pcl
     */
   class PCL_EXPORTS PCDGrabberBase : public Grabber
   {
-    public:   
+    public:
       /** \brief Constructor taking just one PCD file or one TAR file containing multiple PCD files.
         * \param[in] pcd_file path to the PCD file
         * \param[in] frames_per_second frames per second. If 0, start() functions like a trigger, publishing the next PCD in the list.
@@ -77,66 +77,48 @@ namespace pcl
         */
       PCDGrabberBase (const std::vector<std::string>& pcd_files, float frames_per_second, bool repeat);
 
-      /** \brief Copy constructor.
-        * \param[in] src the PCD Grabber base object to copy into this
-        */
-      PCDGrabberBase (const PCDGrabberBase &src) : impl_ ()
-      {
-        *this = src;
-      }
-
-      /** \brief Copy operator.
-        * \param[in] src the PCD Grabber base object to copy into this
-        */
-      PCDGrabberBase&
-      operator = (const PCDGrabberBase &src)
-      {
-        impl_ = src.impl_;
-        return (*this);
-      }
-
       /** \brief Virtual destructor. */
-      ~PCDGrabberBase () throw ();
+      ~PCDGrabberBase () noexcept;
 
       /** \brief Starts playing the list of PCD files if frames_per_second is > 0. Otherwise it works as a trigger: publishes only the next PCD file in the list. */
-      void 
+      void
       start () override;
-      
+
       /** \brief Stops playing the list of PCD files if frames_per_second is > 0. Otherwise the method has no effect. */
-      void 
+      void
       stop () override;
-      
+
       /** \brief Triggers a callback with new data */
-      virtual void 
+      virtual void
       trigger ();
 
       /** \brief Indicates whether the grabber is streaming or not.
         * \return true if grabber is started and hasn't run out of PCD files.
         */
-      bool 
+      bool
       isRunning () const override;
-      
+
       /** \return The name of the grabber */
-      std::string 
+      std::string
       getName () const override;
-      
+
       /** \brief Rewinds to the first PCD file in the list.*/
-      virtual void 
+      virtual void
       rewind ();
 
       /** \brief Returns the frames_per_second. 0 if grabber is trigger-based */
-      float 
+      float
       getFramesPerSecond () const override;
 
       /** \brief Returns whether the repeat flag is on */
-      bool 
+      bool
       isRepeatOn () const;
-  
+
       /** \brief Get cloud (in ROS form) at a particular location */
       bool
-      getCloudAt (std::size_t idx, 
+      getCloudAt (std::size_t idx,
                   pcl::PCLPointCloud2 &blob,
-                  Eigen::Vector4f &origin, 
+                  Eigen::Vector4f &origin,
                   Eigen::Quaternionf &orientation) const;
 
       /** \brief Returns the size */
@@ -144,7 +126,7 @@ namespace pcl
       numFrames () const;
 
     private:
-      virtual void 
+      virtual void
       publish (const pcl::PCLPointCloud2& blob, const Eigen::Vector4f& origin, const Eigen::Quaternionf& orientation, const std::string& file_name) const = 0;
 
       // to separate and hide the implementation from interface: PIMPL
@@ -162,13 +144,13 @@ namespace pcl
 
       PCDGrabber (const std::string& pcd_path, float frames_per_second = 0, bool repeat = false);
       PCDGrabber (const std::vector<std::string>& pcd_files, float frames_per_second = 0, bool repeat = false);
-      
+
       /** \brief Virtual destructor. */
-      ~PCDGrabber () throw ()
+      ~PCDGrabber () noexcept
       {
         stop ();
       }
-    
+
       // Inherited from FileGrabber
       const typename pcl::PointCloud<PointT>::ConstPtr
       operator[] (std::size_t idx) const override;
@@ -178,9 +160,9 @@ namespace pcl
       size () const override;
     protected:
 
-      void 
+      void
       publish (const pcl::PCLPointCloud2& blob, const Eigen::Vector4f& origin, const Eigen::Quaternionf& orientation, const std::string& file_name) const override;
-      
+
       boost::signals2::signal<void (const typename pcl::PointCloud<PointT>::ConstPtr&)>* signal_;
       boost::signals2::signal<void (const std::string&)>* file_name_signal_;
 
@@ -242,7 +224,7 @@ namespace pcl
   }
 
   ////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-  template<typename PointT> void 
+  template<typename PointT> void
   PCDGrabber<PointT>::publish (const pcl::PCLPointCloud2& blob, const Eigen::Vector4f& origin, const Eigen::Quaternionf& orientation, const std::string& file_name) const
   {
     typename pcl::PointCloud<PointT>::Ptr cloud (new pcl::PointCloud<PointT> ());
@@ -293,7 +275,7 @@ namespace pcl
         {
           // Fill r/g/b data, assuming that the order is BGRA
           pcl::RGB rgb;
-          memcpy (&rgb, reinterpret_cast<const char*> (&cloud->points[k]) + rgba_index, sizeof (RGB));
+          memcpy (&rgb, reinterpret_cast<const char*> (&(*cloud)[k]) + rgba_index, sizeof (RGB));
           image_map[k].nRed = static_cast<XnUInt8> (rgb.r);
           image_map[k].nGreen = static_cast<XnUInt8> (rgb.g);
           image_map[k].nBlue = static_cast<XnUInt8> (rgb.b);
@@ -304,7 +286,7 @@ namespace pcl
       openni_wrapper::Image::Ptr image (new openni_wrapper::ImageRGB24 (image_meta_data));
       if (image_signal_->num_slots() > 0)
         image_signal_->operator()(image);
-      
+
       if (image_depth_image_signal_->num_slots() > 0)
         image_depth_image_signal_->operator()(image, depth_image, 1.0f / 525.0f);
     }
