@@ -41,6 +41,9 @@
 
 #include <boost/predef/other/endian.h>
 
+#include <algorithm>
+#include <cstddef>
+
 namespace pcl
 {
   namespace io
