@@ -37,14 +37,17 @@
  *
  */
 
-#ifndef PCL_IO_PLY_IO_H_
-#define PCL_IO_PLY_IO_H_
+#pragma once
 
+#include <pcl/memory.h>
+#include <pcl/pcl_macros.h>
 #include <pcl/io/boost.h>
 #include <pcl/io/file_io.h>
 #include <pcl/io/ply/ply_parser.h>
 #include <pcl/PolygonMesh.h>
+
 #include <sstream>
+#include <tuple>
 
 namespace pcl
 {
@@ -84,33 +87,29 @@ namespace pcl
       };
       
       PLYReader ()
-        : FileReader ()
-        , parser_ ()
-        , origin_ (Eigen::Vector4f::Zero ())
+        : origin_ (Eigen::Vector4f::Zero ())
         , orientation_ (Eigen::Matrix3f::Zero ())
         , cloud_ ()
         , vertex_count_ (0)
         , vertex_offset_before_ (0)
-        , range_grid_ (0)
+        , range_grid_ (nullptr)
         , rgb_offset_before_ (0)
         , do_resize_ (false)
-        , polygons_ (0)
+        , polygons_ (nullptr)
         , r_(0), g_(0), b_(0)
         , a_(0), rgba_(0)
       {}
 
       PLYReader (const PLYReader &p)
-        : FileReader ()
-        , parser_ ()
-        , origin_ (Eigen::Vector4f::Zero ())
+        : origin_ (Eigen::Vector4f::Zero ())
         , orientation_ (Eigen::Matrix3f::Zero ())
         , cloud_ ()
         , vertex_count_ (0)
         , vertex_offset_before_ (0)
-        , range_grid_ (0)
+        , range_grid_ (nullptr)
         , rgb_offset_before_ (0)
         , do_resize_ (false)
-        , polygons_ (0)
+        , polygons_ (nullptr)
         , r_(0), g_(0), b_(0)
         , a_(0), rgba_(0)
       {
@@ -153,7 +152,7 @@ namespace pcl
       int 
       readHeader (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
                   Eigen::Vector4f &origin, Eigen::Quaternionf &orientation,
-                  int &ply_version, int &data_type, unsigned int &data_idx, const int offset = 0);
+                  int &ply_version, int &data_type, unsigned int &data_idx, const int offset = 0) override;
 
       /** \brief Read a point cloud data from a PLY file and store it into a pcl/PCLPointCloud2.
         * \param[in] file_name the name of the file containing the actual PointCloud data
@@ -169,7 +168,7 @@ namespace pcl
         */
       int 
       read (const std::string &file_name, pcl::PCLPointCloud2 &cloud,
-            Eigen::Vector4f &origin, Eigen::Quaternionf &orientation, int& ply_version, const int offset = 0);
+            Eigen::Vector4f &origin, Eigen::Quaternionf &orientation, int& ply_version, const int offset = 0) override;
 
       /** \brief Read a point cloud data from a PLY file and store it into a pcl/PCLPointCloud2.
         * \note This function is provided for backwards compatibility only
@@ -288,7 +287,7 @@ namespace pcl
         * \param[in] element_name element name
         * \param[in] count number of instances
         */
-      boost::tuple<boost::function<void ()>, boost::function<void ()> > 
+      std::tuple<std::function<void ()>, std::function<void ()> > 
       elementDefinitionCallback (const std::string& element_name, std::size_t count);
       
       bool
@@ -298,7 +297,7 @@ namespace pcl
         * \param[in] element_name element name to which the property belongs
         * \param[in] property_name property name
         */
-      template <typename ScalarType> boost::function<void (ScalarType)> 
+      template <typename ScalarType> std::function<void (ScalarType)> 
       scalarPropertyDefinitionCallback (const std::string& element_name, const std::string& property_name);
 
       /** \brief function called when a list property is parsed
@@ -306,7 +305,7 @@ namespace pcl
         * \param[in] property_name list property name
         */
       template <typename SizeType, typename ScalarType>
-      boost::tuple<boost::function<void (SizeType)>, boost::function<void (ScalarType)>, boost::function<void ()> >
+      std::tuple<std::function<void (SizeType)>, std::function<void (ScalarType)>, std::function<void ()> >
       listPropertyDefinitionCallback (const std::string& element_name, const std::string& property_name);
       
       /** \brief function called at the beginning of a list property parsing.
@@ -445,7 +444,7 @@ namespace pcl
         * list property.
         */
       template<typename Scalar> void
-      appendScalarProperty (const std::string& name, const size_t& count = 1);
+      appendScalarProperty (const std::string& name, const std::size_t& count = 1);
 
       /** Amend property from cloud fields identified by \a old_name renaming
         * it \a new_name.
@@ -453,7 +452,7 @@ namespace pcl
         * param[in] new_name property new name
         */
       void
-      amendProperty (const std::string& old_name, const std::string& new_name, uint8_t datatype = 0);
+      amendProperty (const std::string& old_name, const std::string& new_name, std::uint8_t datatype = 0);
 
       /** Callback function for the begin of vertex line */
       void
@@ -523,22 +522,22 @@ namespace pcl
 
       //vertex element artifacts
       pcl::PCLPointCloud2 *cloud_;
-      size_t vertex_count_;
+      std::size_t vertex_count_;
       int vertex_offset_before_;
       //range element artifacts
       std::vector<std::vector <int> > *range_grid_;
-      size_t rgb_offset_before_;
+      std::size_t rgb_offset_before_;
       bool do_resize_;
       //face element artifact
       std::vector<pcl::Vertices> *polygons_;
     public:
-      EIGEN_MAKE_ALIGNED_OPERATOR_NEW
+      PCL_MAKE_ALIGNED_OPERATOR_NEW
       
     private:
       // RGB values stored by vertexColorCallback()
-      int32_t r_, g_, b_;
+      std::int32_t r_, g_, b_;
       // Color values stored by vertexAlphaCallback()
-      uint32_t a_, rgba_;
+      std::uint32_t a_, rgba_;
   };
 
   /** \brief Point Cloud Data (PLY) file format writer.
@@ -549,7 +548,7 @@ namespace pcl
   {
     public:
       ///Constructor
-      PLYWriter () : FileWriter () {};
+      PLYWriter () {};
 
       ///Destructor
       ~PLYWriter () {};
@@ -634,12 +633,11 @@ namespace pcl
       write (const std::string &file_name, const pcl::PCLPointCloud2 &cloud,
              const Eigen::Vector4f &origin = Eigen::Vector4f::Zero (), 
              const Eigen::Quaternionf &orientation = Eigen::Quaternionf::Identity (),
-             const bool binary = false)
+             const bool binary = false) override
       {
         if (binary)
           return (this->writeBinary (file_name, cloud, origin, orientation, true));
-        else
-          return (this->writeASCII (file_name, cloud, origin, orientation, 8, true));
+        return (this->writeASCII (file_name, cloud, origin, orientation, 8, true));
       }
 
       /** \brief Save point cloud data to a PLY file containing n-D points
@@ -661,8 +659,7 @@ namespace pcl
       {
         if (binary)
           return (this->writeBinary (file_name, cloud, origin, orientation, use_camera));
-        else
-          return (this->writeASCII (file_name, cloud, origin, orientation, 8, use_camera));
+        return (this->writeASCII (file_name, cloud, origin, orientation, 8, use_camera));
       }
 
       /** \brief Save point cloud data to a PLY file containing n-D points
@@ -896,5 +893,3 @@ namespace pcl
     savePLYFileBinary (const std::string &file_name, const pcl::PolygonMesh &mesh);
   }
 }
-
-#endif  //#ifndef PCL_IO_PLY_IO_H_
