@@ -4,7 +4,7 @@
  * Point Cloud Library (PCL) - www.pointclouds.org
  * Copyright (c) 2000-2010 Marc Alexander Lehmann <schmorp@schmorp.de>
  * Copyright (c) 2010-2011, Willow Garage, Inc.
- * 
+ *
  *  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
@@ -17,7 +17,7 @@
  *     copyright notice, this list of conditions and the following
  *     disclaimer in the documentation and/or other materials provided
  *     with the distribution.
- * 
+ *
  *  THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
  *  "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
  *  LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
@@ -35,11 +35,13 @@
  *
  */
 
-#include <pcl/io/lzf.h>
-#include <cstring>
-#include <climits>
 #include <pcl/console/print.h>
+#include <pcl/io/lzf.h>
+
 #include <cerrno>
+#include <climits>
+#include <cstddef>
+#include <cstring>
 
 /*
  * Size of hashtable is (1 << HLOG) * sizeof (char *)
@@ -114,7 +116,7 @@ pcl::lzfCompress (const void *const in_data, unsigned int in_len,
 
     hval = (hval << 8) | ip[2];
     hslot = htab + IDX (hval);
-    const unsigned char *ref = *hslot + (static_cast<const unsigned char*> (in_data)); 
+    const unsigned char *ref = *hslot + (static_cast<const unsigned char*> (in_data));
     *hslot = static_cast<unsigned int> (ip - (static_cast<const unsigned char*> (in_data)));
 
     // off requires a type wide enough to hold a general pointer difference.
@@ -123,16 +125,16 @@ pcl::lzfCompress (const void *const in_data, unsigned int in_len,
     // no bit pattern traps. Since the only platform that is both non-POSIX
     // and fails to support both assumptions is windows 64 bit, we make a
     // special workaround for it.
-#if defined (WIN32) && defined (_M_X64) && defined (_MSC_VER)
+#if defined (_WIN32) && defined (_M_X64) && defined (_MSC_VER)
     // workaround for missing POSIX compliance
-    unsigned _int64 off; 
+    unsigned _int64 off;
 #else
     unsigned long off;
 #endif
 
     if (
         // The next test will actually take care of this, but this is faster if htab is initialized
-        ref < ip 
+        ref < ip
         && (off = ip - ref - 1) < (1 << 13)
         && ref > static_cast<const unsigned char *> (in_data)
         && ref[2] == ip[2]
@@ -145,7 +147,7 @@ pcl::lzfCompress (const void *const in_data, unsigned int in_len,
     {
       // Match found at *ref++
       unsigned int len = 2;
-      ptrdiff_t maxlen = in_end - ip - len;
+      std::ptrdiff_t maxlen = in_end - ip - len;
       maxlen = maxlen > ((1 << 8) + (1 << 3)) ? ((1 << 8) + (1 << 3)) : maxlen;
 
       // First a faster conservative test
@@ -248,7 +250,7 @@ pcl::lzfCompress (const void *const in_data, unsigned int in_len,
     }
   }
 
-  // At most 3 bytes can be missing here 
+  // At most 3 bytes can be missing here
   if (op + 3 > out_end)
     return (0);
 
@@ -274,7 +276,7 @@ pcl::lzfCompress (const void *const in_data, unsigned int in_len,
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////
-unsigned int 
+unsigned int
 pcl::lzfDecompress (const void *const in_data,  unsigned int in_len,
                     void             *out_data, unsigned int out_len)
 {
