@@ -42,13 +42,15 @@
 #include <pcl/point_types.h>
 #include <pcl/common/time.h>
 #include <pcl/console/print.h>
-#include <pcl/io/boost.h>
+#include <pcl/io/boost.h>  // for boost::shared_array
+#include <pcl/memory.h>  // for dynamic_pointer_cast
 #include <pcl/exceptions.h>
+
 #include <iostream>
 
 namespace
 {
-  typedef union
+  union RGBValue
   {
     struct /*anonymous*/
     {
@@ -59,7 +61,7 @@ namespace
     };
     float float_value;
     long long_value;
-  } RGBValue;
+  };
 }
 
 namespace pcl
@@ -67,10 +69,7 @@ namespace pcl
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 ONIGrabber::ONIGrabber (const std::string& file_name, bool repeat, bool stream)
-  : rgb_sync_ ()
-  , ir_sync_ ()
-  , device_ ()
-  , rgb_frame_id_ ("/openni_rgb_optical_frame")
+  : rgb_frame_id_ ("/openni_rgb_optical_frame")
   , depth_frame_id_ ("/openni_depth_optical_frame")
   , running_ (false)
   , image_width_ ()
@@ -85,7 +84,7 @@ ONIGrabber::ONIGrabber (const std::string& file_name, bool repeat, bool stream)
   , point_cloud_rgba_signal_ ()
 {
   openni_wrapper::OpenNIDriver& driver = openni_wrapper::OpenNIDriver::getInstance ();
-  device_ = boost::dynamic_pointer_cast< openni_wrapper::DeviceONI> (driver.createVirtualDevice (file_name, repeat, stream));
+  device_ = dynamic_pointer_cast< openni_wrapper::DeviceONI> (driver.createVirtualDevice (file_name, repeat, stream));
 
   if (!device_->hasDepthStream ())
     PCL_THROW_EXCEPTION (pcl::IOException, "Device does not provide 3D information.");
@@ -114,7 +113,13 @@ ONIGrabber::ONIGrabber (const std::string& file_name, bool repeat, bool stream)
     image_depth_image_signal_ = createSignal <sig_cb_openni_image_depth_image> ();
     point_cloud_rgb_signal_   = createSignal <sig_cb_openni_point_cloud_rgb> ();
     point_cloud_rgba_signal_   = createSignal <sig_cb_openni_point_cloud_rgba> ();
-    rgb_sync_.addCallback (boost::bind(&ONIGrabber::imageDepthImageCallback, this, _1, _2));
+    rgb_sync_.addCallback ([this] (const openni_wrapper::Image::Ptr& image,
+                                   const openni_wrapper::DepthImage::Ptr& depth_image,
+                                   unsigned long,
+                                   unsigned long)
+    {
+      imageDepthImageCallback (image, depth_image);
+    });
   }
 
   image_callback_handle = device_->registerImageCallback (&ONIGrabber::imageCallback, *this);
@@ -137,7 +142,7 @@ ONIGrabber::ONIGrabber (const std::string& file_name, bool repeat, bool stream)
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-ONIGrabber::~ONIGrabber() throw ()
+ONIGrabber::~ONIGrabber() noexcept
 {
   try
   {
@@ -247,13 +252,12 @@ ONIGrabber::getFramesPerSecond () const
 {
   if (device_->isStreaming())
     return (static_cast<float> (device_->getDepthOutputMode ().nFPS));
-  else
-    return (0);
+  return (0);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 void 
-ONIGrabber::imageCallback(boost::shared_ptr<openni_wrapper::Image> image, void*)
+ONIGrabber::imageCallback(openni_wrapper::Image::Ptr image, void*)
 {
   if (num_slots<sig_cb_openni_point_cloud_rgb> () > 0 ||
       num_slots<sig_cb_openni_point_cloud_rgba> () > 0 ||
@@ -268,7 +272,7 @@ ONIGrabber::imageCallback(boost::shared_ptr<openni_wrapper::Image> image, void*)
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 void 
-ONIGrabber::depthCallback(boost::shared_ptr<openni_wrapper::DepthImage> depth_image, void*)
+ONIGrabber::depthCallback(openni_wrapper::DepthImage::Ptr depth_image, void*)
 {
   if (num_slots<sig_cb_openni_point_cloud_rgb> () > 0 ||
       num_slots<sig_cb_openni_point_cloud_rgba> () > 0 ||
@@ -290,7 +294,7 @@ ONIGrabber::depthCallback(boost::shared_ptr<openni_wrapper::DepthImage> depth_im
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 void 
-ONIGrabber::irCallback(boost::shared_ptr<openni_wrapper::IRImage> ir_image, void*)
+ONIGrabber::irCallback(openni_wrapper::IRImage::Ptr ir_image, void*)
 {
   if (num_slots<sig_cb_openni_point_cloud_i > () > 0 ||
       num_slots<sig_cb_openni_ir_depth_image > () > 0)
@@ -304,7 +308,7 @@ ONIGrabber::irCallback(boost::shared_ptr<openni_wrapper::IRImage> ir_image, void
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 void 
-ONIGrabber::imageDepthImageCallback(const boost::shared_ptr<openni_wrapper::Image> &image, const boost::shared_ptr<openni_wrapper::DepthImage> &depth_image)
+ONIGrabber::imageDepthImageCallback(const openni_wrapper::Image::Ptr &image, const openni_wrapper::DepthImage::Ptr &depth_image)
 {
   // check if we have color point cloud slots
   if (point_cloud_rgb_signal_->num_slots () > 0)
@@ -325,7 +329,7 @@ ONIGrabber::imageDepthImageCallback(const boost::shared_ptr<openni_wrapper::Imag
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 void 
-ONIGrabber::irDepthImageCallback(const boost::shared_ptr<openni_wrapper::IRImage> &ir_image, const boost::shared_ptr<openni_wrapper::DepthImage> &depth_image)
+ONIGrabber::irDepthImageCallback(const openni_wrapper::IRImage::Ptr &ir_image, const openni_wrapper::DepthImage::Ptr &depth_image)
 {
   // check if we have color point cloud slots
   if (point_cloud_i_signal_->num_slots() > 0)
@@ -340,7 +344,7 @@ ONIGrabber::irDepthImageCallback(const boost::shared_ptr<openni_wrapper::IRImage
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 pcl::PointCloud<pcl::PointXYZ>::Ptr 
-ONIGrabber::convertToXYZPointCloud(const boost::shared_ptr<openni_wrapper::DepthImage>& depth_image) const
+ONIGrabber::convertToXYZPointCloud(const openni_wrapper::DepthImage::Ptr& depth_image) const
 {
   pcl::PointCloud<pcl::PointXYZ>::Ptr cloud(new pcl::PointCloud <pcl::PointXYZ>);
 
@@ -351,24 +355,24 @@ ONIGrabber::convertToXYZPointCloud(const boost::shared_ptr<openni_wrapper::Depth
 
   cloud->points.resize (cloud->height * cloud->width);
 
-  register float constant = 1.0f / device_->getDepthFocalLength (depth_width_);
+  float constant = 1.0f / device_->getDepthFocalLength (depth_width_);
 
   if (device_->isDepthRegistered ())
     cloud->header.frame_id = rgb_frame_id_;
   else
     cloud->header.frame_id = depth_frame_id_;
 
-  register int centerX = (cloud->width >> 1);
+  int centerX = (cloud->width >> 1);
   int centerY = (cloud->height >> 1);
 
   float bad_point = std::numeric_limits<float>::quiet_NaN ();
 
   // we have to use Data, since operator[] uses assert -> Debug-mode very slow!
-  register const unsigned short* depth_map = depth_image->getDepthMetaData ().Data ();
+  const unsigned short* depth_map = depth_image->getDepthMetaData ().Data ();
   if (depth_image->getWidth () != depth_width_ || depth_image->getHeight () != depth_height_)
   {
     static unsigned buffer_size = 0;
-    static boost::shared_array<unsigned short> depth_buffer ((unsigned short*)(NULL));
+    static boost::shared_array<unsigned short> depth_buffer ((unsigned short*)nullptr);
 
     if (buffer_size < depth_width_ * depth_height_)
     {
@@ -379,12 +383,12 @@ ONIGrabber::convertToXYZPointCloud(const boost::shared_ptr<openni_wrapper::Depth
     depth_map = depth_buffer.get ();
   }
 
-  register int depth_idx = 0;
+  int depth_idx = 0;
   for (int v = -centerY; v < centerY; ++v)
   {
-    for (register int u = -centerX; u < centerX; ++u, ++depth_idx)
+    for (int u = -centerX; u < centerX; ++u, ++depth_idx)
     {
-      pcl::PointXYZ& pt = cloud->points[depth_idx];
+      pcl::PointXYZ& pt = (*cloud)[depth_idx];
       // Check for invalid measurements
       if (depth_map[depth_idx] == 0 ||
           depth_map[depth_idx] == depth_image->getNoSampleValue () ||
@@ -404,14 +408,14 @@ ONIGrabber::convertToXYZPointCloud(const boost::shared_ptr<openni_wrapper::Depth
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 pcl::PointCloud<pcl::PointXYZRGB>::Ptr ONIGrabber::convertToXYZRGBPointCloud (
-    const boost::shared_ptr<openni_wrapper::Image> &image, 
-    const boost::shared_ptr<openni_wrapper::DepthImage> &depth_image) const
+    const openni_wrapper::Image::Ptr &image,
+    const openni_wrapper::DepthImage::Ptr &depth_image) const
 {
   static unsigned rgb_array_size = 0;
-  static boost::shared_array<unsigned char> rgb_array((unsigned char*)(NULL));
-  static unsigned char* rgb_buffer = 0;
+  static boost::shared_array<unsigned char> rgb_array((unsigned char*)nullptr);
+  static unsigned char* rgb_buffer = nullptr;
 
-  boost::shared_ptr<pcl::PointCloud<pcl::PointXYZRGB> > cloud(new pcl::PointCloud<pcl::PointXYZRGB> ());
+  pcl::PointCloud<pcl::PointXYZRGB>::Ptr cloud(new pcl::PointCloud<pcl::PointXYZRGB>);
 
   cloud->header.frame_id = rgb_frame_id_;
   cloud->height = depth_height_;
@@ -421,14 +425,14 @@ pcl::PointCloud<pcl::PointXYZRGB>::Ptr ONIGrabber::convertToXYZRGBPointCloud (
   cloud->points.resize(cloud->height * cloud->width);
 
   float constant = 1.0f / device_->getImageFocalLength(cloud->width);
-  register int centerX = (cloud->width >> 1);
+  int centerX = (cloud->width >> 1);
   int centerY = (cloud->height >> 1);
 
-  register const XnDepthPixel* depth_map = depth_image->getDepthMetaData().Data();
+  const XnDepthPixel* depth_map = depth_image->getDepthMetaData().Data();
   if (depth_image->getWidth() != depth_width_ || depth_image->getHeight() != depth_height_)
   {
     static unsigned buffer_size = 0;
-    static boost::shared_array<unsigned short> depth_buffer((unsigned short*)(NULL));
+    static boost::shared_array<unsigned short> depth_buffer((unsigned short*)nullptr);
 
     if (buffer_size < depth_width_ * depth_height_)
     {
@@ -450,7 +454,7 @@ pcl::PointCloud<pcl::PointXYZRGB>::Ptr ONIGrabber::convertToXYZRGBPointCloud (
   image->fillRGB(image_width_, image_height_, rgb_buffer, image_width_ * 3);
 
   // depth_image already has the desired dimensions, but rgb_msg may be higher res.
-  register int color_idx = 0, depth_idx = 0;
+  int color_idx = 0, depth_idx = 0;
   RGBValue color;
   color.Alpha = 0;
 
@@ -458,9 +462,9 @@ pcl::PointCloud<pcl::PointXYZRGB>::Ptr ONIGrabber::convertToXYZRGBPointCloud (
 
   for (int v = -centerY; v < centerY; ++v)
   {
-    for (register int u = -centerX; u < centerX; ++u, color_idx += 3, ++depth_idx)
+    for (int u = -centerX; u < centerX; ++u, color_idx += 3, ++depth_idx)
     {
-      pcl::PointXYZRGB& pt = cloud->points[depth_idx];
+      pcl::PointXYZRGB& pt = (*cloud)[depth_idx];
       /// @todo Different values for these cases
       // Check for invalid measurements
       if (depth_map[depth_idx] == 0 ||
@@ -488,14 +492,14 @@ pcl::PointCloud<pcl::PointXYZRGB>::Ptr ONIGrabber::convertToXYZRGBPointCloud (
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 pcl::PointCloud<pcl::PointXYZRGBA>::Ptr ONIGrabber::convertToXYZRGBAPointCloud (
-    const boost::shared_ptr<openni_wrapper::Image> &image, 
-    const boost::shared_ptr<openni_wrapper::DepthImage> &depth_image) const
+    const openni_wrapper::Image::Ptr &image,
+    const openni_wrapper::DepthImage::Ptr &depth_image) const
 {
   static unsigned rgb_array_size = 0;
-  static boost::shared_array<unsigned char> rgb_array((unsigned char*)(NULL));
-  static unsigned char* rgb_buffer = 0;
+  static boost::shared_array<unsigned char> rgb_array((unsigned char*)nullptr);
+  static unsigned char* rgb_buffer = nullptr;
 
-  boost::shared_ptr<pcl::PointCloud<pcl::PointXYZRGBA> > cloud (new pcl::PointCloud<pcl::PointXYZRGBA> ());
+  pcl::PointCloud<pcl::PointXYZRGBA>::Ptr cloud (new pcl::PointCloud<pcl::PointXYZRGBA>);
 
   cloud->header.frame_id = rgb_frame_id_;
   cloud->height = depth_height_;
@@ -505,14 +509,14 @@ pcl::PointCloud<pcl::PointXYZRGBA>::Ptr ONIGrabber::convertToXYZRGBAPointCloud (
   cloud->points.resize(cloud->height * cloud->width);
 
   float constant = 1.0f / device_->getImageFocalLength(cloud->width);
-  register int centerX = (cloud->width >> 1);
+  int centerX = (cloud->width >> 1);
   int centerY = (cloud->height >> 1);
 
-  register const XnDepthPixel* depth_map = depth_image->getDepthMetaData().Data();
+  const XnDepthPixel* depth_map = depth_image->getDepthMetaData().Data();
   if (depth_image->getWidth() != depth_width_ || depth_image->getHeight() != depth_height_)
   {
     static unsigned buffer_size = 0;
-    static boost::shared_array<unsigned short> depth_buffer((unsigned short*)(NULL));
+    static boost::shared_array<unsigned short> depth_buffer((unsigned short*)nullptr);
 
     if (buffer_size < depth_width_ * depth_height_)
     {
@@ -534,7 +538,7 @@ pcl::PointCloud<pcl::PointXYZRGBA>::Ptr ONIGrabber::convertToXYZRGBAPointCloud (
   image->fillRGB(image_width_, image_height_, rgb_buffer, image_width_ * 3);
 
   // depth_image already has the desired dimensions, but rgb_msg may be higher res.
-  register int color_idx = 0, depth_idx = 0;
+  int color_idx = 0, depth_idx = 0;
   RGBValue color;
   color.Alpha = 0;
 
@@ -542,9 +546,9 @@ pcl::PointCloud<pcl::PointXYZRGBA>::Ptr ONIGrabber::convertToXYZRGBAPointCloud (
 
   for (int v = -centerY; v < centerY; ++v)
   {
-    for (register int u = -centerX; u < centerX; ++u, color_idx += 3, ++depth_idx)
+    for (int u = -centerX; u < centerX; ++u, color_idx += 3, ++depth_idx)
     {
-      pcl::PointXYZRGBA& pt = cloud->points[depth_idx];
+      pcl::PointXYZRGBA& pt = (*cloud)[depth_idx];
       /// @todo Different values for these cases
       // Check for invalid measurements
       if (depth_map[depth_idx] == 0 ||
@@ -564,17 +568,17 @@ pcl::PointCloud<pcl::PointXYZRGBA>::Ptr ONIGrabber::convertToXYZRGBAPointCloud (
       color.Red = rgb_buffer[color_idx];
       color.Green = rgb_buffer[color_idx + 1];
       color.Blue = rgb_buffer[color_idx + 2];
-      pt.rgba = static_cast<uint32_t> (color.long_value);
+      pt.rgba = static_cast<std::uint32_t> (color.long_value);
     }
   }
   return (cloud);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-pcl::PointCloud<pcl::PointXYZI>::Ptr ONIGrabber::convertToXYZIPointCloud(const boost::shared_ptr<openni_wrapper::IRImage> &ir_image,
-  const boost::shared_ptr<openni_wrapper::DepthImage> &depth_image) const
+pcl::PointCloud<pcl::PointXYZI>::Ptr ONIGrabber::convertToXYZIPointCloud(const openni_wrapper::IRImage::Ptr &ir_image,
+  const openni_wrapper::DepthImage::Ptr &depth_image) const
 {
-  boost::shared_ptr<pcl::PointCloud<pcl::PointXYZI> > cloud(new pcl::PointCloud<pcl::PointXYZI > ());
+  pcl::PointCloud<pcl::PointXYZI>::Ptr cloud(new pcl::PointCloud<pcl::PointXYZI>);
 
   cloud->header.frame_id = rgb_frame_id_;
   cloud->height = depth_height_;
@@ -584,17 +588,17 @@ pcl::PointCloud<pcl::PointXYZI>::Ptr ONIGrabber::convertToXYZIPointCloud(const b
   cloud->points.resize(cloud->height * cloud->width);
 
   float constant = 1.0f / device_->getImageFocalLength(cloud->width);
-  register int centerX = (cloud->width >> 1);
+  int centerX = (cloud->width >> 1);
   int centerY = (cloud->height >> 1);
 
-  register const XnDepthPixel* depth_map = depth_image->getDepthMetaData().Data();
-  register const XnIRPixel* ir_map = ir_image->getMetaData().Data();
+  const XnDepthPixel* depth_map = depth_image->getDepthMetaData().Data();
+  const XnIRPixel* ir_map = ir_image->getMetaData().Data();
 
   if (depth_image->getWidth() != depth_width_ || depth_image->getHeight() != depth_height_)
   {
     static unsigned buffer_size = 0;
-    static boost::shared_array<unsigned short> depth_buffer((unsigned short*)(NULL));
-    static boost::shared_array<unsigned short> ir_buffer((unsigned short*)(NULL));
+    static boost::shared_array<unsigned short> depth_buffer((unsigned short*)nullptr);
+    static boost::shared_array<unsigned short> ir_buffer((unsigned short*)nullptr);
 
     if (buffer_size < depth_width_ * depth_height_)
     {
@@ -610,14 +614,14 @@ pcl::PointCloud<pcl::PointXYZI>::Ptr ONIGrabber::convertToXYZIPointCloud(const b
     ir_map = ir_buffer.get ();
   }
 
-  register int depth_idx = 0;
+  int depth_idx = 0;
   float bad_point = std::numeric_limits<float>::quiet_NaN();
 
   for (int v = -centerY; v < centerY; ++v)
   {
-    for (register int u = -centerX; u < centerX; ++u, ++depth_idx)
+    for (int u = -centerX; u < centerX; ++u, ++depth_idx)
     {
-      pcl::PointXYZI& pt = cloud->points[depth_idx];
+      pcl::PointXYZI& pt = (*cloud)[depth_idx];
       /// @todo Different values for these cases
       // Check for invalid measurements
       if (depth_map[depth_idx] == 0 ||
