@@ -37,10 +37,9 @@
 
 #pragma once
 
-#include <pcl/common/common.h>
+#include <pcl/pcl_exports.h> // for PCL_EXPORTS
 
 #include <istream>
-#include <ostream>
 
 namespace pcl {
 
