@@ -39,10 +39,13 @@
 #ifndef PCL_SVM_WRAPPER_HPP_
 #define PCL_SVM_WRAPPER_HPP_
 
-#include <cassert>
-#include <fstream>
 #include <pcl/ml/svm_wrapper.h>
 
+#include <cassert>
+#include <cmath>   // for isfinite
+#include <cstring> // for strrchr
+#include <fstream>
+
 char*
 pcl::SVM::readline(FILE* input)
 {
@@ -145,7 +148,7 @@ pcl::SVMTrain::scaleFactors(std::vector<SVMData> training_set, svm_scaling& scal
 };
 
 void
-pcl::SVM::adaptLibSVMToInput(std::vector<SVMData>& training_set, svm_problem prob)
+pcl::SVM::adaptLibSVMToInput(std::vector<SVMData>& training_set, svm_problem prob) const
 {
   training_set.clear(); // Reset input
 
