@@ -4,7 +4,7 @@
  *  Point Cloud Library (PCL) - www.pointclouds.org
  *  Copyright (c) 2010-2011, Willow Garage, Inc.
  *
- *  All rights reserved. 
+ *  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -45,6 +45,10 @@
 #include <pcl/point_types.h>
 #include <pcl/recognition/point_types.h>
 
+#include <algorithm>
+#include <cstddef>
+#include <list>
+#include <vector>
 
 namespace pcl
 {
@@ -491,7 +495,7 @@ pcl::ColorModality<PointInT>::computeDistanceMap (const MaskMap & input,
   output.resize (width, height);
 
   // compute distance map
-  //float *distance_map = new float[input_->points.size ()];
+  //float *distance_map = new float[input_->size ()];
   const unsigned char * mask_map = input.getData ();
   float * distance_map = output.getData ();
   for (std::size_t index = 0; index < width*height; ++index)
