@@ -4,7 +4,7 @@
  *  Point Cloud Library (PCL) - www.pointclouds.org
  *  Copyright (c) 2010-2012, Willow Garage, Inc.
  *
- *  All rights reserved. 
+ *  All rights reserved.
  *
  *  Redistribution and use in source and binary forms, with or without
  *  modification, are permitted provided that the following conditions
@@ -44,17 +44,20 @@
 #include <pcl/point_cloud.h>
 #include <limits>
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
+namespace pcl
+{
+
 template <typename PointXYZT, typename PointRGBT> bool
-pcl::LineRGBD<PointXYZT, PointRGBT>::readLTMHeader (int fd, pcl::io::TARHeader &header)
+LineRGBD<PointXYZT, PointRGBT>::readLTMHeader (int fd, pcl::io::TARHeader &header)
 {
   // Read in the header
-  int result = static_cast<int> (::read (fd, reinterpret_cast<char*> (&header.file_name[0]), 512));
+  int result = static_cast<int> (io::raw_read (fd, reinterpret_cast<char*> (&header.file_name[0]), 512));
   if (result == -1)
     return (false);
 
-  // We only support regular files for now. 
-  // Additional file types in TAR include: hard links, symbolic links, device/special files, block devices, 
+  // We only support regular files for now.
+  // Additional file types in TAR include: hard links, symbolic links, device/special files, block devices,
   // directories, and named pipes.
   if (header.file_type[0] != '0' && header.file_type[0] != '\0')
     return (false);
@@ -69,15 +72,15 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::readLTMHeader (int fd, pcl::io::TARHeader &
   return (true);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointXYZT, typename PointRGBT> bool
-pcl::LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name, const std::size_t object_id)
+LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name, const std::size_t object_id)
 {
   // Open the file
   int ltm_fd = io::raw_open(file_name.c_str (), O_RDONLY);
   if (ltm_fd == -1)
     return (false);
-  
+
   int ltm_offset = 0;
 
   pcl::io::TARHeader ltm_header;
@@ -115,7 +118,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name
 
       unsigned int fsize = ltm_header.getFileSize ();
       char *buffer = new char[fsize];
-      int result = static_cast<int> (::read (ltm_fd, reinterpret_cast<char*> (&buffer[0]), fsize));
+      int result = static_cast<int> (io::raw_read (ltm_fd, reinterpret_cast<char*> (&buffer[0]), fsize));
       if (result == -1)
       {
         delete [] buffer;
@@ -166,7 +169,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name
     std::size_t counter = 0;
     for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
-      const PointXYZRGBA & p = template_point_cloud.points[j];
+      const PointXYZRGBA & p = template_point_cloud[j];
 
       if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
@@ -199,7 +202,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name
 
     for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
-      PointXYZRGBA p = template_point_cloud.points[j];
+      PointXYZRGBA p = template_point_cloud[j];
 
       if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
@@ -208,16 +211,16 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::loadTemplates (const std::string &file_name
       p.y -= center_y;
       p.z -= center_z;
 
-      template_point_cloud.points[j] = p;
+      template_point_cloud[j] = p;
     }
   }
 
   return (true);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointXYZT, typename PointRGBT> int
-pcl::LineRGBD<PointXYZT, PointRGBT>::createAndAddTemplate (
+LineRGBD<PointXYZT, PointRGBT>::createAndAddTemplate (
   pcl::PointCloud<pcl::PointXYZRGBA> & cloud,
   const std::size_t object_id,
   const MaskMap & mask_xyz,
@@ -253,7 +256,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::createAndAddTemplate (
     std::size_t counter = 0;
     for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
-      const PointXYZRGBA & p = template_point_cloud.points[j];
+      const PointXYZRGBA & p = template_point_cloud[j];
 
       if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
@@ -286,7 +289,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::createAndAddTemplate (
 
     for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
-      PointXYZRGBA p = template_point_cloud.points[j];
+      PointXYZRGBA p = template_point_cloud[j];
 
       if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
@@ -295,7 +298,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::createAndAddTemplate (
       p.y -= center_y;
       p.z -= center_z;
 
-      template_point_cloud.points[j] = p;
+      template_point_cloud[j] = p;
     }
   }
 
@@ -311,9 +314,8 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::createAndAddTemplate (
 }
 
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointXYZT, typename PointRGBT> bool
-pcl::LineRGBD<PointXYZT, PointRGBT>::addTemplate (const SparseQuantizedMultiModTemplate & sqmmt, pcl::PointCloud<pcl::PointXYZRGBA> & cloud, std::size_t object_id)
+LineRGBD<PointXYZT, PointRGBT>::addTemplate (const SparseQuantizedMultiModTemplate & sqmmt, pcl::PointCloud<pcl::PointXYZRGBA> & cloud, std::size_t object_id)
 {
   // add point cloud
   template_point_clouds_.resize (template_point_clouds_.size () + 1);
@@ -345,7 +347,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::addTemplate (const SparseQuantizedMultiModT
     std::size_t counter = 0;
     for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
-      const PointXYZRGBA & p = template_point_cloud.points[j];
+      const PointXYZRGBA & p = template_point_cloud[j];
 
       if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
@@ -378,7 +380,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::addTemplate (const SparseQuantizedMultiModT
 
     for (std::size_t j = 0; j < template_point_cloud.size (); ++j)
     {
-      PointXYZRGBA p = template_point_cloud.points[j];
+      PointXYZRGBA p = template_point_cloud[j];
 
       if (!std::isfinite (p.x) || !std::isfinite (p.y) || !std::isfinite (p.z))
         continue;
@@ -387,16 +389,16 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::addTemplate (const SparseQuantizedMultiModT
       p.y -= center_y;
       p.z -= center_z;
 
-      template_point_cloud.points[j] = p;
+      template_point_cloud[j] = p;
     }
   }
 
   return (true);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-template <typename PointXYZT, typename PointRGBT> void 
-pcl::LineRGBD<PointXYZT, PointRGBT>::detect (
+
+template <typename PointXYZT, typename PointRGBT> void
+LineRGBD<PointXYZT, PointRGBT>::detect (
     std::vector<typename pcl::LineRGBD<PointXYZT, PointRGBT>::Detection> & detections)
 {
   std::vector<pcl::QuantizableModality*> modalities;
@@ -421,11 +423,11 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detect (
     detection.response = linemod_detection.score;
 
     // compute bounding box:
-    // we assume that the bounding boxes of the templates are relative to the center of mass 
+    // we assume that the bounding boxes of the templates are relative to the center of mass
     // of the template points; so we also compute the center of mass of the points
-    // covered by the 
+    // covered by the
 
-    const pcl::SparseQuantizedMultiModTemplate & linemod_template = 
+    const pcl::SparseQuantizedMultiModTemplate & linemod_template =
       linemod_.getTemplate (linemod_detection.template_id);
 
     const std::size_t start_x = std::max (linemod_detection.x, 0);
@@ -492,9 +494,9 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detect (
   }
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-template <typename PointXYZT, typename PointRGBT> void 
-pcl::LineRGBD<PointXYZT, PointRGBT>::detectSemiScaleInvariant (
+
+template <typename PointXYZT, typename PointRGBT> void
+LineRGBD<PointXYZT, PointRGBT>::detectSemiScaleInvariant (
     std::vector<typename pcl::LineRGBD<PointXYZT, PointRGBT>::Detection> & detections,
     const float min_scale,
     const float max_scale,
@@ -522,11 +524,11 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detectSemiScaleInvariant (
     detection.response = linemod_detection.score;
 
     // compute bounding box:
-    // we assume that the bounding boxes of the templates are relative to the center of mass 
+    // we assume that the bounding boxes of the templates are relative to the center of mass
     // of the template points; so we also compute the center of mass of the points
-    // covered by the 
+    // covered by the
 
-    const pcl::SparseQuantizedMultiModTemplate & linemod_template = 
+    const pcl::SparseQuantizedMultiModTemplate & linemod_template =
       linemod_.getTemplate (linemod_detection.template_id);
 
     const std::size_t start_x = std::max (linemod_detection.x, 0);
@@ -593,9 +595,9 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::detectSemiScaleInvariant (
   }
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-template <typename PointXYZT, typename PointRGBT> void 
-pcl::LineRGBD<PointXYZT, PointRGBT>::computeTransformedTemplatePoints (
+
+template <typename PointXYZT, typename PointRGBT> void
+LineRGBD<PointXYZT, PointRGBT>::computeTransformedTemplatePoints (
     const std::size_t detection_id, pcl::PointCloud<pcl::PointXYZRGBA> &cloud)
 {
   if (detection_id >= detections_.size ())
@@ -607,11 +609,11 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::computeTransformedTemplatePoints (
   const pcl::BoundingBoxXYZ & template_bounding_box = bounding_boxes_[template_id];
   const pcl::BoundingBoxXYZ & detection_bounding_box = detections_[detection_id].bounding_box;
 
-  //std::cerr << "detection: " 
+  //std::cerr << "detection: "
   //  << detection_bounding_box.x << ", "
   //  << detection_bounding_box.y << ", "
   //  << detection_bounding_box.z << std::endl;
-  //std::cerr << "template: " 
+  //std::cerr << "template: "
   //  << template_bounding_box.x << ", "
   //  << template_bounding_box.y << ", "
   //  << template_bounding_box.z << std::endl;
@@ -619,7 +621,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::computeTransformedTemplatePoints (
   const float translation_y = detection_bounding_box.y - template_bounding_box.y;
   const float translation_z = detection_bounding_box.z - template_bounding_box.z;
 
-  //std::cerr << "translation: " 
+  //std::cerr << "translation: "
   //  << translation_x << ", "
   //  << translation_y << ", "
   //  << translation_z << std::endl;
@@ -630,19 +632,19 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::computeTransformedTemplatePoints (
   cloud.height = template_point_cloud.height;
   for (std::size_t point_index = 0; point_index < nr_points; ++point_index)
   {
-    pcl::PointXYZRGBA point = template_point_cloud.points[point_index];
+    pcl::PointXYZRGBA point = template_point_cloud[point_index];
 
     point.x += translation_x;
     point.y += translation_y;
     point.z += translation_z;
 
-    cloud.points[point_index] = point;
+    cloud[point_index] = point;
   }
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-template <typename PointXYZT, typename PointRGBT> void 
-pcl::LineRGBD<PointXYZT, PointRGBT>::refineDetectionsAlongDepth ()
+
+template <typename PointXYZT, typename PointRGBT> void
+LineRGBD<PointXYZT, PointRGBT>::refineDetectionsAlongDepth ()
 {
   const std::size_t nr_detections = detections_.size ();
   for (std::size_t detection_index = 0; detection_index < nr_detections; ++detection_index)
@@ -692,7 +694,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::refineDetectionsAlongDepth ()
     }
 
     std::vector<std::size_t> integral_depth_bins (nr_bins, 0);
-    
+
     integral_depth_bins[0] = depth_bins[0];
     for (std::size_t bin_index = 1; bin_index < nr_bins; ++bin_index)
     {
@@ -720,9 +722,9 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::refineDetectionsAlongDepth ()
   }
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-template <typename PointXYZT, typename PointRGBT> void 
-pcl::LineRGBD<PointXYZT, PointRGBT>::applyProjectiveDepthICPOnDetections ()
+
+template <typename PointXYZT, typename PointRGBT> void
+LineRGBD<PointXYZT, PointRGBT>::applyProjectiveDepthICPOnDetections ()
 {
   const std::size_t nr_detections = detections_.size ();
   for (std::size_t detection_index = 0; detection_index < nr_detections; ++detection_index)
@@ -736,7 +738,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::applyProjectiveDepthICPOnDetections ()
     const std::size_t start_y = detection.region.y;
     const std::size_t pc_width = point_cloud.width;
     const std::size_t pc_height = point_cloud.height;
-    
+
     std::vector<std::pair<float, float> > depth_matches;
     for (std::size_t row_index = 0; row_index < pc_height; ++row_index)
     {
@@ -801,9 +803,9 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::applyProjectiveDepthICPOnDetections ()
   }
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-template <typename PointXYZT, typename PointRGBT> void 
-pcl::LineRGBD<PointXYZT, PointRGBT>::removeOverlappingDetections ()
+
+template <typename PointXYZT, typename PointRGBT> void
+LineRGBD<PointXYZT, PointRGBT>::removeOverlappingDetections ()
 {
   // compute overlap between each detection
   const std::size_t nr_detections = detections_.size ();
@@ -820,7 +822,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::removeOverlappingDetections ()
         overlaps (detection_index_1, detection_index_2) = 0.0f;
       else
         overlaps (detection_index_1, detection_index_2) = computeBoundingBoxIntersectionVolume (
-          detections_[detection_index_1].bounding_box, 
+          detections_[detection_index_1].bounding_box,
           detections_[detection_index_2].bounding_box) / bounding_box_volume;
     }
   }
@@ -867,7 +869,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::removeOverlappingDetections ()
   for (std::size_t cluster_id = 0; cluster_id < nr_clusters; ++cluster_id)
   {
     std::vector<std::size_t> & cluster = clusters[cluster_id];
-    
+
     float average_center_x = 0.0f;
     float average_center_y = 0.0f;
     float average_center_z = 0.0f;
@@ -935,9 +937,9 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::removeOverlappingDetections ()
   detections_ = clustered_detections;
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////////////////////////
-template <typename PointXYZT, typename PointRGBT> float 
-pcl::LineRGBD<PointXYZT, PointRGBT>::computeBoundingBoxIntersectionVolume (
+
+template <typename PointXYZT, typename PointRGBT> float
+LineRGBD<PointXYZT, PointRGBT>::computeBoundingBoxIntersectionVolume (
   const BoundingBoxXYZ &box1, const BoundingBoxXYZ &box2)
 {
   const float x1_min = box1.x;
@@ -953,7 +955,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::computeBoundingBoxIntersectionVolume (
   const float x2_max = box2.x + box2.width;
   const float y2_max = box2.y + box2.height;
   const float z2_max = box2.z + box2.depth;
-  
+
   const float xi_min = std::max (x1_min, x2_min);
   const float yi_min = std::max (y1_min, y2_min);
   const float zi_min = std::max (z1_min, z2_min);
@@ -974,6 +976,7 @@ pcl::LineRGBD<PointXYZT, PointRGBT>::computeBoundingBoxIntersectionVolume (
   return (intersection_volume);
 }
 
+} // namespace pcl
 
-#endif        // PCL_RECOGNITION_LINEMOD_LINE_RGBD_IMPL_HPP_ 
+#endif        // PCL_RECOGNITION_LINEMOD_LINE_RGBD_IMPL_HPP_
 
