@@ -234,30 +234,24 @@ namespace pcl
 
             /** \brief Computes the "radius" of the node which is half the diagonal length. */
             inline float
-            getRadius (){ return radius_;}
+            getRadius () const{ return radius_;}
 
             bool
             createChildren ();
 
             inline void
             deleteChildren ()
-            {
-              if ( children_ )
               {
                 delete[] children_;
                 children_ = nullptr;
               }
-            }
 
             inline void
             deleteData ()
-            {
-              if ( data_ )
               {
                 delete data_;
                 data_ = nullptr;
               }
-            }
 
             /** \brief Make this and 'node' neighbors by inserting each node in the others node neighbor set. Nothing happens
               * of either of the nodes has no data. */
