@@ -8,6 +8,7 @@
 #include "pcl/recognition/face_detection/rf_face_detector_trainer.h"
 #include "pcl/recognition/face_detection/face_common.h"
 #include "pcl/io/pcd_io.h"
+#include <pcl/memory.h>  // for dynamic_pointer_cast
 #include "pcl/ml/dt/decision_tree_trainer.h"
 #include "pcl/ml/dt/decision_tree_evaluator.h"
 #include "pcl/ml/dt/decision_forest_trainer.h"
@@ -22,6 +23,7 @@
 #include <pcl/recognition/hv/hv_papazov.h>
 #include <pcl/features/normal_3d.h>
 
+
 void pcl::RFFaceDetectorTrainer::trainWithDataProvider()
 {
 
@@ -58,7 +60,7 @@ void pcl::RFFaceDetectorTrainer::trainWithDataProvider()
 
   dtdp->initialize (directory_);
 
-  auto cast_dtdp = boost::dynamic_pointer_cast<pcl::DecisionTreeTrainerDataProvider<face_detection::FeatureType, std::vector<face_detection::TrainingExample>, float, int, NodeType>> (dtdp);
+  auto cast_dtdp = dynamic_pointer_cast<pcl::DecisionTreeTrainerDataProvider<face_detection::FeatureType, std::vector<face_detection::TrainingExample>, float, int, NodeType>> (dtdp);
   dft.setDecisionTreeDataProvider (cast_dtdp);
 
   pcl::DecisionForest<NodeType> forest;
@@ -274,7 +276,7 @@ void pcl::RFFaceDetectorTrainer::detectFaces()
 
   int element_stride = sizeof(pcl::PointXYZ) / sizeof(float);
   int row_stride = element_stride * cloud->width;
-  const float *data = reinterpret_cast<const float*> (&cloud->points[0]);
+  const float *data = reinterpret_cast<const float*> (&(*cloud)[0]);
   integral_image_depth->setInput (data + 2, cloud->width, cloud->height, element_stride, row_stride);
 
   //Compute normals and normal integral images
@@ -300,15 +302,15 @@ void pcl::RFFaceDetectorTrainer::detectFaces()
   if (use_normals_)
   {
     integral_image_normal_x.reset (new pcl::IntegralImage2D<float, 1> (false));
-    const float *data_nx = reinterpret_cast<const float*> (&normals->points[0]);
+    const float *data_nx = reinterpret_cast<const float*> (&(*normals)[0]);
     integral_image_normal_x->setInput (data_nx, normals->width, normals->height, element_stride_normal, row_stride_normal);
 
     integral_image_normal_y.reset (new pcl::IntegralImage2D<float, 1> (false));
-    const float *data_ny = reinterpret_cast<const float*> (&normals->points[0]);
+    const float *data_ny = reinterpret_cast<const float*> (&(*normals)[0]);
     integral_image_normal_y->setInput (data_ny + 1, normals->width, normals->height, element_stride_normal, row_stride_normal);
 
     integral_image_normal_z.reset (new pcl::IntegralImage2D<float, 1> (false));
-    const float *data_nz = reinterpret_cast<const float*> (&normals->points[0]);
+    const float *data_nz = reinterpret_cast<const float*> (&(*normals)[0]);
     integral_image_normal_z->setInput (data_nz + 2, normals->width, normals->height, element_stride_normal, row_stride_normal);
   }
 
@@ -325,10 +327,7 @@ void pcl::RFFaceDetectorTrainer::detectFaces()
     pcl::TernaryTreeMissingDataBranchEstimator * btt = new pcl::TernaryTreeMissingDataBranchEstimator ();
     face_detection::PoseClassRegressionVarianceStatsEstimator<float, NodeType, std::vector<face_detection::TrainingExample>, int> rse (btt);
 
-    std::vector<float> weights;
-    weights.resize (cloud->points.size ());
-    for (std::size_t i = 0; i < cloud->points.size (); i++)
-      weights[i] = 0;
+    std::vector<float> weights(cloud->size(), 0.f);
 
     int w_size_2 = static_cast<int> (w_size_ / 2);
 
@@ -411,15 +410,15 @@ void pcl::RFFaceDetectorTrainer::detectFaces()
     if (face_heat_map_)
     {
       face_heat_map_.reset (new pcl::PointCloud<pcl::PointXYZI>);
-      face_heat_map_->resize (cloud->points.size ());
+      face_heat_map_->resize (cloud->size ());
       face_heat_map_->height = 1;
-      face_heat_map_->width = static_cast<unsigned int>(cloud->points.size ());
+      face_heat_map_->width = cloud->size ();
       face_heat_map_->is_dense = false;
 
-      for (std::size_t i = 0; i < cloud->points.size (); i++)
+      for (std::size_t i = 0; i < cloud->size (); i++)
       {
-        face_heat_map_->points[i].getVector4fMap () = cloud->points[i].getVector4fMap ();
-        face_heat_map_->points[i].intensity = weights[i];
+        (*face_heat_map_)[i].getVector4fMap () = (*cloud)[i].getVector4fMap ();
+        (*face_heat_map_)[i].intensity = weights[i];
       }
     }
   }
