@@ -38,12 +38,19 @@
  *
  */
 
+
 #ifndef PCL_REGISTRATION_CORRESPONDENCE_ESTIMATION_ORGANIZED_PROJECTION_IMPL_HPP_
 #define PCL_REGISTRATION_CORRESPONDENCE_ESTIMATION_ORGANIZED_PROJECTION_IMPL_HPP_
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
+namespace pcl
+{
+
+namespace registration
+{
+
 template <typename PointSource, typename PointTarget, typename Scalar> bool
-pcl::registration::CorrespondenceEstimationOrganizedProjection<PointSource, PointTarget, Scalar>::initCompute ()
+CorrespondenceEstimationOrganizedProjection<PointSource, PointTarget, Scalar>::initCompute ()
 {
   // Set the target_cloud_updated_ variable to true, so that the kd-tree is not built - it is not needed for this class
   target_cloud_updated_ = false;
@@ -66,9 +73,9 @@ pcl::registration::CorrespondenceEstimationOrganizedProjection<PointSource, Poin
   return (true);
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointSource, typename PointTarget, typename Scalar> void
-pcl::registration::CorrespondenceEstimationOrganizedProjection<PointSource, PointTarget, Scalar>::determineCorrespondences (
+CorrespondenceEstimationOrganizedProjection<PointSource, PointTarget, Scalar>::determineCorrespondences (
     pcl::Correspondences &correspondences,
     double max_distance)
 {
@@ -80,9 +87,9 @@ pcl::registration::CorrespondenceEstimationOrganizedProjection<PointSource, Poin
 
   for (std::vector<int>::const_iterator src_it = indices_->begin (); src_it != indices_->end (); ++src_it)
   {
-    if (isFinite (input_->points[*src_it]))
+    if (isFinite ((*input_)[*src_it]))
     {
-      Eigen::Vector4f p_src (src_to_tgt_transformation_ * input_->points[*src_it].getVector4fMap ());
+      Eigen::Vector4f p_src (src_to_tgt_transformation_ * (*input_)[*src_it].getVector4fMap ());
       Eigen::Vector3f p_src3 (p_src[0], p_src[1], p_src[2]);
       Eigen::Vector3f uv (projection_matrix_ * p_src3);
 
@@ -113,9 +120,9 @@ pcl::registration::CorrespondenceEstimationOrganizedProjection<PointSource, Poin
   correspondences.resize (c_index);
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointSource, typename PointTarget, typename Scalar> void
-pcl::registration::CorrespondenceEstimationOrganizedProjection<PointSource, PointTarget, Scalar>::determineReciprocalCorrespondences (
+CorrespondenceEstimationOrganizedProjection<PointSource, PointTarget, Scalar>::determineReciprocalCorrespondences (
     pcl::Correspondences &correspondences,
     double max_distance)
 {
@@ -123,5 +130,8 @@ pcl::registration::CorrespondenceEstimationOrganizedProjection<PointSource, Poin
   determineCorrespondences (correspondences, max_distance);
 }
 
+} // namespace registration
+} // namespace pcl
+
 #endif    // PCL_REGISTRATION_CORRESPONDENCE_ESTIMATION_ORGANIZED_PROJECTION_IMPL_HPP_
 
