@@ -38,9 +38,13 @@
  *
  */
 
-///////////////////////////////////////////////////////////////////////////////////////////
+#pragma once
+
+namespace pcl
+{
+
 template <typename PointSource, typename PointTarget, typename Scalar> inline void
-pcl::Registration<PointSource, PointTarget, Scalar>::setInputTarget (const PointCloudTargetConstPtr &cloud)
+Registration<PointSource, PointTarget, Scalar>::setInputTarget (const PointCloudTargetConstPtr &cloud)
 {
   if (cloud->points.empty ())
   {
@@ -51,9 +55,9 @@ pcl::Registration<PointSource, PointTarget, Scalar>::setInputTarget (const Point
   target_cloud_updated_ = true;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointSource, typename PointTarget, typename Scalar> bool
-pcl::Registration<PointSource, PointTarget, Scalar>::initCompute ()
+Registration<PointSource, PointTarget, Scalar>::initCompute ()
 {
   if (!target_)
   {
@@ -68,23 +72,22 @@ pcl::Registration<PointSource, PointTarget, Scalar>::initCompute ()
     target_cloud_updated_ = false;
   }
 
-  
   // Update the correspondence estimation
   if (correspondence_estimation_)
   {
     correspondence_estimation_->setSearchMethodTarget (tree_, force_no_recompute_);
     correspondence_estimation_->setSearchMethodSource (tree_reciprocal_, force_no_recompute_reciprocal_);
   }
-  
+
   // Note: we /cannot/ update the search method on all correspondence rejectors, because we know 
   // nothing about them. If they should be cached, they must be cached individually.
 
   return (PCLBase<PointSource>::initCompute ());
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointSource, typename PointTarget, typename Scalar> bool
-pcl::Registration<PointSource, PointTarget, Scalar>::initComputeReciprocal ()
+Registration<PointSource, PointTarget, Scalar>::initComputeReciprocal ()
 {
   if (!input_)
   {
@@ -100,9 +103,9 @@ pcl::Registration<PointSource, PointTarget, Scalar>::initComputeReciprocal ()
   return (true);
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointSource, typename PointTarget, typename Scalar> inline double
-pcl::Registration<PointSource, PointTarget, Scalar>::getFitnessScore (
+Registration<PointSource, PointTarget, Scalar>::getFitnessScore (
     const std::vector<float> &distances_a,
     const std::vector<float> &distances_b)
 {
@@ -112,11 +115,10 @@ pcl::Registration<PointSource, PointTarget, Scalar>::getFitnessScore (
   return (static_cast<double> ((map_a - map_b).sum ()) / static_cast<double> (nr_elem));
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
-template <typename PointSource, typename PointTarget, typename Scalar> inline double
-pcl::Registration<PointSource, PointTarget, Scalar>::getFitnessScore (double max_range)
-{
 
+template <typename PointSource, typename PointTarget, typename Scalar> inline double
+Registration<PointSource, PointTarget, Scalar>::getFitnessScore (double max_range)
+{
   double fitness_score = 0.0;
 
   // Transform the input dataset using the final transformation
@@ -128,11 +130,11 @@ pcl::Registration<PointSource, PointTarget, Scalar>::getFitnessScore (double max
 
   // For each point in the source dataset
   int nr = 0;
-  for (std::size_t i = 0; i < input_transformed.points.size (); ++i)
+  for (const auto& point: input_transformed)
   {
     // Find its nearest neighbor in the target
-    tree_->nearestKSearch (input_transformed.points[i], 1, nn_indices, nn_dists);
-    
+    tree_->nearestKSearch (point, 1, nn_indices, nn_dists);
+
     // Deal with occlusions (incomplete targets)
     if (nn_dists[0] <= max_range)
     {
@@ -148,29 +150,28 @@ pcl::Registration<PointSource, PointTarget, Scalar>::getFitnessScore (double max
 
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointSource, typename PointTarget, typename Scalar> inline void
-pcl::Registration<PointSource, PointTarget, Scalar>::align (PointCloudSource &output)
+Registration<PointSource, PointTarget, Scalar>::align (PointCloudSource &output)
 {
   align (output, Matrix4::Identity ());
 }
 
-//////////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointSource, typename PointTarget, typename Scalar> inline void
-pcl::Registration<PointSource, PointTarget, Scalar>::align (PointCloudSource &output, const Matrix4& guess)
+Registration<PointSource, PointTarget, Scalar>::align (PointCloudSource &output, const Matrix4& guess)
 {
-  if (!initCompute ()) 
+  if (!initCompute ())
     return;
 
   // Resize the output dataset
-  if (output.points.size () != indices_->size ())
-    output.points.resize (indices_->size ());
+  output.resize (indices_->size ());
   // Copy the header
   output.header   = input_->header;
   // Check if the output will be computed for all points or only a subset
-  if (indices_->size () != input_->points.size ())
+  if (indices_->size () != input_->size ())
   {
-    output.width    = static_cast<std::uint32_t> (indices_->size ());
+    output.width    = indices_->size ();
     output.height   = 1;
   }
   else
@@ -182,7 +183,7 @@ pcl::Registration<PointSource, PointTarget, Scalar>::align (PointCloudSource &ou
 
   // Copy the point data to output
   for (std::size_t i = 0; i < indices_->size (); ++i)
-    output.points[i] = input_->points[(*indices_)[i]];
+    output[i] = (*input_)[(*indices_)[i]];
 
   // Set the internal point representation of choice unless otherwise noted
   if (point_representation_ && !force_no_recompute_) 
@@ -195,10 +196,12 @@ pcl::Registration<PointSource, PointTarget, Scalar>::align (PointCloudSource &ou
   // Right before we estimate the transformation, we set all the point.data[3] values to 1 to aid the rigid 
   // transformation
   for (std::size_t i = 0; i < indices_->size (); ++i)
-    output.points[i].data[3] = 1.0;
+    output[i].data[3] = 1.0;
 
   computeTransformation (output, guess);
 
   deinitCompute ();
 }
 
+} // namespace pcl
+
