@@ -40,10 +40,9 @@
 
 #pragma once
 
-#include <pcl/pcl_macros.h>
+#include <pcl/memory.h>
 #include <pcl/registration/transformation_estimation.h>
 #include <pcl/registration/warp_point_rigid.h>
-#include <pcl/registration/distances.h>
 
 namespace pcl
 {
