@@ -39,6 +39,7 @@
 #pragma once
 
 #include <pcl/sample_consensus/sac_model_registration.h>
+#include <pcl/memory.h>
 #include <pcl/pcl_macros.h>
 
 namespace pcl
@@ -91,7 +92,7 @@ namespace pcl
         * \param[in] random if true set the random seed to the current time, else set to 12345 (default: false)
         */
       SampleConsensusModelRegistration2D (const PointCloudConstPtr &cloud,
-                                          const std::vector<int> &indices,
+                                          const Indices &indices,
                                           bool random = false)
         : pcl::SampleConsensusModelRegistration<PointT> (cloud, indices, random)
         , projection_matrix_ (Eigen::Matrix3f::Identity ())
@@ -122,7 +123,7 @@ namespace pcl
       void
       selectWithinDistance (const Eigen::VectorXf &model_coefficients,
                             const double threshold,
-                            std::vector<int> &inliers);
+                            Indices &inliers);
 
       /** \brief Count all the points which respect the given model coefficients as inliers.
         *
@@ -155,7 +156,7 @@ namespace pcl
         * \param[in] samples the resultant index samples
         */
       bool
-      isSampleGood (const std::vector<int> &samples) const;
+      isSampleGood (const Indices &samples) const;
 
       /** \brief Computes an "optimal" sample distance threshold based on the
         * principal directions of the input cloud.
@@ -189,7 +190,7 @@ namespace pcl
         */
       inline void
       computeSampleDistanceThreshold (const PointCloudConstPtr&,
-                                      const std::vector<int>&)
+                                      const Indices&)
       {
         //// Compute the principal directions via PCA
         //Eigen::Vector4f xyz_centroid;
