@@ -102,24 +102,30 @@ namespace pcl
       unsigned int min_pts_per_cluster = 1,
       unsigned int max_pts_per_cluster = (std::numeric_limits<int>::max) ())
   {
-    if (tree->getInputCloud ()->points.size () != cloud.points.size ())
+    if (tree->getInputCloud ()->size () != cloud.size ())
     {
-      PCL_ERROR ("[pcl::extractEuclideanClusters] Tree built for a different point cloud dataset (%lu) than the input cloud (%lu)!\n", tree->getInputCloud ()->points.size (), cloud.points.size ());
+      PCL_ERROR("[pcl::extractEuclideanClusters] Tree built for a different point "
+                "cloud dataset (%zu) than the input cloud (%zu)!\n",
+                static_cast<std::size_t>(tree->getInputCloud()->size()),
+                static_cast<std::size_t>(cloud.size()));
       return;
     }
-    if (cloud.points.size () != normals.points.size ())
+    if (cloud.size () != normals.size ())
     {
-      PCL_ERROR ("[pcl::extractEuclideanClusters] Number of points in the input point cloud (%lu) different than normals (%lu)!\n", cloud.points.size (), normals.points.size ());
+      PCL_ERROR("[pcl::extractEuclideanClusters] Number of points in the input point "
+                "cloud (%zu) different than normals (%zu)!\n",
+                static_cast<std::size_t>(cloud.size()),
+                static_cast<std::size_t>(normals.size()));
       return;
     }
 
     // Create a bool vector of processed point indices, and initialize it to false
-    std::vector<bool> processed (cloud.points.size (), false);
+    std::vector<bool> processed (cloud.size (), false);
 
     std::vector<int> nn_indices;
     std::vector<float> nn_distances;
     // Process all points in the indices vector
-    for (std::size_t i = 0; i < cloud.points.size (); ++i)
+    for (std::size_t i = 0; i < cloud.size (); ++i)
     {
       if (processed[i])
         continue;
@@ -146,10 +152,10 @@ namespace pcl
 
           //processed[nn_indices[j]] = true;
           // [-1;1]
-          double dot_p = normals.points[i].normal[0] * normals.points[nn_indices[j]].normal[0] +
-                         normals.points[i].normal[1] * normals.points[nn_indices[j]].normal[1] +
-                         normals.points[i].normal[2] * normals.points[nn_indices[j]].normal[2];
-          if ( std::abs (std::acos (dot_p)) < eps_angle )
+          double dot_p = normals[i].normal[0] * normals[nn_indices[j]].normal[0] +
+                         normals[i].normal[1] * normals[nn_indices[j]].normal[1] +
+                         normals[i].normal[2] * normals[nn_indices[j]].normal[2];
+          if ( std::acos (std::abs (dot_p)) < eps_angle )
           {
             processed[nn_indices[j]] = true;
             seed_queue.push_back (nn_indices[j]);
@@ -203,23 +209,29 @@ namespace pcl
   {
     // \note If the tree was created over <cloud, indices>, we guarantee a 1-1 mapping between what the tree returns
     //and indices[i]
-    if (tree->getInputCloud ()->points.size () != cloud.points.size ())
-    {
-      PCL_ERROR ("[pcl::extractEuclideanClusters] Tree built for a different point cloud dataset (%lu) than the input cloud (%lu)!\n", tree->getInputCloud ()->points.size (), cloud.points.size ());
+    if (tree->getInputCloud()->size() != cloud.size()) {
+      PCL_ERROR("[pcl::extractEuclideanClusters] Tree built for a different point "
+                "cloud dataset (%zu) than the input cloud (%zu)!\n",
+                static_cast<std::size_t>(tree->getInputCloud()->size()),
+                static_cast<std::size_t>(cloud.size()));
       return;
     }
-    if (tree->getIndices ()->size () != indices.size ())
-    {
-      PCL_ERROR ("[pcl::extractEuclideanClusters] Tree built for a different set of indices (%lu) than the input set (%lu)!\n", tree->getIndices ()->size (), indices.size ());
+    if (tree->getIndices()->size() != indices.size()) {
+      PCL_ERROR("[pcl::extractEuclideanClusters] Tree built for a different set of "
+                "indices (%zu) than the input set (%zu)!\n",
+                static_cast<std::size_t>(tree->getIndices()->size()),
+                indices.size());
       return;
     }
-    if (cloud.points.size () != normals.points.size ())
-    {
-      PCL_ERROR ("[pcl::extractEuclideanClusters] Number of points in the input point cloud (%lu) different than normals (%lu)!\n", cloud.points.size (), normals.points.size ());
+    if (cloud.size() != normals.size()) {
+      PCL_ERROR("[pcl::extractEuclideanClusters] Number of points in the input point "
+                "cloud (%zu) different than normals (%zu)!\n",
+                static_cast<std::size_t>(cloud.size()),
+                static_cast<std::size_t>(normals.size()));
       return;
     }
     // Create a bool vector of processed point indices, and initialize it to false
-    std::vector<bool> processed (cloud.points.size (), false);
+    std::vector<bool> processed (cloud.size (), false);
 
     std::vector<int> nn_indices;
     std::vector<float> nn_distances;
@@ -238,7 +250,7 @@ namespace pcl
       while (sq_idx < static_cast<int> (seed_queue.size ()))
       {
         // Search for sq_idx
-        if (!tree->radiusSearch (cloud.points[seed_queue[sq_idx]], tolerance, nn_indices, nn_distances))
+        if (!tree->radiusSearch (cloud[seed_queue[sq_idx]], tolerance, nn_indices, nn_distances))
         {
           sq_idx++;
           continue;
@@ -252,10 +264,10 @@ namespace pcl
           //processed[nn_indices[j]] = true;
           // [-1;1]
           double dot_p =
-            normals.points[indices[i]].normal[0] * normals.points[indices[nn_indices[j]]].normal[0] +
-            normals.points[indices[i]].normal[1] * normals.points[indices[nn_indices[j]]].normal[1] +
-            normals.points[indices[i]].normal[2] * normals.points[indices[nn_indices[j]]].normal[2];
-          if ( std::abs (std::acos (dot_p)) < eps_angle )
+            normals[indices[i]].normal[0] * normals[indices[nn_indices[j]]].normal[0] +
+            normals[indices[i]].normal[1] * normals[indices[nn_indices[j]]].normal[1] +
+            normals[indices[i]].normal[2] * normals[indices[nn_indices[j]]].normal[2];
+          if ( std::acos (std::abs (dot_p)) < eps_angle )
           {
             processed[nn_indices[j]] = true;
             seed_queue.push_back (nn_indices[j]);
