@@ -225,7 +225,7 @@ pcl::CrfSegmentation<PointT>::createDataVectorFromVoxelGrid ()
         if (index != -1)
         {
           data_.push_back (Eigen::Vector3i (i, j, k));
-          color_.push_back (input_cloud_->points[index].getRGBVector3i ());
+          color_.push_back ((*input_cloud_)[index].getRGBVector3i ());
         }
       }
     }
@@ -244,7 +244,7 @@ pcl::CrfSegmentation<PointT>::createDataVectorFromVoxelGrid ()
 
 
   // reserve space for the data vector
-  data_.resize (filtered_cloud_->points.size ());
+  data_.resize (filtered_cloud_->size ());
 
   std::vector< pcl::PCLPointField > fields;
   // check if we have color data
@@ -256,7 +256,7 @@ pcl::CrfSegmentation<PointT>::createDataVectorFromVoxelGrid ()
   if (rgba_index >= 0)
   {
     color_data = true;
-    color_.resize (filtered_cloud_->points.size ());    
+    color_.resize (filtered_cloud_->size ());    
   }
 
 
@@ -268,22 +268,22 @@ pcl::CrfSegmentation<PointT>::createDataVectorFromVoxelGrid ()
   if (rgba_index >= 0)
   {
     normal_data = true;
-    normal_.resize (filtered_cloud_->points.size ());    
+    normal_.resize (filtered_cloud_->size ());    
   }
 */
 
   // fill the data vector
-  for (std::size_t i = 0; i < filtered_cloud_->points.size (); i++)
+  for (std::size_t i = 0; i < filtered_cloud_->size (); i++)
   {
-    Eigen::Vector3f p (filtered_anno_->points[i].x,
-                       filtered_anno_->points[i].y,
-                       filtered_anno_->points[i].z);
+    Eigen::Vector3f p ((*filtered_anno_)[i].x,
+                       (*filtered_anno_)[i].y,
+                       (*filtered_anno_)[i].z);
     Eigen::Vector3i c = voxel_grid_.getGridCoordinates (p.x (), p.y (), p.y ());
     data_[i] = c;
 
     if (color_data)
     {    
-      std::uint32_t rgb = *reinterpret_cast<int*>(&filtered_cloud_->points[i].rgba);
+      std::uint32_t rgb = *reinterpret_cast<int*>(&(*filtered_cloud_)[i].rgba);
       std::uint8_t r = (rgb >> 16) & 0x0000ff;
       std::uint8_t g = (rgb >> 8)  & 0x0000ff;
       std::uint8_t b = (rgb)       & 0x0000ff;
@@ -293,20 +293,20 @@ pcl::CrfSegmentation<PointT>::createDataVectorFromVoxelGrid ()
 /*
     if (normal_data)
     {
-      float n_x = filtered_cloud_->points[i].normal_x;
-      float n_y = filtered_cloud_->points[i].normal_y;
-      float n_z = filtered_cloud_->points[i].normal_z;
+      float n_x = (*filtered_cloud_)[i].normal_x;
+      float n_y = (*filtered_cloud_)[i].normal_y;
+      float n_z = (*filtered_cloud_)[i].normal_z;
       normal_[i] = Eigen::Vector3f (n_x, n_y, n_z);
     }
 */
   }
 
-  normal_.resize (filtered_normal_->points.size ());
-  for (std::size_t i = 0; i < filtered_normal_->points.size (); i++)
+  normal_.resize (filtered_normal_->size ());
+  for (std::size_t i = 0; i < filtered_normal_->size (); i++)
   {
-    float n_x = filtered_normal_->points[i].normal_x;
-    float n_y = filtered_normal_->points[i].normal_y;
-    float n_z = filtered_normal_->points[i].normal_z;
+    float n_x = (*filtered_normal_)[i].normal_x;
+    float n_y = (*filtered_normal_)[i].normal_y;
+    float n_z = (*filtered_normal_)[i].normal_z;
     normal_[i] = Eigen::Vector3f (n_x, n_y, n_z);
   }
   
@@ -329,9 +329,9 @@ pcl::CrfSegmentation<PointT>::createUnaryPotentials (std::vector<float> &unary,
   const float n_energy = -std::log ( (1.0f - GT_PROB) / static_cast<float>(n_labels - 1) );
   const float p_energy = -std::log ( GT_PROB );
 
-  for (std::size_t k = 0; k < filtered_anno_->points.size (); k++)
+  for (std::size_t k = 0; k < filtered_anno_->size (); k++)
   {
-    int label = filtered_anno_->points[k].label;
+    int label = (*filtered_anno_)[k].label;
 
     if (labels.empty () && label > 0)
       labels.push_back (label);
@@ -450,7 +450,7 @@ pcl::CrfSegmentation<PointT>::segmentPoints (pcl::PointCloud<pcl::PointXYZRGBL>
 
   for (std::size_t i = 0; i < N; i++)
   {
-    tmp_cloud_OLD.points[i].label = map[i];
+    tmp_cloud_OLD[i].label = map[i];
   }
 
 
@@ -480,9 +480,6 @@ pcl::CrfSegmentation<PointT>::segmentPoints (pcl::PointCloud<pcl::PointXYZRGBL>
   // ----------------------------------//
   // --------      -------------------//
 
-  pcl::PointCloud<pcl::PointXYZRGBL> tmp_cloud;
-  tmp_cloud = *filtered_anno_;
-
   // create dense CRF
   DenseCrf crf (N, n_labels);
 
@@ -544,18 +541,21 @@ pcl::CrfSegmentation<PointT>::segmentPoints (pcl::PointCloud<pcl::PointXYZRGBL>
 
   for (int i = 0; i < N; i++)
   {
-    output.points[i].label = labels[r[i]];
+    output[i].label = labels[r[i]];
   }
 
 
 /*
+  pcl::PointCloud<pcl::PointXYZRGBL> tmp_cloud;	
+  tmp_cloud = *filtered_anno_;
+
   bool c = true;
-  for (std::size_t i = 0; i < tmp_cloud.points.size (); i++)
+  for (std::size_t i = 0; i < tmp_cloud.size (); i++)
   {
-    if (tmp_cloud.points[i].label != tmp_cloud_OLD.points[i].label)
+    if (tmp_cloud[i].label != tmp_cloud_OLD[i].label)
     {
       
-      std::cout << "idx: " << i << " =  " <<tmp_cloud.points[i].label << " |  " << tmp_cloud_OLD.points[i].label << std::endl;
+      std::cout << "idx: " << i << " =  " <<tmp_cloud[i].label << " |  " << tmp_cloud_OLD[i].label << std::endl;
       c = false;
       break;
     }
