@@ -190,9 +190,8 @@ template <typename PointT> void
 pcl::MinCutSegmentation<PointT>::setForegroundPoints (typename pcl::PointCloud<PointT>::Ptr foreground_points)
 {
   foreground_points_.clear ();
-  foreground_points_.reserve (foreground_points->points.size ());
-  for (std::size_t i_point = 0; i_point < foreground_points->points.size (); i_point++)
-    foreground_points_.push_back (foreground_points->points[i_point]);
+  foreground_points_.insert(
+      foreground_points_.end(), foreground_points->cbegin(), foreground_points->cend());
 
   unary_potentials_are_valid_ = false;
 }
@@ -209,9 +208,8 @@ template <typename PointT> void
 pcl::MinCutSegmentation<PointT>::setBackgroundPoints (typename pcl::PointCloud<PointT>::Ptr background_points)
 {
   background_points_.clear ();
-  background_points_.reserve (background_points->points.size ());
-  for (std::size_t i_point = 0; i_point < background_points->points.size (); i_point++)
-    background_points_.push_back (background_points->points[i_point]);
+  background_points_.insert(
+      background_points_.end(), background_points->cbegin(), background_points->cend());
 
   unary_potentials_are_valid_ = false;
 }
@@ -238,11 +236,10 @@ pcl::MinCutSegmentation<PointT>::extract (std::vector <pcl::PointIndices>& clust
   }
 
   clusters_.clear ();
-  bool success = true;
 
   if ( !graph_is_valid_ )
   {
-    success = buildGraph ();
+    bool success = buildGraph ();
     if (!success)
     {
       deinitCompute ();
@@ -255,7 +252,7 @@ pcl::MinCutSegmentation<PointT>::extract (std::vector <pcl::PointIndices>& clust
 
   if ( !unary_potentials_are_valid_ )
   {
-    success = recalculateUnaryPotentials ();
+    bool success = recalculateUnaryPotentials ();
     if (!success)
     {
       deinitCompute ();
@@ -266,7 +263,7 @@ pcl::MinCutSegmentation<PointT>::extract (std::vector <pcl::PointIndices>& clust
 
   if ( !binary_potentials_are_valid_ )
   {
-    success = recalculateBinaryPotentials ();
+    bool success = recalculateBinaryPotentials ();
     if (!success)
     {
       deinitCompute ();
@@ -306,8 +303,8 @@ pcl::MinCutSegmentation<PointT>::getGraph () const
 template <typename PointT> bool
 pcl::MinCutSegmentation<PointT>::buildGraph ()
 {
-  int number_of_points = static_cast<int> (input_->points.size ());
-  int number_of_indices = static_cast<int> (indices_->size ());
+  const auto number_of_points = input_->size ();
+  const auto number_of_indices = indices_->size ();
 
   if (input_->points.empty () || number_of_points == 0 || foreground_points_.empty () == true )
     return (false);
@@ -331,15 +328,15 @@ pcl::MinCutSegmentation<PointT>::buildGraph ()
   edge_marker_.clear ();
   edge_marker_.resize (number_of_points + 2, out_edges_marker);
 
-  for (int i_point = 0; i_point < number_of_points + 2; i_point++)
+  for (std::size_t i_point = 0; i_point < number_of_points + 2; i_point++)
     vertices_[i_point] = boost::add_vertex (*graph_);
 
   source_ = vertices_[number_of_points];
   sink_ = vertices_[number_of_points + 1];
 
-  for (int i_point = 0; i_point < number_of_indices; i_point++)
+  for (std::size_t i_point = 0; i_point < number_of_indices; i_point++)
   {
-    int point_index = (*indices_)[i_point];
+    index_t point_index = (*indices_)[i_point];
     double source_weight = 0.0;
     double sink_weight = 0.0;
     calculateUnaryPotential (point_index, source_weight, sink_weight);
@@ -350,9 +347,9 @@ pcl::MinCutSegmentation<PointT>::buildGraph ()
   std::vector<int> neighbours;
   std::vector<float> distances;
   search_->setInputCloud (input_, indices_);
-  for (int i_point = 0; i_point < number_of_indices; i_point++)
+  for (std::size_t i_point = 0; i_point < number_of_indices; i_point++)
   {
-    int point_index = (*indices_)[i_point];
+    index_t point_index = (*indices_)[i_point];
     search_->nearestKSearch (i_point, number_of_neighbours_, neighbours, distances);
     for (std::size_t i_nghbr = 1; i_nghbr < neighbours.size (); i_nghbr++)
     {
@@ -373,13 +370,11 @@ pcl::MinCutSegmentation<PointT>::calculateUnaryPotential (int point, double& sou
 {
   double min_dist_to_foreground = std::numeric_limits<double>::max ();
   //double min_dist_to_background = std::numeric_limits<double>::max ();
-  double closest_foreground_point[2];
-  closest_foreground_point[0] = closest_foreground_point[1] = 0;
   //double closest_background_point[] = {0.0, 0.0};
   double initial_point[] = {0.0, 0.0};
 
-  initial_point[0] = input_->points[point].x;
-  initial_point[1] = input_->points[point].y;
+  initial_point[0] = (*input_)[point].x;
+  initial_point[1] = (*input_)[point].y;
 
   for (std::size_t i_point = 0; i_point < foreground_points_.size (); i_point++)
   {
@@ -389,8 +384,6 @@ pcl::MinCutSegmentation<PointT>::calculateUnaryPotential (int point, double& sou
     if (min_dist_to_foreground > dist)
     {
       min_dist_to_foreground = dist;
-      closest_foreground_point[0] = foreground_points_[i_point].x;
-      closest_foreground_point[1] = foreground_points_[i_point].y;
     }
   }
 
@@ -459,9 +452,9 @@ pcl::MinCutSegmentation<PointT>::calculateBinaryPotential (int source, int targe
 {
   double weight = 0.0;
   double distance = 0.0;
-  distance += (input_->points[source].x - input_->points[target].x) * (input_->points[source].x - input_->points[target].x);
-  distance += (input_->points[source].y - input_->points[target].y) * (input_->points[source].y - input_->points[target].y);
-  distance += (input_->points[source].z - input_->points[target].z) * (input_->points[source].z - input_->points[target].z);
+  distance += ((*input_)[source].x - (*input_)[target].x) * ((*input_)[source].x - (*input_)[target].x);
+  distance += ((*input_)[source].y - (*input_)[target].y) * ((*input_)[source].y - (*input_)[target].y);
+  distance += ((*input_)[source].z - (*input_)[target].z) * ((*input_)[source].z - (*input_)[target].z);
   distance *= inverse_sigma_;
   weight = std::exp (-distance);
 
@@ -545,7 +538,7 @@ template <typename PointT> void
 pcl::MinCutSegmentation<PointT>::assembleLabels (ResidualCapacityMap& residual_capacity)
 {
   std::vector<int> labels;
-  labels.resize (input_->points.size (), 0);
+  labels.resize (input_->size (), 0);
   int number_of_indices = static_cast<int> (indices_->size ());
   for (int i_point = 0; i_point < number_of_indices; i_point++)
     labels[(*indices_)[i_point]] = 1;
@@ -587,13 +580,12 @@ pcl::MinCutSegmentation<PointT>::getColoredCloud ()
     colored_cloud->is_dense = input_->is_dense;
 
     pcl::PointXYZRGB point;
-    int point_index = 0;
     for (int i_point = 0; i_point < num_of_pts_in_first_cluster; i_point++)
     {
-      point_index = clusters_[0].indices[i_point];
-      point.x = *(input_->points[point_index].data);
-      point.y = *(input_->points[point_index].data + 1);
-      point.z = *(input_->points[point_index].data + 2);
+      index_t point_index = clusters_[0].indices[i_point];
+      point.x = *((*input_)[point_index].data);
+      point.y = *((*input_)[point_index].data + 1);
+      point.z = *((*input_)[point_index].data + 2);
       point.r = background_color[0];
       point.g = background_color[1];
       point.b = background_color[2];
@@ -602,10 +594,10 @@ pcl::MinCutSegmentation<PointT>::getColoredCloud ()
 
     for (int i_point = 0; i_point < num_of_pts_in_second_cluster; i_point++)
     {
-      point_index = clusters_[1].indices[i_point];
-      point.x = *(input_->points[point_index].data);
-      point.y = *(input_->points[point_index].data + 1);
-      point.z = *(input_->points[point_index].data + 2);
+      index_t point_index = clusters_[1].indices[i_point];
+      point.x = *((*input_)[point_index].data);
+      point.y = *((*input_)[point_index].data + 1);
+      point.z = *((*input_)[point_index].data + 2);
       point.r = foreground_color[0];
       point.g = foreground_color[1];
       point.b = foreground_color[2];
