@@ -56,7 +56,7 @@ pcl::OrganizedConnectedComponentSegmentation<PointT, PointLT>::findLabeledRegion
   int curr_idx = start_idx;
   int curr_x   = start_idx % labels->width;
   int curr_y   = start_idx / labels->width;
-  unsigned label = labels->points[start_idx].label;
+  unsigned label = (*labels)[start_idx].label;
   
   // fill lookup table for next points to visit
   Neighbor directions [8] = {Neighbor(-1,  0,                 -1),
@@ -78,7 +78,7 @@ pcl::OrganizedConnectedComponentSegmentation<PointT, PointLT>::findLabeledRegion
     x = curr_x + directions [dIdx].d_x;
     y = curr_y + directions [dIdx].d_y;
     index = curr_idx + directions [dIdx].d_index;
-    if (x >= 0 && x < int(labels->width) && y >= 0 && y < int(labels->height) && labels->points[index].label != label)
+    if (x >= 0 && x < int(labels->width) && y >= 0 && y < int(labels->height) && (*labels)[index].label != label)
     {
       direction = dIdx;
       break;
@@ -100,7 +100,7 @@ pcl::OrganizedConnectedComponentSegmentation<PointT, PointLT>::findLabeledRegion
       x = curr_x + directions [nIdx].d_x;
       y = curr_y + directions [nIdx].d_y;
       index = curr_idx + directions [nIdx].d_index;
-      if (x >= 0 && x < int(labels->width) && y >= 0 && y < int(labels->height) && labels->points[index].label == label)
+      if (x >= 0 && x < int(labels->width) && y >= 0 && y < int(labels->height) && (*labels)[index].label == label)
         break;
     }
     
@@ -122,13 +122,13 @@ pcl::OrganizedConnectedComponentSegmentation<PointT, PointLT>::segment (pcl::Poi
   unsigned invalid_label = std::numeric_limits<unsigned>::max ();
   PointLT invalid_pt;
   invalid_pt.label = std::numeric_limits<unsigned>::max ();
-  labels.points.resize (input_->points.size (), invalid_pt);
+  labels.points.resize (input_->size (), invalid_pt);
   labels.width = input_->width;
   labels.height = input_->height;
   std::size_t clust_id = 0;
   
   //First pixel
-  if (std::isfinite (input_->points[0].x))
+  if (std::isfinite ((*input_)[0].x))
   {
     labels[0].label = clust_id++;
     run_ids.push_back (labels[0].label );
@@ -137,7 +137,7 @@ pcl::OrganizedConnectedComponentSegmentation<PointT, PointLT>::segment (pcl::Poi
   // First row
   for (int colIdx = 1; colIdx < static_cast<int> (input_->width); ++colIdx)
   {
-    if (!std::isfinite (input_->points[colIdx].x))
+    if (!std::isfinite ((*input_)[colIdx].x))
       continue;
     if (compare_->compare (colIdx, colIdx - 1 ))
     {
@@ -156,7 +156,7 @@ pcl::OrganizedConnectedComponentSegmentation<PointT, PointLT>::segment (pcl::Poi
   for (std::size_t rowIdx = 1; rowIdx < input_->height; ++rowIdx, previous_row = current_row, current_row += input_->width)
   {
     // First pixel
-    if (std::isfinite (input_->points[current_row].x))
+    if (std::isfinite ((*input_)[current_row].x))
     {
       if (compare_->compare (current_row, previous_row))
       {
@@ -172,7 +172,7 @@ pcl::OrganizedConnectedComponentSegmentation<PointT, PointLT>::segment (pcl::Poi
     // Rest of row
     for (int colIdx = 1; colIdx < static_cast<int> (input_->width); ++colIdx)
     {
-      if (std::isfinite (input_->points[current_row + colIdx].x))
+      if (std::isfinite ((*input_)[current_row + colIdx].x))
       {
         if (compare_->compare (current_row + colIdx, current_row + colIdx - 1))
         {
@@ -216,7 +216,7 @@ pcl::OrganizedConnectedComponentSegmentation<PointT, PointLT>::segment (pcl::Poi
   }
 
   label_indices.resize (max_id + 1);
-  for (std::size_t idx = 0; idx < input_->points.size (); idx++)
+  for (std::size_t idx = 0; idx < input_->size (); idx++)
   {
     if (labels[idx].label != invalid_label)
     {
