@@ -37,15 +37,15 @@
  *
  */
 
-#ifndef PCL_SEGMENTATION_REGION_GROWING_HPP_
-#define PCL_SEGMENTATION_REGION_GROWING_HPP_
+#pragma once
 
 #include <pcl/segmentation/region_growing.h>
 
-#include <pcl/search/search.h>
-#include <pcl/search/kdtree.h>
 #include <pcl/point_cloud.h>
 #include <pcl/point_types.h>
+#include <pcl/common/point_tests.h> // for pcl::isFinite
+#include <pcl/search/search.h>
+#include <pcl/search/kdtree.h>
 
 #include <queue>
 #include <list>
@@ -276,13 +276,13 @@ pcl::RegionGrowing<PointT, NormalT>::extract (std::vector <pcl::PointIndices>& c
 
   clusters.resize (clusters_.size ());
   std::vector<pcl::PointIndices>::iterator cluster_iter_input = clusters.begin ();
-  for (std::vector<pcl::PointIndices>::const_iterator cluster_iter = clusters_.begin (); cluster_iter != clusters_.end (); cluster_iter++)
+  for (std::vector<pcl::PointIndices>::const_iterator cluster_iter = clusters_.begin (); cluster_iter != clusters_.end (); ++cluster_iter)
   {
     if ((static_cast<int> (cluster_iter->indices.size ()) >= min_pts_per_cluster_) &&
         (static_cast<int> (cluster_iter->indices.size ()) <= max_pts_per_cluster_))
     {
       *cluster_iter_input = *cluster_iter;
-      cluster_iter_input++;
+      ++cluster_iter_input;
     }
   }
 
@@ -301,7 +301,7 @@ pcl::RegionGrowing<PointT, NormalT>::prepareForSegmentation ()
     return (false);
 
   // if user forgot to pass normals or the sizes of point and normal cloud are different
-  if ( !normals_ || input_->points.size () != normals_->points.size () )
+  if ( !normals_ || input_->size () != normals_->size () )
     return (false);
 
   // if residual test is on then we need to check if all needed parameters were correctly initialized
@@ -346,7 +346,7 @@ pcl::RegionGrowing<PointT, NormalT>::findPointNeighbours ()
   std::vector<int> neighbours;
   std::vector<float> distances;
 
-  point_neighbours_.resize (input_->points.size (), neighbours);
+  point_neighbours_.resize (input_->size (), neighbours);
   if (input_->is_dense)
   {
     for (int i_point = 0; i_point < point_number; i_point++)
@@ -363,7 +363,7 @@ pcl::RegionGrowing<PointT, NormalT>::findPointNeighbours ()
     {
       neighbours.clear ();
       int point_index = (*indices_)[i_point];
-      if (!pcl::isFinite (input_->points[point_index]))
+      if (!pcl::isFinite ((*input_)[point_index]))
         continue;
       search_->nearestKSearch (i_point, neighbour_number_, neighbours, distances);
       point_neighbours_[point_index].swap (neighbours);
@@ -376,7 +376,7 @@ template <typename PointT, typename NormalT> void
 pcl::RegionGrowing<PointT, NormalT>::applySmoothRegionGrowingAlgorithm ()
 {
   int num_of_pts = static_cast<int> (indices_->size ());
-  point_labels_.resize (input_->points.size (), -1);
+  point_labels_.resize (input_->size (), -1);
 
   std::vector< std::pair<float, int> > point_residual;
   std::pair<float, int> pair;
@@ -387,7 +387,7 @@ pcl::RegionGrowing<PointT, NormalT>::applySmoothRegionGrowingAlgorithm ()
     for (int i_point = 0; i_point < num_of_pts; i_point++)
     {
       int point_index = (*indices_)[i_point];
-      point_residual[i_point].first = normals_->points[point_index].curvature;
+      point_residual[i_point].first = (*normals_)[point_index].curvature;
       point_residual[i_point].second = point_index;
     }
     std::sort (point_residual.begin (), point_residual.end (), comparePair);
@@ -487,17 +487,17 @@ pcl::RegionGrowing<PointT, NormalT>::validatePoint (int initial_seed, int point,
   float cosine_threshold = std::cos (theta_threshold_);
   float data[4];
 
-  data[0] = input_->points[point].data[0];
-  data[1] = input_->points[point].data[1];
-  data[2] = input_->points[point].data[2];
-  data[3] = input_->points[point].data[3];
+  data[0] = (*input_)[point].data[0];
+  data[1] = (*input_)[point].data[1];
+  data[2] = (*input_)[point].data[2];
+  data[3] = (*input_)[point].data[3];
   Eigen::Map<Eigen::Vector3f> initial_point (static_cast<float*> (data));
-  Eigen::Map<Eigen::Vector3f> initial_normal (static_cast<float*> (normals_->points[point].normal));
+  Eigen::Map<Eigen::Vector3f> initial_normal (static_cast<float*> ((*normals_)[point].normal));
 
   //check the angle between normals
   if (smooth_mode_flag_ == true)
   {
-    Eigen::Map<Eigen::Vector3f> nghbr_normal (static_cast<float*> (normals_->points[nghbr].normal));
+    Eigen::Map<Eigen::Vector3f> nghbr_normal (static_cast<float*> ((*normals_)[nghbr].normal));
     float dot_product = std::abs (nghbr_normal.dot (initial_normal));
     if (dot_product < cosine_threshold)
     {
@@ -506,15 +506,15 @@ pcl::RegionGrowing<PointT, NormalT>::validatePoint (int initial_seed, int point,
   }
   else
   {
-    Eigen::Map<Eigen::Vector3f> nghbr_normal (static_cast<float*> (normals_->points[nghbr].normal));
-    Eigen::Map<Eigen::Vector3f> initial_seed_normal (static_cast<float*> (normals_->points[initial_seed].normal));
+    Eigen::Map<Eigen::Vector3f> nghbr_normal (static_cast<float*> ((*normals_)[nghbr].normal));
+    Eigen::Map<Eigen::Vector3f> initial_seed_normal (static_cast<float*> ((*normals_)[initial_seed].normal));
     float dot_product = std::abs (nghbr_normal.dot (initial_seed_normal));
     if (dot_product < cosine_threshold)
       return (false);
   }
 
   // check the curvature if needed
-  if (curvature_flag_ && normals_->points[nghbr].curvature > curvature_threshold_)
+  if (curvature_flag_ && (*normals_)[nghbr].curvature > curvature_threshold_)
   {
     is_a_seed = false;
   }
@@ -522,10 +522,10 @@ pcl::RegionGrowing<PointT, NormalT>::validatePoint (int initial_seed, int point,
   // check the residual if needed
   float data_1[4];
   
-  data_1[0] = input_->points[nghbr].data[0];
-  data_1[1] = input_->points[nghbr].data[1];
-  data_1[2] = input_->points[nghbr].data[2];
-  data_1[3] = input_->points[nghbr].data[3];
+  data_1[0] = (*input_)[nghbr].data[0];
+  data_1[1] = (*input_)[nghbr].data[1];
+  data_1[2] = (*input_)[nghbr].data[2];
+  data_1[3] = (*input_)[nghbr].data[3];
   Eigen::Map<Eigen::Vector3f> nghbr_point (static_cast<float*> (data_1));
   float residual = std::abs (initial_normal.dot (initial_point - nghbr_point));
   if (residual_flag_ && residual > residual_threshold_)
@@ -538,26 +538,25 @@ pcl::RegionGrowing<PointT, NormalT>::validatePoint (int initial_seed, int point,
 template <typename PointT, typename NormalT> void
 pcl::RegionGrowing<PointT, NormalT>::assembleRegions ()
 {
-  int number_of_segments = static_cast<int> (num_pts_in_segment_.size ());
-  int number_of_points = static_cast<int> (input_->points.size ());
+  const auto number_of_segments = num_pts_in_segment_.size ();
+  const auto number_of_points = input_->size ();
 
   pcl::PointIndices segment;
   clusters_.resize (number_of_segments, segment);
 
-  for (int i_seg = 0; i_seg < number_of_segments; i_seg++)
+  for (std::size_t i_seg = 0; i_seg < number_of_segments; i_seg++)
   {
     clusters_[i_seg].indices.resize ( num_pts_in_segment_[i_seg], 0);
   }
 
-  std::vector<int> counter;
-  counter.resize (number_of_segments, 0);
+  std::vector<int> counter(number_of_segments, 0);
 
-  for (int i_point = 0; i_point < number_of_points; i_point++)
+  for (std::size_t i_point = 0; i_point < number_of_points; i_point++)
   {
-    int segment_index = point_labels_[i_point];
+    const auto segment_index = point_labels_[i_point];
     if (segment_index != -1)
     {
-      int point_index = counter[segment_index];
+      const auto point_index = counter[segment_index];
       clusters_[segment_index].indices[point_index] = i_point;
       counter[segment_index] = point_index + 1;
     }
@@ -657,12 +656,12 @@ pcl::RegionGrowing<PointT, NormalT>::getColoredCloud ()
     colored_cloud->width = input_->width;
     colored_cloud->height = input_->height;
     colored_cloud->is_dense = input_->is_dense;
-    for (std::size_t i_point = 0; i_point < input_->points.size (); i_point++)
+    for (const auto& i_point: *input_)
     {
       pcl::PointXYZRGB point;
-      point.x = *(input_->points[i_point].data);
-      point.y = *(input_->points[i_point].data + 1);
-      point.z = *(input_->points[i_point].data + 2);
+      point.x = *(i_point.data);
+      point.y = *(i_point.data + 1);
+      point.z = *(i_point.data + 2);
       point.r = 255;
       point.g = 0;
       point.b = 0;
@@ -676,9 +675,9 @@ pcl::RegionGrowing<PointT, NormalT>::getColoredCloud ()
       {
         int index;
         index = *i_point;
-        colored_cloud->points[index].r = colors[3 * next_color];
-        colored_cloud->points[index].g = colors[3 * next_color + 1];
-        colored_cloud->points[index].b = colors[3 * next_color + 2];
+        (*colored_cloud)[index].r = colors[3 * next_color];
+        (*colored_cloud)[index].g = colors[3 * next_color + 1];
+        (*colored_cloud)[index].b = colors[3 * next_color + 2];
       }
       next_color++;
     }
@@ -709,12 +708,12 @@ pcl::RegionGrowing<PointT, NormalT>::getColoredCloudRGBA ()
     colored_cloud->width = input_->width;
     colored_cloud->height = input_->height;
     colored_cloud->is_dense = input_->is_dense;
-    for (std::size_t i_point = 0; i_point < input_->points.size (); i_point++)
+    for (const auto& i_point: *input_)
     {
       pcl::PointXYZRGBA point;
-      point.x = *(input_->points[i_point].data);
-      point.y = *(input_->points[i_point].data + 1);
-      point.z = *(input_->points[i_point].data + 2);
+      point.x = *(i_point.data);
+      point.y = *(i_point.data + 1);
+      point.z = *(i_point.data + 2);
       point.r = 255;
       point.g = 0;
       point.b = 0;
@@ -728,9 +727,9 @@ pcl::RegionGrowing<PointT, NormalT>::getColoredCloudRGBA ()
       for (auto i_point = i_segment->indices.cbegin (); i_point != i_segment->indices.cend (); i_point++)
       {
         int index = *i_point;
-        colored_cloud->points[index].r = colors[3 * next_color];
-        colored_cloud->points[index].g = colors[3 * next_color + 1];
-        colored_cloud->points[index].b = colors[3 * next_color + 2];
+        (*colored_cloud)[index].r = colors[3 * next_color];
+        (*colored_cloud)[index].g = colors[3 * next_color + 1];
+        (*colored_cloud)[index].b = colors[3 * next_color + 2];
       }
       next_color++;
     }
@@ -741,4 +740,3 @@ pcl::RegionGrowing<PointT, NormalT>::getColoredCloudRGBA ()
 
 #define PCL_INSTANTIATE_RegionGrowing(T) template class pcl::RegionGrowing<T, pcl::Normal>;
 
-#endif    // PCL_SEGMENTATION_REGION_GROWING_HPP_
