@@ -82,23 +82,23 @@ pcl::ConvexHull<PointInT>::performReconstruction2D (PointCloud &hull, std::vecto
   bool xz_proj_safe = true;
 
   // Check the input's normal to see which projection to use
-  PointInT p0 = input_->points[(*indices_)[0]];
-  PointInT p1 = input_->points[(*indices_)[indices_->size () - 1]];
-  PointInT p2 = input_->points[(*indices_)[indices_->size () / 2]];
+  PointInT p0 = (*input_)[(*indices_)[0]];
+  PointInT p1 = (*input_)[(*indices_)[indices_->size () - 1]];
+  PointInT p2 = (*input_)[(*indices_)[indices_->size () / 2]];
   Eigen::Array4f dy1dy2 = (p1.getArray4fMap () - p0.getArray4fMap ()) / (p2.getArray4fMap () - p0.getArray4fMap ());
   while (!( (dy1dy2[0] != dy1dy2[1]) || (dy1dy2[2] != dy1dy2[1]) ) )
   {
-    p0 = input_->points[(*indices_)[rand () % indices_->size ()]];
-    p1 = input_->points[(*indices_)[rand () % indices_->size ()]];
-    p2 = input_->points[(*indices_)[rand () % indices_->size ()]];
+    p0 = (*input_)[(*indices_)[rand () % indices_->size ()]];
+    p1 = (*input_)[(*indices_)[rand () % indices_->size ()]];
+    p2 = (*input_)[(*indices_)[rand () % indices_->size ()]];
     dy1dy2 = (p1.getArray4fMap () - p0.getArray4fMap ()) / (p2.getArray4fMap () - p0.getArray4fMap ());
   }
     
   pcl::PointCloud<PointInT> normal_calc_cloud;
   normal_calc_cloud.points.resize (3);
-  normal_calc_cloud.points[0] = p0;
-  normal_calc_cloud.points[1] = p1;
-  normal_calc_cloud.points[2] = p2;
+  normal_calc_cloud[0] = p0;
+  normal_calc_cloud[1] = p1;
+  normal_calc_cloud[2] = p2;
     
   Eigen::Vector4d normal_calc_centroid;
   Eigen::Matrix3d normal_calc_covariance;
@@ -155,24 +155,24 @@ pcl::ConvexHull<PointInT>::performReconstruction2D (PointCloud &hull, std::vecto
   {
     for (std::size_t i = 0; i < indices_->size (); ++i, j+=dimension)
     {
-      points[j + 0] = static_cast<coordT> (input_->points[(*indices_)[i]].x);
-      points[j + 1] = static_cast<coordT> (input_->points[(*indices_)[i]].y);
+      points[j + 0] = static_cast<coordT> ((*input_)[(*indices_)[i]].x);
+      points[j + 1] = static_cast<coordT> ((*input_)[(*indices_)[i]].y);
     }
   } 
   else if (yz_proj_safe)
   {
     for (std::size_t i = 0; i < indices_->size (); ++i, j+=dimension)
     {
-      points[j + 0] = static_cast<coordT> (input_->points[(*indices_)[i]].y);
-      points[j + 1] = static_cast<coordT> (input_->points[(*indices_)[i]].z);
+      points[j + 0] = static_cast<coordT> ((*input_)[(*indices_)[i]].y);
+      points[j + 1] = static_cast<coordT> ((*input_)[(*indices_)[i]].z);
     }
   }
   else if (xz_proj_safe)
   {
     for (std::size_t i = 0; i < indices_->size (); ++i, j+=dimension)
     {
-      points[j + 0] = static_cast<coordT> (input_->points[(*indices_)[i]].x);
-      points[j + 1] = static_cast<coordT> (input_->points[(*indices_)[i]].z);
+      points[j + 0] = static_cast<coordT> ((*input_)[(*indices_)[i]].x);
+      points[j + 1] = static_cast<coordT> ((*input_)[(*indices_)[i]].z);
     }
   }
   else
@@ -215,18 +215,18 @@ pcl::ConvexHull<PointInT>::performReconstruction2D (PointCloud &hull, std::vecto
 
   int num_vertices = qh num_vertices;
   hull.points.resize (num_vertices);
-  memset (&hull.points[0], static_cast<int> (hull.points.size ()), sizeof (PointInT));
+  memset (&hull.points[0], hull.size (), sizeof (PointInT));
 
   vertexT * vertex;
   int i = 0;
 
   std::vector<std::pair<int, Eigen::Vector4f>, Eigen::aligned_allocator<std::pair<int, Eigen::Vector4f> > > idx_points (num_vertices);
-  idx_points.resize (hull.points.size ());
-  memset (&idx_points[0], static_cast<int> (hull.points.size ()), sizeof (std::pair<int, Eigen::Vector4f>));
+  idx_points.resize (hull.size ());
+  memset (&idx_points[0], hull.size (), sizeof (std::pair<int, Eigen::Vector4f>));
 
   FORALLvertices
   {
-    hull.points[i] = input_->points[(*indices_)[qh_pointid (vertex->point)]];
+    hull[i] = (*input_)[(*indices_)[qh_pointid (vertex->point)]];
     idx_points[i].first = qh_pointid (vertex->point);
     ++i;
   }
@@ -236,41 +236,41 @@ pcl::ConvexHull<PointInT>::performReconstruction2D (PointCloud &hull, std::vecto
   pcl::compute3DCentroid (hull, centroid);
   if (xy_proj_safe)
   {
-    for (std::size_t j = 0; j < hull.points.size (); j++)
+    for (std::size_t j = 0; j < hull.size (); j++)
     {
-      idx_points[j].second[0] = hull.points[j].x - centroid[0];
-      idx_points[j].second[1] = hull.points[j].y - centroid[1];
+      idx_points[j].second[0] = hull[j].x - centroid[0];
+      idx_points[j].second[1] = hull[j].y - centroid[1];
     }
   }
   else if (yz_proj_safe)
   {
-    for (std::size_t j = 0; j < hull.points.size (); j++)
+    for (std::size_t j = 0; j < hull.size (); j++)
     {
-      idx_points[j].second[0] = hull.points[j].y - centroid[1];
-      idx_points[j].second[1] = hull.points[j].z - centroid[2];
+      idx_points[j].second[0] = hull[j].y - centroid[1];
+      idx_points[j].second[1] = hull[j].z - centroid[2];
     }
   }
   else if (xz_proj_safe)
   {
-    for (std::size_t j = 0; j < hull.points.size (); j++)
+    for (std::size_t j = 0; j < hull.size (); j++)
     {
-      idx_points[j].second[0] = hull.points[j].x - centroid[0];
-      idx_points[j].second[1] = hull.points[j].z - centroid[2];
+      idx_points[j].second[0] = hull[j].x - centroid[0];
+      idx_points[j].second[1] = hull[j].z - centroid[2];
     }
   }
   std::sort (idx_points.begin (), idx_points.end (), comparePoints2D);
     
   polygons.resize (1);
-  polygons[0].vertices.resize (hull.points.size ());
+  polygons[0].vertices.resize (hull.size ());
 
   hull_indices_.header = input_->header;
   hull_indices_.indices.clear ();
-  hull_indices_.indices.reserve (hull.points.size ());
+  hull_indices_.indices.reserve (hull.size ());
 
-  for (int j = 0; j < static_cast<int> (hull.points.size ()); j++)
+  for (int j = 0; j < static_cast<int> (hull.size ()); j++)
   {
     hull_indices_.indices.push_back ((*indices_)[idx_points[j].first]);
-    hull.points[j] = input_->points[(*indices_)[idx_points[j].first]];
+    hull[j] = (*input_)[(*indices_)[idx_points[j].first]];
     polygons[0].vertices[j] = static_cast<unsigned int> (j);
   }
     
@@ -278,7 +278,7 @@ pcl::ConvexHull<PointInT>::performReconstruction2D (PointCloud &hull, std::vecto
   int curlong, totlong;
   qh_memfreeshort (&curlong, &totlong);
 
-  hull.width = static_cast<std::uint32_t> (hull.points.size ());
+  hull.width = hull.size ();
   hull.height = 1;
   hull.is_dense = false;
   return;
@@ -315,9 +315,9 @@ pcl::ConvexHull<PointInT>::performReconstruction3D (
   int j = 0;
   for (std::size_t i = 0; i < indices_->size (); ++i, j+=dimension)
   {
-    points[j + 0] = static_cast<coordT> (input_->points[(*indices_)[i]].x);
-    points[j + 1] = static_cast<coordT> (input_->points[(*indices_)[i]].y);
-    points[j + 2] = static_cast<coordT> (input_->points[(*indices_)[i]].z);
+    points[j + 0] = static_cast<coordT> ((*input_)[(*indices_)[i]].x);
+    points[j + 1] = static_cast<coordT> ((*input_)[(*indices_)[i]].y);
+    points[j + 2] = static_cast<coordT> ((*input_)[(*indices_)[i]].z);
   }
 
   // Compute convex hull
@@ -332,7 +332,10 @@ pcl::ConvexHull<PointInT>::performReconstruction3D (
   // 0 if no error from qhull
   if (exitcode != 0)
   {
-    PCL_ERROR ("[pcl::%s::performReconstrution3D] ERROR: qhull was unable to compute a convex hull for the given point cloud (%lu)!\n", getClassName ().c_str (), input_->points.size ());
+    PCL_ERROR("[pcl::%s::performReconstrution3D] ERROR: qhull was unable to compute a "
+              "convex hull for the given point cloud (%zu)!\n",
+              getClassName().c_str(),
+              static_cast<std::size_t>(input_->size()));
 
     hull.points.resize (0);
     hull.width = hull.height = 0;
@@ -373,7 +376,7 @@ pcl::ConvexHull<PointInT>::performReconstruction3D (
   {
     // Add vertices to hull point_cloud and store index
     hull_indices_.indices.push_back ((*indices_)[qh_pointid (vertex->point)]);
-    hull.points[i] = input_->points[hull_indices_.indices.back ()];
+    hull[i] = (*input_)[hull_indices_.indices.back ()];
 
     qhid_to_pcidx[vertex->id] = i; // map the vertex id of qhull to the point cloud index
     ++i;
@@ -408,7 +411,7 @@ pcl::ConvexHull<PointInT>::performReconstruction3D (
   int curlong, totlong;
   qh_memfreeshort (&curlong, &totlong);
 
-  hull.width = static_cast<std::uint32_t> (hull.points.size ());
+  hull.width = hull.size ();
   hull.height = 1;
   hull.is_dense = false;
 }
@@ -446,7 +449,7 @@ pcl::ConvexHull<PointInT>::reconstruct (PointCloud &points)
   std::vector<pcl::Vertices> polygons;
   performReconstruction (points, polygons, false);
 
-  points.width = static_cast<std::uint32_t> (points.points.size ());
+  points.width = points.size ();
   points.height = 1;
   points.is_dense = true;
 
@@ -488,7 +491,7 @@ pcl::ConvexHull<PointInT>::reconstruct (PointCloud &points, std::vector<pcl::Ver
   // Perform the actual surface reconstruction
   performReconstruction (points, polygons, true);
 
-  points.width = static_cast<std::uint32_t> (points.points.size ());
+  points.width = points.size ();
   points.height = 1;
   points.is_dense = true;
 
