@@ -35,6 +35,7 @@
 
 #pragma once
 
+#include <pcl/memory.h>
 #include <pcl/pcl_macros.h>
 #include <pcl/surface/boost.h>
 #include <pcl/surface/marching_cubes.h>
@@ -91,7 +92,7 @@ namespace pcl
       /** \brief Method that sets the distance for ignoring voxels which are far from point cloud.
         * If the distance is negative, then the distance functions would be calculated in all voxels;
         * otherwise, only voxels with distance lower than dist_ignore would be involved in marching cube.
-        * \param[in] threshold of distance. Default value is -1.0. Set to negative if all voxels are
+        * \param[in] dist_ignore threshold of distance. Default value is -1.0. Set to negative if all voxels are
         * to be involved.
         */
       inline void
