@@ -37,6 +37,8 @@
 
 #include <pcl/surface/on_nurbs/global_optimization_pdm.h>
 #include <pcl/surface/on_nurbs/closing_boundary.h>
+#include <pcl/pcl_macros.h>
+
 #include <stdexcept>
 
 #undef DEBUG
@@ -115,8 +117,8 @@ GlobalOptimization::assemble (Parameter params)
 
   m_solver.assign (m_nrows, m_ncols, 3);
 
-  for (unsigned i = 0; i < m_data.size (); i++)
-    m_data[i]->common_boundary_param.clear ();
+  for (const auto &i : m_data)
+    i->common_boundary_param.clear ();
 
   // assemble matrix
   unsigned row (0);
@@ -159,10 +161,8 @@ GlobalOptimization::updateSurf (double damp)
 {
   int ncps (0);
 
-  for (unsigned i = 0; i < m_nurbs.size (); i++)
+  for (const auto &nurbs : m_nurbs)
   {
-    ON_NurbsSurface* nurbs = m_nurbs[i];
-
     int ncp = nurbs->CVCount ();
 
     for (int A = 0; A < ncp; A++)
@@ -199,12 +199,12 @@ GlobalOptimization::refine (unsigned id, int dim)
   std::vector<double> xi;
   std::vector<double> elements = FittingSurface::getElementVector (*m_nurbs[id], dim);
 
-  for (unsigned i = 0; i < elements.size () - 1; i++)
+  for (std::size_t i = 0; i < elements.size () - 1; i++)
     xi.push_back (elements[i] + 0.5 * (elements[i + 1] - elements[i]));
 
-  for (unsigned i = 0; i < xi.size (); i++)
+  for (const double &i : xi)
   {
-    m_nurbs[id]->InsertKnot (dim, xi[i], 1);
+    m_nurbs[id]->InsertKnot (dim, i, 1);
   }
 }
 
@@ -216,7 +216,7 @@ GlobalOptimization::assembleCommonParams (unsigned id1, double weight, unsigned
 
   NurbsDataSurface *data = m_data[id1];
 
-  for (size_t i = 0; i < data->common_idx.size (); i++)
+  for (std::size_t i = 0; i < data->common_idx.size (); i++)
     addParamConstraint (Eigen::Vector2i (id1, data->common_idx[i]), data->common_param1[i], data->common_param2[i],
                         weight, row);
 }
@@ -234,7 +234,7 @@ GlobalOptimization::assembleCommonBoundaries (unsigned id1, double weight, unsig
   if (nurbs1->Order (0) != nurbs1->Order (1))
     printf ("[GlobalOptimization::assembleCommonBoundaries] Warning, order in u and v direction differ (nurbs1).\n");
 
-  for (unsigned i = 0; i < data1->common_boundary_point.size (); i++)
+  for (std::size_t i = 0; i < data1->common_boundary_point.size (); i++)
   {
     Eigen::Vector3d p1, tu1, tv1, p2, tu2, tv2, t1, t2;
     Eigen::Vector2d params1, params2;
@@ -242,7 +242,7 @@ GlobalOptimization::assembleCommonBoundaries (unsigned id1, double weight, unsig
     Eigen::Vector3d p0 = data1->common_boundary_point[i];
     Eigen::Vector2i id (id1, data1->common_boundary_idx[i]);
 
-    if (id (1) < 0 || id (1) >= m_nurbs.size ())
+    if (id (1) < 0 || id (1) >= static_cast<int>(m_nurbs.size ()))
       throw std::runtime_error (
                                 "[GlobalOptimization::assembleCommonBoundaries] Error, common boundary index out of bounds.\n");
 
@@ -302,7 +302,7 @@ GlobalOptimization::assembleCommonBoundaries (unsigned id1, double weight, unsig
     m_data[id (1)]->common_boundary_param.push_back (params2);
 
     //    double error = (p1-p2).norm();
-    //    double w = weight * exp(-(error * error) * ds);
+    //    double w = weight * std::exp(-(error * error) * ds);
     addParamConstraint (id, params1, params2, weight * w, row);
 
   }
@@ -325,12 +325,12 @@ GlobalOptimization::assembleClosingBoundaries (unsigned id, unsigned samples, do
   ClosingBoundary::sampleFromBoundary (nurbs1, boundary1, params1, samples);
 
   // for each other nurbs
-  for (unsigned n2 = (id + 1); n2 < m_nurbs.size (); n2++)
+  for (std::size_t n2 = (id + 1); n2 < m_nurbs.size (); n2++)
   {
     ON_NurbsSurface *nurbs2 = m_nurbs[n2];
 
     // find closest point to boundary
-    for (unsigned i = 0; i < boundary1.size (); i++)
+    for (std::size_t i = 0; i < boundary1.size (); i++)
     {
       double error;
       Eigen::Vector3d p, tu, tv;
@@ -344,7 +344,7 @@ GlobalOptimization::assembleClosingBoundaries (unsigned id, unsigned samples, do
 
       //      double dist = (p - p0).norm();
       //      if (error < max_error && dist < max_dist) {
-      double w = weight * exp (-(error * error) * ds);
+      double w = weight * std::exp (-(error * error) * ds);
       addParamConstraint (Eigen::Vector2i (id, n2), params1[i], params, w, row);
       //      }
     }
@@ -359,7 +359,7 @@ GlobalOptimization::assembleInteriorPoints (unsigned id, int ncps, double weight
 
   ON_NurbsSurface *nurbs = m_nurbs[id];
   NurbsDataSurface *data = m_data[id];
-  unsigned nInt = static_cast<unsigned> (m_data[id]->interior.size ());
+  std::size_t interiorSize = m_data[id]->interior.size ();
 
   // interior points should lie on surface
   data->interior_line_start.clear ();
@@ -368,7 +368,7 @@ GlobalOptimization::assembleInteriorPoints (unsigned id, int ncps, double weight
   data->interior_normals.clear ();
   //  data->interior_param.clear();
 
-  for (unsigned p = 0; p < nInt; p++)
+  for (std::size_t p = 0; p < interiorSize; p++)
   {
     Vector3d pcp;
     pcp (0) = data->interior[p] (0);
@@ -613,6 +613,7 @@ GlobalOptimization::addCageBoundaryRegularisation (unsigned id, int ncps, double
   {
     case SOUTH:
       j = nurbs->CVCount (1) - 1;
+      PCL_FALLTHROUGH
     case NORTH:
       for (i = 1; i < (nurbs->CVCount (0) - 1); i++)
       {
@@ -631,6 +632,7 @@ GlobalOptimization::addCageBoundaryRegularisation (unsigned id, int ncps, double
 
     case EAST:
       i = nurbs->CVCount (0) - 1;
+      PCL_FALLTHROUGH
     case WEST:
       for (j = 1; j < (nurbs->CVCount (1) - 1); j++)
       {
