@@ -36,11 +36,7 @@
  *
  */
 
-#include <gtest/gtest.h>
-#include <pcl/common/common.h>
-#include <pcl/common/distances.h>
-#include <pcl/common/intersections.h>
-#include <pcl/common/io.h>
+#include <pcl/test/gtest.h>
 #include <pcl/common/eigen.h>
 #include <pcl/point_types.h>
 #include <pcl/point_cloud.h>
@@ -58,7 +54,7 @@ pcl::PCLPointCloud2 cloud_blob;
 TEST (PCL, compute3DCentroidFloat)
 {
   pcl::PointIndices pindices;
-  std::vector<int> indices;
+  Indices indices;
   PointXYZ point;
   PointCloud<PointXYZ> cloud;
   Eigen::Vector4f centroid;
@@ -164,7 +160,7 @@ TEST (PCL, compute3DCentroidFloat)
 TEST (PCL, compute3DCentroidDouble)
 {
   pcl::PointIndices pindices;
-  std::vector<int> indices;
+  Indices indices;
   PointXYZ point;
   PointCloud<PointXYZ> cloud;
   Eigen::Vector4d centroid;
@@ -269,7 +265,7 @@ TEST (PCL, compute3DCentroidDouble)
 TEST (PCL, compute3DCentroidCloudIterator)
 {
   pcl::PointIndices pindices;
-  std::vector<int> indices;
+  Indices indices;
   PointXYZ point;
   PointCloud<PointXYZ> cloud;
   Eigen::Vector4f centroid_f;
@@ -333,7 +329,7 @@ TEST (PCL, computeCovarianceMatrix)
 {
   PointCloud<PointXYZ> cloud;
   PointXYZ point;
-  std::vector <int> indices;
+  Indices indices;
   Eigen::Vector4f centroid;
   Eigen::Matrix3f covariance_matrix;
 
@@ -449,7 +445,7 @@ TEST (PCL, computeCovarianceMatrixNormalized)
 {
   PointCloud<PointXYZ> cloud;
   PointXYZ point;
-  std::vector <int> indices;
+  Indices indices;
   Eigen::Vector4f centroid;
   Eigen::Matrix3f covariance_matrix;
 
@@ -567,7 +563,7 @@ TEST (PCL, computeDemeanedCovariance)
 {
   PointCloud<PointXYZ> cloud;
   PointXYZ point;
-  std::vector <int> indices;
+  Indices indices;
   Eigen::Matrix3f covariance_matrix;
 
   // test empty cloud which is dense
@@ -673,7 +669,7 @@ TEST (PCL, computeMeanAndCovariance)
 {
   PointCloud<PointXYZ> cloud;
   PointXYZ point;
-  std::vector <int> indices;
+  Indices indices;
   Eigen::Matrix3f covariance_matrix;
   Eigen::Vector4f centroid;
 
@@ -931,7 +927,7 @@ TEST (PCL, CentroidPoint)
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
 TEST (PCL, computeCentroid)
 {
-  std::vector<int> indices;
+  Indices indices;
   PointXYZI point;
   PointCloud<PointXYZI> cloud;
   PointXYZINormal centroid;
@@ -1057,7 +1053,7 @@ TEST (PCL, demeanPointCloud)
   EXPECT_XYZ_NEAR (cloud_demean[0], PointXYZ (0.034503, 0.010837, 0.013447), 1e-4);
   EXPECT_XYZ_NEAR (cloud_demean[cloud_demean.size () - 1], PointXYZ (-0.048849, 0.072507, -0.071702), 1e-4);
 
-  std::vector<int> indices (cloud.size ());
+  Indices indices (cloud.size ());
   for (int i = 0; i < static_cast<int> (indices.size ()); ++i) { indices[i] = i; }
 
   // Check standard demean w/ indices
