@@ -37,7 +37,7 @@
  *
  */
 
-#include <gtest/gtest.h>
+#include <pcl/test/gtest.h>
 #include <pcl/pcl_tests.h>
 #include <pcl/common/common.h>
 #include <pcl/common/distances.h>
@@ -46,8 +46,7 @@
 #include <pcl/common/eigen.h>
 #include <pcl/point_types.h>
 #include <pcl/point_cloud.h>
-
-#include <pcl/common/centroid.h>
+#include <pcl/common/point_tests.h> // for isFinite
 
 using namespace pcl;
 
@@ -121,10 +120,10 @@ TEST(PCL, isFinite)
 {
   PointXYZ p;
   p.x = std::numeric_limits<float>::quiet_NaN ();
-  EXPECT_EQ (isFinite (p), false);
+  EXPECT_FALSE (isFinite (p));
   Normal n;
   n.normal_x = std::numeric_limits<float>::quiet_NaN ();
-  EXPECT_EQ (isFinite (n), false);
+  EXPECT_FALSE (isFinite (n));
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -178,10 +177,10 @@ TEST (PCL, PointCloud)
   cloud.width = 640;
   cloud.height = 480;
 
-  EXPECT_EQ (cloud.isOrganized (), true);
+  EXPECT_TRUE (cloud.isOrganized ());
 
   cloud.height = 1;
-  EXPECT_EQ (cloud.isOrganized (), false);
+  EXPECT_FALSE (cloud.isOrganized ());
 
   cloud.width = 10;
   for (std::uint32_t i = 0; i < cloud.width*cloud.height; ++i)
@@ -260,27 +259,27 @@ TEST (PCL, PointCloud)
   cloud.height = 480;
 
   cloud.insert (cloud.end (), PointXYZ (1, 1, 1));
-  EXPECT_EQ (cloud.isOrganized (), false);
+  EXPECT_FALSE (cloud.isOrganized ());
   EXPECT_EQ (cloud.width, 1);
 
   cloud.insert (cloud.end (), 5, PointXYZ (1, 1, 1));
-  EXPECT_EQ (cloud.isOrganized (), false);
+  EXPECT_FALSE (cloud.isOrganized ());
   EXPECT_EQ (cloud.width, 6);
 
   cloud.erase (cloud.end () - 1);
-  EXPECT_EQ (cloud.isOrganized (), false);
+  EXPECT_FALSE (cloud.isOrganized ());
   EXPECT_EQ (cloud.width, 5);
 
   cloud.erase (cloud.begin (), cloud.end ());
-  EXPECT_EQ (cloud.isOrganized (), false);
+  EXPECT_FALSE (cloud.isOrganized ());
   EXPECT_EQ (cloud.width, 0);
 
   cloud.emplace (cloud.end (), 1, 1, 1);
-  EXPECT_EQ (cloud.isOrganized (), false);
+  EXPECT_FALSE (cloud.isOrganized ());
   EXPECT_EQ (cloud.width, 1);
 
   auto& new_point = cloud.emplace_back (1, 1, 1);
-  EXPECT_EQ (cloud.isOrganized (), false);
+  EXPECT_FALSE (cloud.isOrganized ());
   EXPECT_EQ (cloud.width, 2);
   EXPECT_EQ (&new_point, &cloud.back ());
 }
@@ -308,7 +307,7 @@ TEST (PCL, PointTypes)
 
 template <typename T> class XYZPointTypesTest : public ::testing::Test { };
 using XYZPointTypes = ::testing::Types<BOOST_PP_SEQ_ENUM(PCL_XYZ_POINT_TYPES)>;
-TYPED_TEST_CASE(XYZPointTypesTest, XYZPointTypes);
+TYPED_TEST_SUITE(XYZPointTypesTest, XYZPointTypes);
 TYPED_TEST(XYZPointTypesTest, GetVectorXfMap)
 {
   TypeParam pt;
@@ -329,7 +328,7 @@ TYPED_TEST(XYZPointTypesTest, GetArrayXfMap)
 
 template <typename T> class NormalPointTypesTest : public ::testing::Test { };
 using NormalPointTypes = ::testing::Types<BOOST_PP_SEQ_ENUM(PCL_NORMAL_POINT_TYPES)>;
-TYPED_TEST_CASE(NormalPointTypesTest, NormalPointTypes);
+TYPED_TEST_SUITE(NormalPointTypesTest, NormalPointTypes);
 TYPED_TEST(NormalPointTypesTest, GetNormalVectorXfMap)
 {
   TypeParam pt;
@@ -341,7 +340,7 @@ TYPED_TEST(NormalPointTypesTest, GetNormalVectorXfMap)
 
 template <typename T> class RGBPointTypesTest : public ::testing::Test { };
 using RGBPointTypes = ::testing::Types<BOOST_PP_SEQ_ENUM(PCL_RGB_POINT_TYPES)>;
-TYPED_TEST_CASE(RGBPointTypesTest, RGBPointTypes);
+TYPED_TEST_SUITE(RGBPointTypesTest, RGBPointTypes);
 TYPED_TEST(RGBPointTypesTest, GetRGBVectorXi)
 {
   TypeParam pt; pt.r = 1; pt.g = 2; pt.b = 3; pt.a = 4;
@@ -378,7 +377,7 @@ TEST (PCL, Intersections)
   yline[0] = 0.493479f; yline[1] = 0.169246f;  yline[2] = 1.22677f; yline[3] = 0.5992f;    yline[4] = 0.0505085f; yline[5] = 0.405749f;
 
   Eigen::Vector4f pt;
-  EXPECT_EQ ((pcl::lineWithLineIntersection (zline, yline, pt)), true);
+  EXPECT_TRUE (pcl::lineWithLineIntersection (zline, yline, pt));
   EXPECT_NEAR (pt[0], 0.574544, 1e-3);
   EXPECT_NEAR (pt[1], 0.175526, 1e-3);
   EXPECT_NEAR (pt[2], 1.27636,  1e-3);
@@ -386,7 +385,7 @@ TEST (PCL, Intersections)
 
   zline << 0.545203f, -0.514419f, 1.31967f, 0.0243372f, 0.597946f, -0.0413579f;
   yline << 0.492706f,  0.164196f, 1.23192f, 0.598704f,  0.0442014f, 0.411328f;
-  EXPECT_EQ ((pcl::lineWithLineIntersection (zline, yline, pt)), false);
+  EXPECT_FALSE (pcl::lineWithLineIntersection (zline, yline, pt));
   //intersection: [ 3.06416e+08    15.2237     3.06416e+08       4.04468e-34 ]
 }
 
@@ -409,27 +408,27 @@ TEST (PCL, CopyIfFieldExists)
   rgb_val = std::numeric_limits<float>::quiet_NaN ();
 
   pcl::for_each_type<FieldList> (CopyIfFieldExists<PointXYZRGBNormal, float> (p, "x", is_x, x_val));
-  EXPECT_EQ (is_x, true);
+  EXPECT_TRUE (is_x);
   EXPECT_EQ (x_val, 1.0);
   pcl::for_each_type<FieldList> (CopyIfFieldExists<PointXYZRGBNormal, float> (p, "y", is_y, y_val));
-  EXPECT_EQ (is_y, true);
+  EXPECT_TRUE (is_y);
   EXPECT_EQ (y_val, 2.0);
   pcl::for_each_type<FieldList> (CopyIfFieldExists<PointXYZRGBNormal, float> (p, "z", is_z, z_val));
-  EXPECT_EQ (is_z, true);
+  EXPECT_TRUE (is_z);
   EXPECT_EQ (z_val, 3.0);
   pcl::for_each_type<FieldList> (CopyIfFieldExists<PointXYZRGBNormal, float> (p, "rgb", is_rgb, rgb_val));
-  EXPECT_EQ (is_rgb, true);
+  EXPECT_TRUE (is_rgb);
   std::uint32_t rgb;
   std::memcpy (&rgb, &rgb_val, sizeof(rgb_val));
   EXPECT_EQ (rgb, 0xff7f40fe);      // alpha is 255
   pcl::for_each_type<FieldList> (CopyIfFieldExists<PointXYZRGBNormal, float> (p, "normal_x", is_normal_x, normal_x_val));
-  EXPECT_EQ (is_normal_x, true);
+  EXPECT_TRUE (is_normal_x);
   EXPECT_EQ (normal_x_val, 1.0);
   pcl::for_each_type<FieldList> (CopyIfFieldExists<PointXYZRGBNormal, float> (p, "normal_y", is_normal_y, normal_y_val));
-  EXPECT_EQ (is_normal_y, true);
+  EXPECT_TRUE (is_normal_y);
   EXPECT_EQ (normal_y_val, 0.0);
   pcl::for_each_type<FieldList> (CopyIfFieldExists<PointXYZRGBNormal, float> (p, "normal_z", is_normal_z, normal_z_val));
-  EXPECT_EQ (is_normal_z, true);
+  EXPECT_TRUE (is_normal_z);
   EXPECT_EQ (normal_z_val, 0.0);
 
   pcl::for_each_type<FieldList> (CopyIfFieldExists<PointXYZRGBNormal, float> (p, "x", x_val));
@@ -440,7 +439,7 @@ TEST (PCL, CopyIfFieldExists)
   EXPECT_EQ (xx_val, -1.0);
   bool is_xx = true;
   pcl::for_each_type<FieldList> (CopyIfFieldExists<PointXYZRGBNormal, float> (p, "xx", is_xx, xx_val));
-  EXPECT_EQ (is_xx, false);
+  EXPECT_FALSE (is_xx);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -552,7 +551,7 @@ TEST (PCL, GetMaxDistance)
   test::EXPECT_EQ_VECTORS (max_exp_pt, max_pt);
 
   // Specifying indices
-  std::vector<int> idx (2);
+  Indices idx (2);
   idx[0] = 1; idx[1] = 2;
   max_exp_pt = cloud[2].getVector4fMap ();
   getMaxDistance (cloud, idx, pivot_pt, max_pt);
