@@ -35,7 +35,7 @@
  *
  */
 
-#include <gtest/gtest.h>
+#include <pcl/test/gtest.h>
 
 #include <pcl/point_types.h>
 #include <pcl/features/normal_3d.h>
@@ -44,7 +44,6 @@
 #include <iostream>
 
 using namespace pcl;
-using namespace std;
 
 using KdTreePtr = search::KdTree<PointXYZ>::Ptr;
 PointCloud<PointXYZ> cloud;
@@ -354,15 +353,15 @@ TEST (PCL, NormalEstimation)
   PointCloud<Normal> output;
   n.compute (output);
 
-  EXPECT_EQ (output.points.size (), cloud.points.size ());
+  EXPECT_EQ (output.size (), cloud.size ());
   EXPECT_EQ (output.width, cloud.width);
   EXPECT_EQ (output.height, cloud.height);
 
-  for (std::size_t i = 0; i < cloud.points.size (); ++i)
+  for (const auto& point: output)
   {
-    EXPECT_NEAR (std::abs (output.points[i].normal_x),   0, 1e-2);
-    EXPECT_NEAR (std::abs (output.points[i].normal_y),   0, 1e-2);
-    EXPECT_NEAR (std::abs (output.points[i].normal_z), 1.0, 1e-2);
+    EXPECT_NEAR (std::abs (point.normal_x),   0, 1e-2);
+    EXPECT_NEAR (std::abs (point.normal_y),   0, 1e-2);
+    EXPECT_NEAR (std::abs (point.normal_z), 1.0, 1e-2);
   }
 }
 
@@ -374,7 +373,7 @@ TEST (PCL, IINormalEstimationCovariance)
   ne.setNormalEstimationMethod (ne.COVARIANCE_MATRIX);
   ne.compute (output);
 
-  EXPECT_EQ (output.points.size (), cloud.points.size ());
+  EXPECT_EQ (output.size (), cloud.size ());
   EXPECT_EQ (output.width, cloud.width);
   EXPECT_EQ (output.height, cloud.height);
 
@@ -402,7 +401,7 @@ TEST (PCL, IINormalEstimationAverage3DGradient)
   ne.setNormalEstimationMethod (ne.AVERAGE_3D_GRADIENT);
   ne.compute (output);
 
-  EXPECT_EQ (output.points.size (), cloud.points.size ());
+  EXPECT_EQ (output.size (), cloud.size ());
   EXPECT_EQ (output.width, cloud.width);
   EXPECT_EQ (output.height, cloud.height);
 
@@ -434,7 +433,7 @@ TEST (PCL, IINormalEstimationAverageDepthChange)
   ne.setNormalEstimationMethod (ne.AVERAGE_DEPTH_CHANGE);
   ne.compute (output);
 
-  EXPECT_EQ (output.points.size (), cloud.points.size ());
+  EXPECT_EQ (output.size (), cloud.size ());
   EXPECT_EQ (output.width, cloud.width);
   EXPECT_EQ (output.height, cloud.height);
 
@@ -466,7 +465,7 @@ TEST (PCL, IINormalEstimationSimple3DGradient)
   ne.setNormalEstimationMethod (ne.SIMPLE_3D_GRADIENT);
   ne.compute (output);
 
-  EXPECT_EQ (output.points.size (), cloud.points.size ());
+  EXPECT_EQ (output.size (), cloud.size ());
   EXPECT_EQ (output.width, cloud.width);
   EXPECT_EQ (output.height, cloud.height);
 
@@ -501,7 +500,7 @@ TEST (PCL, IINormalEstimationSimple3DGradientUnorganized)
   ne.setNormalEstimationMethod (ne.SIMPLE_3D_GRADIENT);
   ne.compute (output);
 
-  EXPECT_EQ (output.points.size (), 0);
+  EXPECT_EQ (output.size (), 0);
   EXPECT_EQ (output.width, 0);
   EXPECT_EQ (output.height, 0);
 }
