@@ -37,9 +37,9 @@
  *
  */
 
-#include <gtest/gtest.h>
+#include <pcl/test/gtest.h>
 #include <pcl/point_cloud.h>
-#include <pcl/features/normal_3d_omp.h>
+#include <pcl/features/normal_3d.h> // for NormalEstimation
 #include <pcl/io/pcd_io.h>
 #include <pcl/features/shot.h>
 #include <pcl/features/shot_omp.h>
@@ -49,7 +49,6 @@
 
 using namespace pcl;
 using namespace pcl::io;
-using namespace std;
 
 using KdTreePtr = search::KdTree<PointXYZ>::Ptr;
 
@@ -71,8 +70,8 @@ checkDesc(const pcl::PointCloud<PointT>& d0, const pcl::PointCloud<PointT>& d1)
 {
   ASSERT_EQ (d0.size (), d1.size ());
   for (std::size_t i = 0; i < d1.size (); ++i)
-    for (std::size_t j = 0; j < d0.points[i].descriptor.size(); ++j)
-      ASSERT_EQ (d0.points[i].descriptor[j], d1.points[i].descriptor[j]);
+    for (std::size_t j = 0; j < d0[i].descriptor.size(); ++j)
+      ASSERT_EQ (d0[i].descriptor[j], d1[i].descriptor[j]);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////
@@ -82,7 +81,7 @@ checkDesc<SHOT352>(const pcl::PointCloud<SHOT352>& d0, const pcl::PointCloud<SHO
   ASSERT_EQ (d0.size (), d1.size ());
   for (std::size_t i = 0; i < d1.size (); ++i)
     for (std::size_t j = 0; j < 352; ++j)
-      ASSERT_EQ (d0.points[i].descriptor[j], d1.points[i].descriptor[j]);
+      ASSERT_EQ (d0[i].descriptor[j], d1[i].descriptor[j]);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////
@@ -92,7 +91,7 @@ checkDesc<SHOT1344>(const pcl::PointCloud<SHOT1344>& d0, const pcl::PointCloud<S
   ASSERT_EQ (d0.size (), d1.size ());
   for (std::size_t i = 0; i < d1.size (); ++i)
     for (std::size_t j = 0; j < 1344; ++j)
-      ASSERT_EQ (d0.points[i].descriptor[j], d1.points[i].descriptor[j]);
+      ASSERT_EQ (d0[i].descriptor[j], d1[i].descriptor[j]);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////
@@ -102,7 +101,7 @@ checkDesc<ShapeContext1980>(const pcl::PointCloud<ShapeContext1980>& d0, const p
   ASSERT_EQ (d0.size (), d1.size ());
   for (std::size_t i = 0; i < d1.size (); ++i)
     for (std::size_t j = 0; j < 1980; ++j)
-      ASSERT_EQ (d0.points[i].descriptor[j], d1.points[i].descriptor[j]);
+      ASSERT_EQ (d0[i].descriptor[j], d1[i].descriptor[j]);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////
@@ -112,7 +111,7 @@ checkDesc<UniqueShapeContext1960>(const pcl::PointCloud<UniqueShapeContext1960>&
   ASSERT_EQ (d0.size (), d1.size ());
   for (std::size_t i = 0; i < d1.size (); ++i)
     for (std::size_t j = 0; j < 1960; ++j)
-      ASSERT_EQ (d0.points[i].descriptor[j], d1.points[i].descriptor[j]);
+      ASSERT_EQ (d0[i].descriptor[j], d1[i].descriptor[j]);
 }
 
 ///////////////////////////////////////////////////////////////////////////////////
@@ -327,15 +326,15 @@ testSHOTLocalReferenceFrame (const typename PointCloud<PointT>::Ptr & points,
   // Check frames
   pcl::PointCloud<pcl::ReferenceFrame>::ConstPtr f = est.getInputReferenceFrames ();
   pcl::PointCloud<pcl::ReferenceFrame>::ConstPtr f2 = est2.getInputReferenceFrames ();
-  ASSERT_EQ (frames->points.size (), f->points.size ());
-  ASSERT_EQ (f2->points.size (), f->points.size ());
-  for (int i = 0; i < static_cast<int> (frames->points.size ()); ++i)
+  ASSERT_EQ (frames->size (), f->size ());
+  ASSERT_EQ (f2->size (), f->size ());
+  for (int i = 0; i < static_cast<int> (frames->size ()); ++i)
   {
     for (unsigned j = 0; j < 9; ++j)
-      ASSERT_EQ (frames->points[i].rf[j], f->points[i].rf[j]);
+      ASSERT_EQ ((*frames)[i].rf[j], (*f)[i].rf[j]);
 
     for (unsigned j = 0; j < 9; ++j)
-      ASSERT_EQ (frames->points[i].rf[j], f2->points[i].rf[j]);
+      ASSERT_EQ ((*frames)[i].rf[j], (*f2)[i].rf[j]);
   }
 
   // The two cases above should produce equivalent results
@@ -371,7 +370,7 @@ struct SHOTShapeTest<SHOTEstimationOMP<PointXYZ, Normal, SHOT352> >
 using SHOTEstimatorTypes = ::testing::Types
         <SHOTEstimation<PointXYZ, Normal, SHOT352>,
          SHOTEstimationOMP<PointXYZ, Normal, SHOT352> >;
-TYPED_TEST_CASE (SHOTShapeTest, SHOTEstimatorTypes);
+TYPED_TEST_SUITE (SHOTShapeTest, SHOTEstimatorTypes);
 
 // This is a copy of the old SHOTShapeEstimation test which will now
 // be applied to both SHOTEstimation and SHOTEstimationOMP
@@ -389,16 +388,16 @@ TYPED_TEST (SHOTShapeTest, Estimation)
   n.setRadiusSearch (20 * mr);
   n.compute (*normals);
 
-  EXPECT_NEAR (normals->points[103].normal_x, 0.36683175, 1e-4);
-  EXPECT_NEAR (normals->points[103].normal_y, -0.44696972, 1e-4);
-  EXPECT_NEAR (normals->points[103].normal_z, -0.81587529, 1e-4);
-  EXPECT_NEAR (normals->points[200].normal_x, -0.71414840, 1e-4);
-  EXPECT_NEAR (normals->points[200].normal_y, -0.06002361, 1e-4);
-  EXPECT_NEAR (normals->points[200].normal_z, -0.69741613, 1e-4);
+  EXPECT_NEAR ((*normals)[103].normal_x, 0.36683175, 1e-4);
+  EXPECT_NEAR ((*normals)[103].normal_y, -0.44696972, 1e-4);
+  EXPECT_NEAR ((*normals)[103].normal_z, -0.81587529, 1e-4);
+  EXPECT_NEAR ((*normals)[200].normal_x, -0.71414840, 1e-4);
+  EXPECT_NEAR ((*normals)[200].normal_y, -0.06002361, 1e-4);
+  EXPECT_NEAR ((*normals)[200].normal_z, -0.69741613, 1e-4);
 
-  EXPECT_NEAR (normals->points[140].normal_x, -0.45109111, 1e-4);
-  EXPECT_NEAR (normals->points[140].normal_y, -0.19499126, 1e-4);
-  EXPECT_NEAR (normals->points[140].normal_z, -0.87091631, 1e-4);
+  EXPECT_NEAR ((*normals)[140].normal_x, -0.45109111, 1e-4);
+  EXPECT_NEAR ((*normals)[140].normal_y, -0.19499126, 1e-4);
+  EXPECT_NEAR ((*normals)[140].normal_z, -0.87091631, 1e-4);
 
 /*
   SHOTEstimation<PointXYZ, Normal, SHOT> shot;
@@ -416,18 +415,18 @@ TYPED_TEST (SHOTShapeTest, Estimation)
 
   // estimate
   shot.compute (*shots);
-  EXPECT_EQ (shots->points.size (), indices.size ());
+  EXPECT_EQ (shots->size (), indices.size ());
 
-  EXPECT_NEAR (shots->points[103].descriptor[9 ], 0.0072018504, 1e-4);
-  EXPECT_NEAR (shots->points[103].descriptor[10], 0.0023103887, 1e-4);
-  EXPECT_NEAR (shots->points[103].descriptor[11], 0.0024724449, 1e-4);
-  EXPECT_NEAR (shots->points[103].descriptor[19], 0.0031367359, 1e-4);
-  EXPECT_NEAR (shots->points[103].descriptor[20], 0.17439659, 1e-4);
-  EXPECT_NEAR (shots->points[103].descriptor[21], 0.070665278, 1e-4);
-  EXPECT_NEAR (shots->points[103].descriptor[42], 0.013304681, 1e-4);
-  EXPECT_NEAR (shots->points[103].descriptor[53], 0.0073520984, 1e-4);
-  EXPECT_NEAR (shots->points[103].descriptor[54], 0.013584172, 1e-4);
-  EXPECT_NEAR (shots->points[103].descriptor[55], 0.0050609680, 1e-4);
+  EXPECT_NEAR ((*shots)[103].descriptor[9 ], 0.0072018504, 1e-4);
+  EXPECT_NEAR ((*shots)[103].descriptor[10], 0.0023103887, 1e-4);
+  EXPECT_NEAR ((*shots)[103].descriptor[11], 0.0024724449, 1e-4);
+  EXPECT_NEAR ((*shots)[103].descriptor[19], 0.0031367359, 1e-4);
+  EXPECT_NEAR ((*shots)[103].descriptor[20], 0.17439659, 1e-4);
+  EXPECT_NEAR ((*shots)[103].descriptor[21], 0.070665278, 1e-4);
+  EXPECT_NEAR ((*shots)[103].descriptor[42], 0.013304681, 1e-4);
+  EXPECT_NEAR ((*shots)[103].descriptor[53], 0.0073520984, 1e-4);
+  EXPECT_NEAR ((*shots)[103].descriptor[54], 0.013584172, 1e-4);
+  EXPECT_NEAR ((*shots)[103].descriptor[55], 0.0050609680, 1e-4);
 */
 
   // SHOT352
@@ -446,18 +445,18 @@ TYPED_TEST (SHOTShapeTest, Estimation)
 
   // estimate
   shot352.compute (*shots352);
-  EXPECT_EQ (shots352->points.size (), indices.size ());
+  EXPECT_EQ (shots352->size (), indices.size ());
 
-  EXPECT_NEAR (shots352->points[103].descriptor[9 ], 0.0072018504, 1e-4);
-  EXPECT_NEAR (shots352->points[103].descriptor[10], 0.0023103887, 1e-4);
-  EXPECT_NEAR (shots352->points[103].descriptor[11], 0.0024724449, 1e-4);
-  EXPECT_NEAR (shots352->points[103].descriptor[19], 0.0031367359, 1e-4);
-  EXPECT_NEAR (shots352->points[103].descriptor[20], 0.17439659, 1e-4);
-  EXPECT_NEAR (shots352->points[103].descriptor[21], 0.06542316, 1e-4);
-  EXPECT_NEAR (shots352->points[103].descriptor[42], 0.013304681, 1e-4);
-  EXPECT_NEAR (shots352->points[103].descriptor[53], 0.0073520984, 1e-4);
-  EXPECT_NEAR (shots352->points[103].descriptor[54], 0.013584172, 1e-4);
-  EXPECT_NEAR (shots352->points[103].descriptor[55], 0.0050609680, 1e-4);
+  EXPECT_NEAR ((*shots352)[103].descriptor[9 ], 0.0072018504, 1e-4);
+  EXPECT_NEAR ((*shots352)[103].descriptor[10], 0.0023103887, 1e-4);
+  EXPECT_NEAR ((*shots352)[103].descriptor[11], 0.0024724449, 1e-4);
+  EXPECT_NEAR ((*shots352)[103].descriptor[19], 0.0031367359, 1e-4);
+  EXPECT_NEAR ((*shots352)[103].descriptor[20], 0.17439659, 1e-4);
+  EXPECT_NEAR ((*shots352)[103].descriptor[21], 0.06542316, 1e-4);
+  EXPECT_NEAR ((*shots352)[103].descriptor[42], 0.013304681, 1e-4);
+  EXPECT_NEAR ((*shots352)[103].descriptor[53], 0.0073520984, 1e-4);
+  EXPECT_NEAR ((*shots352)[103].descriptor[54], 0.013584172, 1e-4);
+  EXPECT_NEAR ((*shots352)[103].descriptor[55], 0.0050609680, 1e-4);
 
 
   // Test results when setIndices and/or setSearchSurface are used
@@ -508,18 +507,18 @@ TEST (PCL, GenericSHOTShapeEstimation)
 
   // estimate
   shot.compute (*shots);
-  EXPECT_EQ (shots->points.size (), indices.size ());
+  EXPECT_EQ (shots->size (), indices.size ());
 
-  EXPECT_NEAR (shots->points[103].descriptor[18], 0.0077019366, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[19], 0.0024708188, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[21], 0.0079652183, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[38], 0.0067090928, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[39], 0.17498907, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[40], 0.078413926, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[81], 0.014228539, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[103], 0.022390056, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[105], 0.0058866320, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[123], 0.019105887, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[18], 0.0077019366, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[19], 0.0024708188, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[21], 0.0079652183, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[38], 0.0067090928, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[39], 0.17498907, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[40], 0.078413926, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[81], 0.014228539, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[103], 0.022390056, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[105], 0.0058866320, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[123], 0.019105887, 1e-5);
 
   // Test results when setIndices and/or setSearchSurface are used
   pcl::IndicesPtr test_indices (new pcl::Indices (0));
@@ -560,7 +559,7 @@ struct SHOTShapeAndColorTest<SHOTColorEstimationOMP<PointXYZRGBA, Normal, SHOT13
 using SHOTColorEstimatorTypes= ::testing::Types
         <SHOTColorEstimation<PointXYZRGBA, Normal, SHOT1344>,
          SHOTColorEstimationOMP<PointXYZRGBA, Normal, SHOT1344> >;
-TYPED_TEST_CASE (SHOTShapeAndColorTest, SHOTColorEstimatorTypes);
+TYPED_TEST_SUITE (SHOTShapeAndColorTest, SHOTColorEstimatorTypes);
 
 // This is a copy of the old SHOTShapeAndColorEstimation test which will now
 // be applied to both SHOTColorEstimation and SHOTColorEstimationOMP
@@ -583,12 +582,12 @@ TYPED_TEST (SHOTShapeAndColorTest, Estimation)
 
   // Create fake point cloud with colors
   PointCloud<PointXYZRGBA> cloudWithColors;
-  for (int i = 0; i < static_cast<int> (cloud.points.size ()); ++i)
+  for (int i = 0; i < static_cast<int> (cloud.size ()); ++i)
   {
     PointXYZRGBA p;
-    p.x = cloud.points[i].x;
-    p.y = cloud.points[i].y;
-    p.z = cloud.points[i].z;
+    p.x = cloud[i].x;
+    p.y = cloud[i].y;
+    p.z = cloud[i].z;
 
     p.rgba = ( (i%255) << 16 ) + ( ( (255 - i ) %255) << 8) + ( ( i*37 ) %255);
     cloudWithColors.push_back(p);
@@ -611,29 +610,29 @@ TYPED_TEST (SHOTShapeAndColorTest, Estimation)
 
   // estimate
   shot.compute (*shots);
-  EXPECT_EQ (shots->points.size (), indices.size ());
+  EXPECT_EQ (shots->size (), indices.size ());
 
-  EXPECT_NEAR (shots->points[103].descriptor[10], 0.0020453099, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[11], 0.0021887729, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[21], 0.062557608, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[42], 0.011778189, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[53], 0.0065085669, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[54], 0.012025614, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[55], 0.0044803056, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[64], 0.064429596, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[65], 0.046486385, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[86], 0.011518310, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[10], 0.0020453099, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[11], 0.0021887729, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[21], 0.062557608, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[42], 0.011778189, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[53], 0.0065085669, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[54], 0.012025614, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[55], 0.0044803056, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[64], 0.064429596, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[65], 0.046486385, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[86], 0.011518310, 1e-5);
 
-  EXPECT_NEAR (shots->points[103].descriptor[357], 0.0020453099, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[360], 0.0027993850, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[386], 0.045115642, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[387], 0.059068538, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[389], 0.0047547864, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[453], 0.0051176427, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[481], 0.0053625242, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[482], 0.012025614, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[511], 0.0057367259, 1e-5);
-  EXPECT_NEAR (shots->points[103].descriptor[512], 0.048357654, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[357], 0.0020453099, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[360], 0.0027993850, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[386], 0.045115642, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[387], 0.059068538, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[389], 0.0047547864, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[453], 0.0051176427, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[481], 0.0053625242, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[482], 0.012025614, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[511], 0.0057367259, 1e-5);
+  EXPECT_NEAR ((*shots)[103].descriptor[512], 0.048357654, 1e-5);
 */
 
   // SHOT1344
@@ -651,29 +650,29 @@ TYPED_TEST (SHOTShapeAndColorTest, Estimation)
 
   // estimate
   shot1344.compute (*shots1344);
-  EXPECT_EQ (shots1344->points.size (), indices.size ());
+  EXPECT_EQ (shots1344->size (), indices.size ());
 
-  EXPECT_NEAR (shots1344->points[103].descriptor[10], 0.0020453099, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[11], 0.0021887729, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[21], 0.0579300672, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[42], 0.011778189, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[53], 0.0065085669, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[54], 0.012025614, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[55], 0.0044803056, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[64], 0.064453065, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[65], 0.046504568, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[86], 0.011518310, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[10], 0.0020453099, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[11], 0.0021887729, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[21], 0.0579300672, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[42], 0.011778189, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[53], 0.0065085669, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[54], 0.012025614, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[55], 0.0044803056, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[64], 0.064453065, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[65], 0.046504568, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[86], 0.011518310, 1e-5);
 
-  EXPECT_NEAR (shots1344->points[103].descriptor[357], 0.0020453099, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[360], 0.0027993850, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[386], 0.0451327376, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[387], 0.0544394031, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[389], 0.0047547864, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[453], 0.0051176427, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[481], 0.0053625242, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[482], 0.012025614, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[511], 0.0057367259, 1e-5);
-  EXPECT_NEAR (shots1344->points[103].descriptor[512], 0.048375979, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[357], 0.0020453099, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[360], 0.0027993850, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[386], 0.0451327376, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[387], 0.0544394031, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[389], 0.0047547864, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[453], 0.0051176427, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[481], 0.0053625242, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[482], 0.012025614, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[511], 0.0057367259, 1e-5);
+  EXPECT_NEAR ((*shots1344)[103].descriptor[512], 0.048375979, 1e-5);
 
   // Test results when setIndices and/or setSearchSurface are used
   pcl::IndicesPtr test_indices (new pcl::Indices (0));
@@ -839,7 +838,7 @@ main (int argc, char** argv)
     return (-1);
   }
 
-  indices.resize (cloud.points.size ());
+  indices.resize (cloud.size ());
   for (std::size_t i = 0; i < indices.size (); ++i)
     indices[i] = static_cast<int> (i);
 
