@@ -38,7 +38,9 @@
  *
  */
 
-#include <gtest/gtest.h>
+#include <pcl/test/gtest.h>
+#include <pcl/memory.h>  // for pcl::make_shared
+#include <pcl/pcl_base.h>  // for pcl::Indices
 #include <pcl/pcl_tests.h>
 #include <pcl/point_types.h>
 #include <pcl/filters/box_clipper3D.h>
@@ -49,7 +51,6 @@
 #include <pcl/common/eigen.h>
 
 using namespace pcl;
-using namespace std;
 using namespace Eigen;
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -71,7 +72,7 @@ TEST (BoxClipper3D, Filters)
   input->push_back (PointXYZ (-0.9f, -0.9f, -0.9f));
 
   ExtractIndices<PointXYZ> extract_indices;
-  std::vector<int> indices;
+  pcl::Indices indices;
 
   BoxClipper3D<PointXYZ> boxClipper3D (Affine3f::Identity ());
   boxClipper3D.clipPointCloud3D (*input, indices);
@@ -79,7 +80,7 @@ TEST (BoxClipper3D, Filters)
   PointCloud<PointXYZ> cloud_out;
 
   extract_indices.setInputCloud (input);
-  extract_indices.setIndices (boost::make_shared<vector<int> > (indices));
+  extract_indices.setIndices (pcl::make_shared<pcl::Indices> (indices));
   extract_indices.filter (cloud_out);
 
   EXPECT_EQ (int (indices.size ()), 9);
@@ -776,4 +777,4 @@ main (int argc, char** argv)
   testing::InitGoogleTest (&argc, argv);
   return (RUN_ALL_TESTS ());
 }
-/* ]--- */
\ No newline at end of file
+/* ]--- */
