@@ -39,7 +39,7 @@
 
 #include <iostream>
 
-#include <gtest/gtest.h>
+#include <pcl/test/gtest.h>
 #include <pcl/point_types.h>
 #include <pcl/io/point_cloud_image_extractors.h>
 
@@ -170,8 +170,8 @@ TEST (PCL, PointCloudImageExtractorFromLabelFieldMono)
   cloud.height = 2;
   cloud.is_dense = true;
   cloud.points.resize (cloud.width * cloud.height);
-  for (std::size_t i = 0; i < cloud.points.size (); i++)
-    cloud.points[i].label = i;
+  for (std::size_t i = 0; i < cloud.size (); i++)
+    cloud[i].label = i;
 
   pcl::PCLImage image;
   PointCloudImageExtractorFromLabelField<PointT> pcie;
@@ -184,7 +184,7 @@ TEST (PCL, PointCloudImageExtractorFromLabelFieldMono)
   EXPECT_EQ (cloud.width, image.width);
   EXPECT_EQ (cloud.height, image.height);
 
-  for (std::size_t i = 0; i < cloud.points.size (); i++)
+  for (std::size_t i = 0; i < cloud.size (); i++)
     EXPECT_EQ (i, data[i]);
 }
 
@@ -197,8 +197,8 @@ TEST (PCL, PointCloudImageExtractorFromLabelFieldRGB)
   cloud.height = 2;
   cloud.is_dense = true;
   cloud.points.resize (cloud.width * cloud.height);
-  for (std::size_t i = 0; i < cloud.points.size (); i++)
-    cloud.points[i].label = i % 2;
+  for (std::size_t i = 0; i < cloud.size (); i++)
+    cloud[i].label = i % 2;
 
   pcl::PCLImage image;
   PointCloudImageExtractorFromLabelField<PointT> pcie;
@@ -235,8 +235,8 @@ TEST (PCL, PointCloudImageExtractorFromLabelFieldGlasbey)
   cloud.height = 2;
   cloud.is_dense = true;
   cloud.points.resize (cloud.width * cloud.height);
-  for (std::size_t i = 0; i < cloud.points.size (); i++)
-    cloud.points[i].label = i % 2;
+  for (std::size_t i = 0; i < cloud.size (); i++)
+    cloud[i].label = i % 2;
 
   pcl::PCLImage image;
   PointCloudImageExtractorFromLabelField<PointT> pcie;
@@ -249,8 +249,8 @@ TEST (PCL, PointCloudImageExtractorFromLabelFieldGlasbey)
   EXPECT_EQ (cloud.height, image.height);
 
   // Fill in different labels and extract another image
-  for (std::size_t i = 0; i < cloud.points.size (); i++)
-    cloud.points[i].label = i % 2 + 10;
+  for (std::size_t i = 0; i < cloud.size (); i++)
+    cloud[i].label = i % 2 + 10;
   pcl::PCLImage image2;
   ASSERT_TRUE (pcie.extract (cloud, image2));
 
@@ -272,8 +272,8 @@ TEST (PCL, PointCloudImageExtractorFromZField)
   cloud.height = 2;
   cloud.is_dense = true;
   cloud.points.resize (cloud.width * cloud.height);
-  for (std::size_t i = 0; i < cloud.points.size (); i++)
-    cloud.points[i].z = 1.0 + i;
+  for (std::size_t i = 0; i < cloud.size (); i++)
+    cloud[i].z = 1.0 + i;
 
   pcl::PCLImage image;
   PointCloudImageExtractorFromZField<PointT> pcie;
@@ -286,7 +286,7 @@ TEST (PCL, PointCloudImageExtractorFromZField)
   EXPECT_EQ (cloud.height, image.height);
 
   // by default Z field extractor scales with factor 10000
-  for (std::size_t i = 0; i < cloud.points.size (); i++)
+  for (std::size_t i = 0; i < cloud.size (); i++)
     EXPECT_EQ (10000 * (i + 1), data[i]);
 }
 
@@ -300,10 +300,10 @@ TEST (PCL, PointCloudImageExtractorFromCurvatureField)
   cloud.is_dense = true;
   cloud.points.resize (cloud.width * cloud.height);
 
-  cloud.points[0].curvature = 1.0;
-  cloud.points[1].curvature = 2.0;
-  cloud.points[2].curvature = 1.0;
-  cloud.points[3].curvature = 2.0;
+  cloud[0].curvature = 1.0;
+  cloud[1].curvature = 2.0;
+  cloud[2].curvature = 1.0;
+  cloud[3].curvature = 2.0;
 
   pcl::PCLImage image;
   PointCloudImageExtractorFromCurvatureField<PointT> pcie;
@@ -332,10 +332,10 @@ TEST (PCL, PointCloudImageExtractorFromIntensityField)
   cloud.is_dense = true;
   cloud.points.resize (cloud.width * cloud.height);
 
-  cloud.points[0].intensity = 10.0;
-  cloud.points[1].intensity = 23.3;
-  cloud.points[2].intensity = 28.9;
-  cloud.points[3].intensity = 40.0;
+  cloud[0].intensity = 10.0;
+  cloud[1].intensity = 23.3;
+  cloud[2].intensity = 28.9;
+  cloud[3].intensity = 40.0;
 
   pcl::PCLImage image;
   PointCloudImageExtractorFromIntensityField<PointT> pcie;
@@ -348,8 +348,8 @@ TEST (PCL, PointCloudImageExtractorFromIntensityField)
   EXPECT_EQ (cloud.height, image.height);
 
   // by default Intensity field extractor does not apply scaling
-  for (std::size_t i = 0; i < cloud.points.size (); i++)
-    EXPECT_EQ (static_cast<unsigned short> (cloud.points[i].intensity), data[i]);
+  for (std::size_t i = 0; i < cloud.size (); i++)
+    EXPECT_EQ (static_cast<unsigned short> (cloud[i].intensity), data[i]);
 }
 
 //////////////////////////////////////////////////////////////////////////////////////////////////////////////////
@@ -399,11 +399,11 @@ TEST (PCL, PointCloudImageExtractorBlackNaNs)
   cloud.is_dense = false;
   cloud.points.resize (cloud.width * cloud.height);
 
-  cloud.points[0].curvature = 1.0;
-  cloud.points[1].curvature = 2.0;
-  cloud.points[2].curvature = 1.0;
-  cloud.points[3].curvature = 2.0;
-  cloud.points[3].z = std::numeric_limits<float>::quiet_NaN ();
+  cloud[0].curvature = 1.0;
+  cloud[1].curvature = 2.0;
+  cloud[2].curvature = 1.0;
+  cloud[3].curvature = 2.0;
+  cloud[3].z = std::numeric_limits<float>::quiet_NaN ();
 
   pcl::PCLImage image;
 
