@@ -36,7 +36,7 @@
  * $Id: $
  *
  */
-#include <gtest/gtest.h>
+#include <pcl/test/gtest.h>
 #include <pcl/io/pcd_io.h>
 #include <pcl/point_cloud.h>
 #include <pcl/common/transforms.h>
@@ -49,7 +49,6 @@
 #include <pcl/recognition/cg/geometric_consistency.h>
 #include <pcl/common/eigen.h>
 
-using namespace std;
 using namespace pcl;
 using namespace pcl::io;
 
