@@ -36,6 +36,7 @@
 
 #include <iostream>
 #include <string>
+#include <thread>
 #include <tide/ebml_element.h>
 #include <tide/file_cluster.h>
 #include <tide/segment.h>
@@ -53,6 +54,7 @@
 #include <pcl/common/time.h>
 #include "boost.h"
 
+using namespace std::chrono_literals;
 namespace bpt = boost::posix_time;
 
 
@@ -189,8 +191,9 @@ class Recorder
             // Set up a callback to get clouds from a grabber and write them to the
             // file.
             pcl::Grabber* interface(new pcl::OpenNIGrabber());
-            boost::function<void (const pcl::PointCloud<pcl::PointXYZ>::ConstPtr&)> f(
-                    boost::bind(&Recorder::Callback, this, _1));
+            std::function<void (const pcl::PointCloud<pcl::PointXYZ>::ConstPtr&)> f (
+                [this] (const pcl::PointCloud<pcl::PointXYZ>::ConstPtr&) { Callback (cloud); }
+            );
             interface->registerCallback(f);
             // Start the first cluster
             cltr_start_ = bpt::microsec_clock::local_time();
@@ -387,7 +390,7 @@ class Player
                 played_time = bpt::microsec_clock::local_time() - pb_start;
                 bpt::time_duration sleep_time(blk_offset - played_time);
                 std::cerr << "Will sleep " << sleep_time << " until displaying block\n";
-                boost::this_thread::sleep(sleep_time);
+                std::this_thread::sleep_for(sleep_time);
                 viewer_.showCloud(cloud);
                 //viewer_.removePointCloud("1");
                 //viewer_.addPointCloud(cloud, "1");
