@@ -35,18 +35,24 @@
  *
  */
 
-#ifndef PCL_POINT_CLOUD_COLOR_HANDLERS_IMPL_HPP_
-#define PCL_POINT_CLOUD_COLOR_HANDLERS_IMPL_HPP_
+#pragma once
 
 #include <set>
 #include <map>
 
 #include <pcl/pcl_macros.h>
 #include <pcl/common/colors.h>
+#include <pcl/common/point_tests.h> // for pcl::isFinite
+
+
+namespace pcl
+{
+
+namespace visualization
+{
 
-///////////////////////////////////////////////////////////////////////////////////////////
 template <typename PointT> vtkSmartPointer<vtkDataArray>
-pcl::visualization::PointCloudColorHandlerCustom<PointT>::getColor () const
+PointCloudColorHandlerCustom<PointT>::getColor () const
 {
   if (!capable_ || !cloud_)
     return nullptr;
@@ -54,7 +60,7 @@ pcl::visualization::PointCloudColorHandlerCustom<PointT>::getColor () const
   auto scalars = vtkSmartPointer<vtkUnsignedCharArray>::New ();
   scalars->SetNumberOfComponents (3);
 
-  vtkIdType nr_points = cloud_->points.size ();
+  vtkIdType nr_points = cloud_->size ();
   scalars->SetNumberOfTuples (nr_points);
 
   // Get a random color
@@ -71,9 +77,9 @@ pcl::visualization::PointCloudColorHandlerCustom<PointT>::getColor () const
   return scalars;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT> vtkSmartPointer<vtkDataArray>
-pcl::visualization::PointCloudColorHandlerRandom<PointT>::getColor () const
+PointCloudColorHandlerRandom<PointT>::getColor () const
 {
   if (!capable_ || !cloud_)
     return nullptr;
@@ -81,7 +87,7 @@ pcl::visualization::PointCloudColorHandlerRandom<PointT>::getColor () const
   auto scalars = vtkSmartPointer<vtkUnsignedCharArray>::New ();
   scalars->SetNumberOfComponents (3);
 
-  vtkIdType nr_points = cloud_->points.size ();
+  vtkIdType nr_points = cloud_->size ();
   scalars->SetNumberOfTuples (nr_points);
 
   // Get a random color
@@ -89,8 +95,8 @@ pcl::visualization::PointCloudColorHandlerRandom<PointT>::getColor () const
   double r, g, b;
   pcl::visualization::getRandomColors (r, g, b);
 
-  int r_ = static_cast<int> (pcl_lrint (r * 255.0)), 
-      g_ = static_cast<int> (pcl_lrint (g * 255.0)), 
+  int r_ = static_cast<int> (pcl_lrint (r * 255.0)),
+      g_ = static_cast<int> (pcl_lrint (g * 255.0)),
       b_ = static_cast<int> (pcl_lrint (b * 255.0));
 
   // Color every point
@@ -104,9 +110,9 @@ pcl::visualization::PointCloudColorHandlerRandom<PointT>::getColor () const
   return scalars;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT> void
-pcl::visualization::PointCloudColorHandlerRGBField<PointT>::setInputCloud (
+PointCloudColorHandlerRGBField<PointT>::setInputCloud (
     const PointCloudConstPtr &cloud)
 {
   PointCloudColorHandler<PointT>::setInputCloud (cloud);
@@ -127,9 +133,9 @@ pcl::visualization::PointCloudColorHandlerRGBField<PointT>::setInputCloud (
   }
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT> vtkSmartPointer<vtkDataArray>
-pcl::visualization::PointCloudColorHandlerRGBField<PointT>::getColor () const
+PointCloudColorHandlerRGBField<PointT>::getColor () const
 {
   if (!capable_ || !cloud_)
     return nullptr;
@@ -146,7 +152,7 @@ pcl::visualization::PointCloudColorHandlerRGBField<PointT>::getColor () const
   auto scalars = vtkSmartPointer<vtkUnsignedCharArray>::New ();
   scalars->SetNumberOfComponents (3);
 
-  vtkIdType nr_points = cloud_->points.size ();
+  vtkIdType nr_points = cloud_->size ();
   scalars->SetNumberOfTuples (nr_points);
   unsigned char* colors = scalars->GetPointer (0);
 
@@ -164,12 +170,12 @@ pcl::visualization::PointCloudColorHandlerRGBField<PointT>::getColor () const
     for (vtkIdType cp = 0; cp < nr_points; ++cp)
     {
       // Copy the value at the specified field
-      if (!std::isfinite (cloud_->points[cp].x) ||
-          !std::isfinite (cloud_->points[cp].y) || 
-          !std::isfinite (cloud_->points[cp].z))
+      if (!std::isfinite ((*cloud_)[cp].x) ||
+          !std::isfinite ((*cloud_)[cp].y) ||
+          !std::isfinite ((*cloud_)[cp].z))
         continue;
 
-      memcpy (&rgb, (reinterpret_cast<const char *> (&cloud_->points[cp])) + rgba_offset, sizeof (pcl::RGB));
+      memcpy (&rgb, (reinterpret_cast<const char *> (&(*cloud_)[cp])) + rgba_offset, sizeof (pcl::RGB));
       colors[j    ] = rgb.r;
       colors[j + 1] = rgb.g;
       colors[j + 2] = rgb.b;
@@ -182,7 +188,7 @@ pcl::visualization::PointCloudColorHandlerRGBField<PointT>::getColor () const
     for (vtkIdType cp = 0; cp < nr_points; ++cp)
     {
       int idx = static_cast<int> (cp) * 3;
-      memcpy (&rgb, (reinterpret_cast<const char *> (&cloud_->points[cp])) + rgba_offset, sizeof (pcl::RGB));
+      memcpy (&rgb, (reinterpret_cast<const char *> (&(*cloud_)[cp])) + rgba_offset, sizeof (pcl::RGB));
       colors[idx    ] = rgb.r;
       colors[idx + 1] = rgb.g;
       colors[idx + 2] = rgb.b;
@@ -191,10 +197,10 @@ pcl::visualization::PointCloudColorHandlerRGBField<PointT>::getColor () const
   return scalars;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT>
-pcl::visualization::PointCloudColorHandlerHSVField<PointT>::PointCloudColorHandlerHSVField (const PointCloudConstPtr &cloud) : 
-  pcl::visualization::PointCloudColorHandler<PointT>::PointCloudColorHandler (cloud)
+PointCloudColorHandlerHSVField<PointT>::PointCloudColorHandlerHSVField (const PointCloudConstPtr &cloud) :
+  PointCloudColorHandler<PointT>::PointCloudColorHandler (cloud)
 {
   // Check for the presence of the "H" field
   field_idx_ = pcl::getFieldIndex<PointT> ("h", fields_);
@@ -222,9 +228,9 @@ pcl::visualization::PointCloudColorHandlerHSVField<PointT>::PointCloudColorHandl
   capable_ = true;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT> vtkSmartPointer<vtkDataArray>
-pcl::visualization::PointCloudColorHandlerHSVField<PointT>::getColor () const
+PointCloudColorHandlerHSVField<PointT>::getColor () const
 {
   if (!capable_ || !cloud_)
     return nullptr;
@@ -232,7 +238,7 @@ pcl::visualization::PointCloudColorHandlerHSVField<PointT>::getColor () const
   auto scalars = vtkSmartPointer<vtkUnsignedCharArray>::New ();
   scalars->SetNumberOfComponents (3);
 
-  vtkIdType nr_points = cloud_->points.size ();
+  vtkIdType nr_points = cloud_->size ();
   scalars->SetNumberOfTuples (nr_points);
   unsigned char* colors = scalars->GetPointer (0);
 
@@ -250,16 +256,16 @@ pcl::visualization::PointCloudColorHandlerHSVField<PointT>::getColor () const
     for (vtkIdType cp = 0; cp < nr_points; ++cp)
     {
       // Copy the value at the specified field
-      if (!std::isfinite (cloud_->points[cp].x) ||
-          !std::isfinite (cloud_->points[cp].y) ||
-          !std::isfinite (cloud_->points[cp].z))
+      if (!std::isfinite ((*cloud_)[cp].x) ||
+          !std::isfinite ((*cloud_)[cp].y) ||
+          !std::isfinite ((*cloud_)[cp].z))
         continue;
 
       ///@todo do this with the point_types_conversion in common, first template it!
 
-      float h = cloud_->points[cp].h;
-      float v = cloud_->points[cp].v;
-      float s = cloud_->points[cp].s;
+      float h = (*cloud_)[cp].h;
+      float v = (*cloud_)[cp].v;
+      float s = (*cloud_)[cp].s;
 
       // Fill color data with HSV here:
       // restrict the hue value to [0,360[
@@ -309,9 +315,9 @@ pcl::visualization::PointCloudColorHandlerHSVField<PointT>::getColor () const
     // Color every point
     for (vtkIdType cp = 0; cp < nr_points; ++cp)
     {
-      float h = cloud_->points[cp].h;
-      float v = cloud_->points[cp].v;
-      float s = cloud_->points[cp].s;
+      float h = (*cloud_)[cp].h;
+      float v = (*cloud_)[cp].v;
+      float s = (*cloud_)[cp].s;
 
       // Fill color data with HSV here:
       // restrict the hue value to [0,360[
@@ -359,9 +365,9 @@ pcl::visualization::PointCloudColorHandlerHSVField<PointT>::getColor () const
   return scalars;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT> void
-pcl::visualization::PointCloudColorHandlerGenericField<PointT>::setInputCloud (
+PointCloudColorHandlerGenericField<PointT>::setInputCloud (
     const PointCloudConstPtr &cloud)
 {
   PointCloudColorHandler<PointT>::setInputCloud (cloud);
@@ -372,9 +378,9 @@ pcl::visualization::PointCloudColorHandlerGenericField<PointT>::setInputCloud (
     capable_ = false;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT> vtkSmartPointer<vtkDataArray>
-pcl::visualization::PointCloudColorHandlerGenericField<PointT>::getColor () const
+PointCloudColorHandlerGenericField<PointT>::getColor () const
 {
   if (!capable_ || !cloud_)
     return nullptr;
@@ -382,7 +388,7 @@ pcl::visualization::PointCloudColorHandlerGenericField<PointT>::getColor () cons
   auto scalars = vtkSmartPointer<vtkFloatArray>::New ();
   scalars->SetNumberOfComponents (1);
 
-  vtkIdType nr_points = cloud_->points.size ();
+  vtkIdType nr_points = cloud_->size ();
   scalars->SetNumberOfTuples (nr_points);
 
   using FieldList = typename pcl::traits::fieldList<PointT>::type;
@@ -403,10 +409,10 @@ pcl::visualization::PointCloudColorHandlerGenericField<PointT>::getColor () cons
     for (vtkIdType cp = 0; cp < nr_points; ++cp)
     {
       // Copy the value at the specified field
-      if (!std::isfinite (cloud_->points[cp].x) || !std::isfinite (cloud_->points[cp].y) || !std::isfinite (cloud_->points[cp].z))
+      if (!std::isfinite ((*cloud_)[cp].x) || !std::isfinite ((*cloud_)[cp].y) || !std::isfinite ((*cloud_)[cp].z))
         continue;
 
-      const std::uint8_t* pt_data = reinterpret_cast<const std::uint8_t*> (&cloud_->points[cp]);
+      const std::uint8_t* pt_data = reinterpret_cast<const std::uint8_t*> (&(*cloud_)[cp]);
       memcpy (&field_data, pt_data + fields_[field_idx_].offset, pcl::getFieldSize (fields_[field_idx_].datatype));
 
       colors[j] = field_data;
@@ -418,7 +424,7 @@ pcl::visualization::PointCloudColorHandlerGenericField<PointT>::getColor () cons
     // Color every point
     for (vtkIdType cp = 0; cp < nr_points; ++cp)
     {
-      const std::uint8_t* pt_data = reinterpret_cast<const std::uint8_t*> (&cloud_->points[cp]);
+      const std::uint8_t* pt_data = reinterpret_cast<const std::uint8_t*> (&(*cloud_)[cp]);
       memcpy (&field_data, pt_data + fields_[field_idx_].offset, pcl::getFieldSize (fields_[field_idx_].datatype));
 
       if (!std::isfinite (field_data))
@@ -432,9 +438,9 @@ pcl::visualization::PointCloudColorHandlerGenericField<PointT>::getColor () cons
   return scalars;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT> void
-pcl::visualization::PointCloudColorHandlerRGBAField<PointT>::setInputCloud (
+PointCloudColorHandlerRGBAField<PointT>::setInputCloud (
     const PointCloudConstPtr &cloud)
 {
   PointCloudColorHandler<PointT>::setInputCloud (cloud);
@@ -446,9 +452,9 @@ pcl::visualization::PointCloudColorHandlerRGBAField<PointT>::setInputCloud (
     capable_ = false;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT> vtkSmartPointer<vtkDataArray>
-pcl::visualization::PointCloudColorHandlerRGBAField<PointT>::getColor () const
+PointCloudColorHandlerRGBAField<PointT>::getColor () const
 {
   if (!capable_ || !cloud_)
     return nullptr;
@@ -456,11 +462,10 @@ pcl::visualization::PointCloudColorHandlerRGBAField<PointT>::getColor () const
   auto scalars = vtkSmartPointer<vtkUnsignedCharArray>::New ();
   scalars->SetNumberOfComponents (4);
 
-  vtkIdType nr_points = cloud_->points.size ();
+  vtkIdType nr_points = cloud_->size ();
   scalars->SetNumberOfTuples (nr_points);
   unsigned char* colors = scalars->GetPointer (0);
 
-  int j = 0;
   // If XYZ present, check if the points are invalid
   int x_idx = -1;
   for (std::size_t d = 0; d < fields_.size (); ++d)
@@ -469,19 +474,20 @@ pcl::visualization::PointCloudColorHandlerRGBAField<PointT>::getColor () const
 
   if (x_idx != -1)
   {
+    int j = 0;
     // Color every point
     for (vtkIdType cp = 0; cp < nr_points; ++cp)
     {
       // Copy the value at the specified field
-      if (!std::isfinite (cloud_->points[cp].x) ||
-          !std::isfinite (cloud_->points[cp].y) ||
-          !std::isfinite (cloud_->points[cp].z))
+      if (!std::isfinite ((*cloud_)[cp].x) ||
+          !std::isfinite ((*cloud_)[cp].y) ||
+          !std::isfinite ((*cloud_)[cp].z))
         continue;
 
-      colors[j    ] = cloud_->points[cp].r;
-      colors[j + 1] = cloud_->points[cp].g;
-      colors[j + 2] = cloud_->points[cp].b;
-      colors[j + 3] = cloud_->points[cp].a;
+      colors[j    ] = (*cloud_)[cp].r;
+      colors[j + 1] = (*cloud_)[cp].g;
+      colors[j + 2] = (*cloud_)[cp].b;
+      colors[j + 3] = (*cloud_)[cp].a;
       j += 4;
     }
   }
@@ -491,18 +497,18 @@ pcl::visualization::PointCloudColorHandlerRGBAField<PointT>::getColor () const
     for (vtkIdType cp = 0; cp < nr_points; ++cp)
     {
       int idx = static_cast<int> (cp) * 4;
-      colors[idx    ] = cloud_->points[cp].r;
-      colors[idx + 1] = cloud_->points[cp].g;
-      colors[idx + 2] = cloud_->points[cp].b;
-      colors[idx + 3] = cloud_->points[cp].a;
+      colors[idx    ] = (*cloud_)[cp].r;
+      colors[idx + 1] = (*cloud_)[cp].g;
+      colors[idx + 2] = (*cloud_)[cp].b;
+      colors[idx + 3] = (*cloud_)[cp].a;
     }
   }
   return scalars;
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT> void
-pcl::visualization::PointCloudColorHandlerLabelField<PointT>::setInputCloud (const PointCloudConstPtr &cloud)
+PointCloudColorHandlerLabelField<PointT>::setInputCloud (const PointCloudConstPtr &cloud)
 {
   PointCloudColorHandler<PointT>::setInputCloud (cloud);
   field_idx_ = pcl::getFieldIndex<PointT> ("label", fields_);
@@ -513,9 +519,9 @@ pcl::visualization::PointCloudColorHandlerLabelField<PointT>::setInputCloud (con
   }
 }
 
-///////////////////////////////////////////////////////////////////////////////////////////
+
 template <typename PointT> vtkSmartPointer<vtkDataArray>
-pcl::visualization::PointCloudColorHandlerLabelField<PointT>::getColor () const
+PointCloudColorHandlerLabelField<PointT>::getColor () const
 {
   if (!capable_ || !cloud_)
     return nullptr;
@@ -523,7 +529,7 @@ pcl::visualization::PointCloudColorHandlerLabelField<PointT>::getColor () const
   auto scalars = vtkSmartPointer<vtkUnsignedCharArray>::New ();
   scalars->SetNumberOfComponents (3);
 
-  vtkIdType nr_points = cloud_->points.size ();
+  vtkIdType nr_points = cloud_->size ();
   scalars->SetNumberOfTuples (nr_points);
   unsigned char* colors = scalars->GetPointer (0);
 
@@ -534,7 +540,7 @@ pcl::visualization::PointCloudColorHandlerLabelField<PointT>::getColor () const
     std::set<std::uint32_t> labels;
     // First pass: find unique labels
     for (vtkIdType i = 0; i < nr_points; ++i)
-      labels.insert (cloud_->points[i].label);
+      labels.insert ((*cloud_)[i].label);
 
     // Assign Glasbey colors in ascending order of labels
     std::size_t color = 0;
@@ -545,9 +551,9 @@ pcl::visualization::PointCloudColorHandlerLabelField<PointT>::getColor () const
   int j = 0;
   for (vtkIdType cp = 0; cp < nr_points; ++cp)
   {
-    if (pcl::isFinite (cloud_->points[cp]))
+    if (pcl::isFinite ((*cloud_)[cp]))
     {
-      const pcl::RGB& color = static_mapping_ ? GlasbeyLUT::at (cloud_->points[cp].label % GlasbeyLUT::size ()) : colormap[cloud_->points[cp].label];
+      const pcl::RGB& color = static_mapping_ ? GlasbeyLUT::at ((*cloud_)[cp].label % GlasbeyLUT::size ()) : colormap[(*cloud_)[cp].label];
       colors[j    ] = color.r;
       colors[j + 1] = color.g;
       colors[j + 2] = color.b;
@@ -558,5 +564,6 @@ pcl::visualization::PointCloudColorHandlerLabelField<PointT>::getColor () const
   return scalars;
 }
 
-#endif      // PCL_POINT_CLOUD_COLOR_HANDLERS_IMPL_HPP_
+} // namespace visualization
+} // namespace pcl
 
