@@ -71,7 +71,7 @@ namespace pcl
         performSinglePick (vtkRenderWindowInteractor *iren, float &x, float &y, float &z);
 
         int
-        performAreaPick (vtkRenderWindowInteractor *iren, std::vector<int> &indices);
+        performAreaPick (vtkRenderWindowInteractor *iren, std::vector<int> &indices) const;
 
       private:
         float x_, y_, z_;
